@@ -1,5 +1,5 @@
 ;Liquid War 6 is a unique multiplayer wargame.
-;Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
+;Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
 ;
 ;This program is free software; you can redistribute it and/or modify
 ;it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@
 (debug-set! depth 50)
 
 (define (lazy-catch-handler key . args)
-  ;(let ((stack (make-stack #t lazy-catch-handler)))
+  ;; (let ((stack (make-stack #t lazy-catch-handler)))
   (let ((stack (make-stack #t 5)))
     ;; do whatever you want with stack, such as
     ;; saving it off or calling display-backtrace
@@ -37,22 +37,23 @@
 	(display-backtrace stack backtrace-port 
 			   (- (stack-length stack) 5)
 			   (- (stack-length stack) 8))
-	(c-lw6sys-log 0
-	 (format #f
-		 "~a \"~a\""
-		 (_ "scheme error")
-		 (apply format (cons #f (cons (cadr args) (caddr args))))
-		 ))
 	(c-lw6sys-dump 
 	 (format #f
 		 "~a\n~a"
 		 (apply format (cons #f (cons (cadr args) (caddr args))))
 		 (get-output-string backtrace-port)))
+	(c-lw6sys-log 0
+		      (format #f
+			      "~a \"~a\""
+			      (_ "scheme error")
+			      (apply format (cons #f (cons (cadr args) (caddr args))))
+			      ))
 	(close-output-port backtrace-port)	       
+	(c-lw6-release)
 	)
       )
     )
-    ;(apply throw key args)
+  ;; (apply throw key args)
   )
 
 (catch #t
@@ -66,11 +67,13 @@
 			 (c-lw6sys-log 3 (_ "leaving Guile"))
 			 )
 		       )
-		       lazy-catch-handler
-		       )
+		     lazy-catch-handler
+		     )
 	 )
        (lambda (key . args)
-	 (c-lw6sys-log 1 (_ "unexpected error, leaving Guile without proper cleaning"))
+	 (begin
+	   (c-lw6sys-log 3 (_ "catched Guile error"))
+	   )
 	 )
        )
 
