@@ -25,7 +25,6 @@
       (load "backend.scm")
       (load "bench.scm")
       (load "clear.scm")
-      (load "color.scm")
       (load "command.scm")
       (load "config.scm")
       (load "console.scm")
@@ -48,7 +47,6 @@
       (load "menu-ingame.scm")
       (load "menu-map.scm")
       (load "menu-options.scm")
-      (load "menu-options-map.scm")
       (load "menu-options-time.scm")
       (load "menu-options-rules.scm")
       (load "menu-options-audio.scm")
@@ -58,6 +56,7 @@
       (load "menu-player-detail.scm")
       (load "menu-players.scm")
       (load "menu-root.scm")
+      (load "menu-score.scm")
       (load "menu-wait.scm")
       (load "mover.scm")
       (load "music.scm")
