@@ -25,10 +25,10 @@
 	  )
       (begin
 	;; no items here!
-	(assoc-set! menu "on-cancel" (lambda (m) (begin (c-lw6gfx-show-mouse #t) 
-							(lw6-push-menu (lw6-options-menu-light)))))
-	(assoc-set! menu "on-pop" (lambda (m) (c-lw6gfx-show-mouse #t)))
-	(assoc-set! menu "on-push" (lambda (m) (c-lw6gfx-show-mouse #f)))
-	(assoc-set! menu "on-pop-child" (lambda (m) (c-lw6gfx-show-mouse #f)))
+	(assoc-set! menu "on-cancel" (lambda (m) 
+				       (let ((dsp (lw6-get-game-global "dsp")))
+					 (begin
+					   (c-lw6gui-input-reset dsp)					  
+					   (lw6-push-menu (lw6-options-menu-light))))))
 	menu
 	))))
