@@ -28,32 +28,39 @@
 		     (c-lw6sys-signal-poll-quit)
 		     (c-lw6gui-mouse-pop-button-left dsp)
 		     (c-lw6gui-mouse-pop-button-right dsp)
+		     (c-lw6gui-mouse-pop-button-middle dsp)
 		     (c-lw6gui-mouse-pop-wheel-up dsp)
 		     (c-lw6gui-mouse-pop-wheel-down dsp)
-		     (c-lw6gui-keyboard-pop-key-up dsp)
-		     (c-lw6gui-keyboard-pop-key-down dsp)
-		     (c-lw6gui-keyboard-pop-key-left dsp)
-		     (c-lw6gui-keyboard-pop-key-right dsp)
+		     (c-lw6gui-keyboard-pop-arrow-up dsp)
+		     (c-lw6gui-keyboard-pop-arrow-down dsp)
+		     (c-lw6gui-keyboard-pop-arrow-left dsp)
+		     (c-lw6gui-keyboard-pop-arrow-right dsp)
 		     (c-lw6gui-keyboard-pop-key-enter dsp)
 		     (c-lw6gui-keyboard-pop-key-esc dsp)
+		     (c-lw6gui-keyboard-pop-key-ctrl dsp)
+		     (c-lw6gui-keyboard-pop-key-alt dsp)
 		     (c-lw6gui-keyboard-pop-key-pgup dsp)
 		     (c-lw6gui-keyboard-pop-key-pgdown dsp)
-		     (c-lw6gui-joystick1-pop-button-up dsp)
-		     (c-lw6gui-joystick1-pop-button-down dsp)
-		     (c-lw6gui-joystick1-pop-button-left dsp)
-		     (c-lw6gui-joystick1-pop-button-right dsp)
+		     (c-lw6gui-joystick1-pop-pad-up dsp)
+		     (c-lw6gui-joystick1-pop-pad-down dsp)
+		     (c-lw6gui-joystick1-pop-pad-left dsp)
+		     (c-lw6gui-joystick1-pop-pad-right dsp)
 		     (c-lw6gui-joystick1-pop-button-a dsp)
 		     (c-lw6gui-joystick1-pop-button-b dsp)
 		     (c-lw6gui-joystick1-pop-button-c dsp)
 		     (c-lw6gui-joystick1-pop-button-d dsp)
-		     (c-lw6gui-joystick2-pop-button-up dsp)
-		     (c-lw6gui-joystick2-pop-button-down dsp)
-		     (c-lw6gui-joystick2-pop-button-left dsp)
-		     (c-lw6gui-joystick2-pop-button-right dsp)
+		     (c-lw6gui-joystick1-pop-button-e dsp)
+		     (c-lw6gui-joystick1-pop-button-f dsp)
+		     (c-lw6gui-joystick2-pop-pad-up dsp)
+		     (c-lw6gui-joystick2-pop-pad-down dsp)
+		     (c-lw6gui-joystick2-pop-pad-left dsp)
+		     (c-lw6gui-joystick2-pop-pad-right dsp)
 		     (c-lw6gui-joystick2-pop-button-a dsp)
 		     (c-lw6gui-joystick2-pop-button-b dsp)
 		     (c-lw6gui-joystick2-pop-button-c dsp)
-		     (c-lw6gui-joystick2-pop-button-d dsp)))
+		     (c-lw6gui-joystick2-pop-button-d dsp)
+		     (c-lw6gui-joystick2-pop-button-e dsp)
+		     (c-lw6gui-joystick2-pop-button-f dsp)))
 	       (begin 
 		 (lw6-display-update)
 		 (lw6-node-poll)
