@@ -95,7 +95,7 @@ mod_idiot_get_pedigree ()
     {
       module_pedigree->id = "idiot";
       module_pedigree->category = "bot";
-      module_pedigree->name = _x_ ("Idiot");
+      module_pedigree->name = _("Idiot");
       module_pedigree->readme =
 	_x_
 	("A basic - almost idiot - bot which uses the old LW5 algorithm, that is, choose a point in the opponents' amries and go to it.");
