@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -32,11 +32,9 @@
 static void
 defaults_callback (void *func_data, void *data)
 {
-  _lw6cfg_context_t *context;
   char *entry = NULL;
   char *default_value = NULL;
 
-  context = (_lw6cfg_context_t *) func_data;
   entry = (char *) data;
   if (entry)
     {
@@ -132,7 +130,7 @@ lw6cfg_defaults (void *context)
       hostname = lw6sys_get_hostname ();
       if (hostname)
 	{
-	  player_name = lw6sys_new_sprintf (_("player2@%s"), hostname);
+	  player_name = lw6sys_new_sprintf (_x_ ("player2@%s"), hostname);
 	  if (player_name)
 	    {
 	      lw6cfg_set_option (context, LW6DEF_PLAYER2_NAME, player_name);
@@ -142,7 +140,7 @@ lw6cfg_defaults (void *context)
 	    {
 	      ret = 0;
 	    }
-	  player_name = lw6sys_new_sprintf (_("player3@%s"), hostname);
+	  player_name = lw6sys_new_sprintf (_x_ ("player3@%s"), hostname);
 	  if (player_name)
 	    {
 	      lw6cfg_set_option (context, LW6DEF_PLAYER3_NAME, player_name);
@@ -152,7 +150,7 @@ lw6cfg_defaults (void *context)
 	    {
 	      ret = 0;
 	    }
-	  player_name = lw6sys_new_sprintf (_("player4@%s"), hostname);
+	  player_name = lw6sys_new_sprintf (_x_ ("player4@%s"), hostname);
 	  if (player_name)
 	    {
 	      lw6cfg_set_option (context, LW6DEF_PLAYER4_NAME, player_name);
