@@ -33,6 +33,7 @@
 #define TEST_ARGV2 "--width=800"
 #define TEST_UNIFIED_KEY_YES LW6DEF_WIDTH
 #define TEST_UNIFIED_KEY_NO "unknown"
+#define TEST_EXP_DIR "/tmp"
 
 /*
  * Testing loading/saving
@@ -130,6 +131,51 @@ test_unified ()
   return ret;
 }
 
+/*
+ * Test exp functions
+ */
+static int
+test_exp ()
+{
+  int ret = 1;
+  LW6SYS_TEST_FUNCTION_BEGIN;
+
+  {
+    int exp = 0;
+    int new_exp = 0;
+
+    lw6cfg_load_exp (TEST_EXP_DIR, &exp);
+    lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("first exp read exp=%d"), exp);
+    if (lw6cfg_save_exp (TEST_EXP_DIR, exp))
+      {
+	lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("exp saved"));
+	if (lw6cfg_load_exp (TEST_EXP_DIR, &new_exp))
+	  {
+	    if (new_exp == exp)
+	      {
+		lw6sys_log (LW6SYS_LOG_NOTICE,
+			    _x_ ("new exp read exp=%d"), new_exp);
+	      }
+	    else
+	      {
+		lw6sys_log (LW6SYS_LOG_WARNING,
+			    _x_ ("wrong new exp should be %d but is %d"),
+			    exp, new_exp);
+		ret = 0;
+	      }
+	  }
+      }
+    else
+      {
+	lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("unable to save exp"));
+	ret = 0;
+      }
+  }
+
+  LW6SYS_TEST_FUNCTION_END;
+  return ret;
+}
+
 /**
  * lw6cfg_test
  *
@@ -154,5 +200,10 @@ lw6cfg_test (int mode)
 
   ret = test_load_save () && test_unified ();
 
+  if (mode)
+    {
+      ret = ret && test_exp ();
+    }
+
   return ret;
 }
