@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@ static void
 _warning (const char *func_name)
 {
   lw6sys_log (LW6SYS_LOG_WARNING,
-	      _("cli backend function \"%s\" is not defined"), func_name);
+	      _x_ ("cli backend function \"%s\" is not defined"), func_name);
 }
 
 int
@@ -99,19 +99,25 @@ lw6cli_process_oob (lw6cli_backend_t * backend,
   return ret;
 }
 
-lw6cli_connection_t *
-lw6cli_connect (lw6cli_backend_t * backend, char *server_url,
-		char *client_url, char *password)
+lw6cnx_connection_t *
+lw6cli_open (lw6cli_backend_t * backend, char *local_url, char *remote_url,
+	     char *remote_ip, int remote_port,
+	     char *password, u_int64_t local_id, u_int64_t remote_id,
+	     int dns_ok, int network_reliability,
+	     lw6cnx_recv_callback_t recv_callback_func,
+	     void *recv_callback_data)
 {
-  lw6cli_connection_t *ret = NULL;
+  lw6cnx_connection_t *ret = NULL;
 
   LW6SYS_BACKEND_FUNCTION_BEGIN;
 
-  if (backend->connect)
+  if (backend->open)
     {
       ret =
-	backend->connect (backend->cli_context, server_url, client_url,
-			  password);
+	backend->open (backend->cli_context, local_url, remote_url, remote_ip,
+		       remote_port, password, local_id, remote_id, dns_ok,
+		       network_reliability, recv_callback_func,
+		       recv_callback_data);
     }
   else
     {
@@ -124,7 +130,7 @@ lw6cli_connect (lw6cli_backend_t * backend, char *server_url,
 }
 
 void
-lw6cli_close (lw6cli_backend_t * backend, lw6cli_connection_t * connection)
+lw6cli_close (lw6cli_backend_t * backend, lw6cnx_connection_t * connection)
 {
   LW6SYS_BACKEND_FUNCTION_BEGIN;
 
@@ -141,8 +147,10 @@ lw6cli_close (lw6cli_backend_t * backend, lw6cli_connection_t * connection)
 }
 
 int
-lw6cli_send (lw6cli_backend_t * backend, lw6cli_connection_t * connection,
-	     char *message)
+lw6cli_send (lw6cli_backend_t * backend, lw6cnx_connection_t * connection,
+	     u_int32_t physical_ticket_sig, u_int32_t logical_ticket_sig,
+	     u_int64_t logical_from_id,
+	     u_int64_t logical_to_id, char *message)
 {
   int ret = 0;
 
@@ -150,7 +158,21 @@ lw6cli_send (lw6cli_backend_t * backend, lw6cli_connection_t * connection,
 
   if (backend->send)
     {
-      ret = backend->send (backend->cli_context, connection, message);
+      if (lw6cnx_connection_reliability_filter (connection))
+	{
+	  ret =
+	    backend->send (backend->cli_context, connection,
+			   physical_ticket_sig, logical_ticket_sig,
+			   logical_from_id, logical_to_id, message);
+	}
+      else
+	{
+	  /*
+	   * Yes, we return true, the idea is to pretend success
+	   * but in fact real send failed.
+	   */
+	  ret = 1;
+	}
     }
   else
     {
@@ -162,50 +184,25 @@ lw6cli_send (lw6cli_backend_t * backend, lw6cli_connection_t * connection,
   return ret;
 }
 
+void
+lw6cli_poll (lw6cli_backend_t * backend, lw6cnx_connection_t * connection)
+{
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
+
+  if (backend->poll)
+    {
+      backend->poll (backend->cli_context, connection);
+    }
+  else
+    {
+      _warning (__FUNCTION__);
+    }
+
+  LW6SYS_BACKEND_FUNCTION_END;
+}
+
 char *
-lw6cli_recv (lw6cli_backend_t * backend, lw6cli_connection_t * connection)
-{
-  char *ret = NULL;
-
-  LW6SYS_BACKEND_FUNCTION_BEGIN;
-
-  if (backend->recv)
-    {
-      ret = backend->recv (backend->cli_context, connection);
-    }
-  else
-    {
-      _warning (__FUNCTION__);
-    }
-
-  LW6SYS_BACKEND_FUNCTION_END;
-
-  return ret;
-}
-
-int
-lw6cli_is_alive (lw6cli_backend_t * backend, lw6cli_connection_t * connection)
-{
-  int ret = 0;
-
-  LW6SYS_BACKEND_FUNCTION_BEGIN;
-
-  if (backend->is_alive)
-    {
-      ret = backend->is_alive (backend->cli_context, connection);
-    }
-  else
-    {
-      _warning (__FUNCTION__);
-    }
-
-  LW6SYS_BACKEND_FUNCTION_END;
-
-  return ret;
-}
-
-char *
-lw6cli_repr (lw6cli_backend_t * backend, lw6cli_connection_t * connection)
+lw6cli_repr (lw6cli_backend_t * backend, lw6cnx_connection_t * connection)
 {
   char *ret = NULL;
 
@@ -224,24 +221,3 @@ lw6cli_repr (lw6cli_backend_t * backend, lw6cli_connection_t * connection)
 
   return ret;
 }
-
-char *
-lw6cli_error (lw6cli_backend_t * backend, lw6cli_connection_t * connection)
-{
-  char *ret = NULL;
-
-  LW6SYS_BACKEND_FUNCTION_BEGIN;
-
-  if (backend->error)
-    {
-      ret = backend->error (backend->cli_context, connection);
-    }
-  else
-    {
-      _warning (__FUNCTION__);
-    }
-
-  LW6SYS_BACKEND_FUNCTION_END;
-
-  return ret;
-}
