@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -29,16 +29,10 @@
 #include "../cfg/cfg.h"
 #include "../net/net.h"
 #include "../nod/nod.h"
+#include "../cnx/cnx.h"
 #include "../msg/msg.h"
 
-typedef struct lw6cli_connection_s
-{
-  void *cli_context;
-  char *server_url;
-  char *client_url;
-  void *connection_data;
-}
-lw6cli_connection_t;
+#define LW6CLI_CONTENT_BUFFER_SIZE LW6NET_PPPOE_MTU
 
 typedef int (*lw6cli_verify_callback_func_t) (void *func_data, char *url,
 					      char *ip, int port,
@@ -75,15 +69,22 @@ typedef struct lw6cli_backend_s
   void (*quit) (void *cli_context);
   int (*process_oob) (void *cli_context, lw6nod_info_t * node_info,
 		      lw6cli_oob_data_t * oob_data);
-  lw6cli_connection_t *(*connect) (void *cli_context, char *server_url,
-				   char *client_url, char *password);
-  void (*close) (void *cli_context, lw6cli_connection_t * connection);
-  int (*send) (void *cli_context, lw6cli_connection_t * connection,
-	       char *message);
-  char *(*recv) (void *cli_context, lw6cli_connection_t * connection);
-  int (*is_alive) (void *cli_context, lw6cli_connection_t * connection);
-  char *(*repr) (void *cli_context, lw6cli_connection_t * connection);
-  char *(*error) (void *cli_context, lw6cli_connection_t * connection);
+  lw6cnx_connection_t *(*open) (void *cli_context, char *local_url,
+				char *remote_url, char *remote_ip,
+				int remote_port, char *password,
+				u_int64_t local_id, u_int64_t remote_id,
+				int dns_ok,
+				int network_reliability,
+				lw6cnx_recv_callback_t recv_callback_func,
+				void *recv_callback_data);
+  void (*close) (void *cli_context, lw6cnx_connection_t * connection);
+  int (*send) (void *cli_context, lw6cnx_connection_t * connection,
+	       u_int32_t physical_ticket_sig,
+	       u_int32_t logical_ticket_sig,
+	       u_int64_t logical_from_id,
+	       u_int64_t logical_to_id, char *message);
+  void (*poll) (void *cli_context, lw6cnx_connection_t * connection);
+  char *(*repr) (void *cli_context, lw6cnx_connection_t * connection);
 }
 lw6cli_backend_t;
 
@@ -95,21 +96,31 @@ extern void lw6cli_quit (lw6cli_backend_t * backend);
 extern int lw6cli_process_oob (lw6cli_backend_t * backend,
 			       lw6nod_info_t * node_info,
 			       lw6cli_oob_data_t * oob_data);
-extern lw6cli_connection_t *lw6cli_connect (lw6cli_backend_t * backend,
-					    char *server_url,
-					    char *client_url, char *password);
+extern lw6cnx_connection_t *lw6cli_open (lw6cli_backend_t * backend,
+					 char *local_url,
+					 char *remote_url,
+					 char *remote_ip,
+					 int remote_port,
+					 char *password,
+					 u_int64_t local_id,
+					 u_int64_t remote_id,
+					 int dns_ok,
+					 int network_reliability,
+					 lw6cnx_recv_callback_t
+					 recv_callback_func,
+					 void *recv_callback_data);
 extern void lw6cli_close (lw6cli_backend_t * backend,
-			  lw6cli_connection_t * connection);
+			  lw6cnx_connection_t * connection);
 extern int lw6cli_send (lw6cli_backend_t * backend,
-			lw6cli_connection_t * connection, char *message);
-extern char *lw6cli_recv (lw6cli_backend_t * backend,
-			  lw6cli_connection_t * connection);
-extern int lw6cli_is_alive (lw6cli_backend_t * backend,
-			    lw6cli_connection_t * connection);
+			lw6cnx_connection_t * connection,
+			u_int32_t physical_ticket_sig,
+			u_int32_t logical_ticket_sig,
+			u_int64_t logical_from_id, u_int64_t logical_to_id,
+			char *message);
+extern void lw6cli_poll (lw6cli_backend_t * backend,
+			 lw6cnx_connection_t * connection);
 extern char *lw6cli_repr (lw6cli_backend_t * backend,
-			  lw6cli_connection_t * connection);
-extern char *lw6cli_error (lw6cli_backend_t * backend,
-			   lw6cli_connection_t * connection);
+			  lw6cnx_connection_t * connection);
 
 /* cli-oob.c */
 extern lw6cli_oob_t *lw6cli_oob_new (char *public_url,
