@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -42,9 +42,7 @@ extern void lw6cns_history_add_if_needed (char *line);
  */
 extern int lw6cns_support ();
 
-/*
- * Functions in test.c
- */
-extern int lw6cns_test ();
+/* cns-test.c */
+extern int lw6cns_test (int mode);
 
 #endif
