@@ -39,6 +39,7 @@
 #define TEST_FULLSCREEN2 0
 #define TEST_REPEAT_DELAY 200
 #define TEST_REPEAT_INTERVAL 20
+#define TEST_DOUBLE_CLICK_DELAY 400
 #define TEST_FRAMES_PER_SEC 60
 #define TEST_DISPLAY_BACKGROUND 1
 #define TEST_DISPLAY_MENU 1
@@ -112,6 +113,7 @@ level_new (char *name, int display_width, int display_height,
 {
   lw6map_level_t *ret = NULL;
   char *map_path = NULL;
+  char *user_dir = NULL;
   int argc = TEST_ARGC;
   char *argv[TEST_ARGC] = { TEST_ARGV0 };
 
@@ -119,10 +121,17 @@ level_new (char *name, int display_width, int display_height,
   map_path = lw6cfg_unified_get_map_path (argc, argv);
   if (map_path)
     {
-      ret =
-	lw6ldr_read_relative (map_path, TEST_MAP, NULL, NULL, display_width,
-			      display_height, LW6LDR_DEFAULT_BENCH_VALUE,
-			      LW6LDR_DEFAULT_MAGIC_NUMBER, progress);
+      user_dir = lw6sys_get_user_dir (argc, argv);
+      if (user_dir)
+	{
+	  ret =
+	    lw6ldr_read_relative (map_path, TEST_MAP, NULL, NULL,
+				  display_width, display_height,
+				  LW6LDR_DEFAULT_BENCH_VALUE,
+				  LW6LDR_DEFAULT_MAGIC_NUMBER, user_dir,
+				  progress);
+	  LW6SYS_FREE (user_dir);
+	}
       LW6SYS_FREE (map_path);
     }
   lw6sys_progress_begin (progress);
@@ -251,6 +260,8 @@ test_display (char *gfx_backend_name)
 		param.video_mode.fullscreen = TEST_FULLSCREEN2;
 		param.misc.repeat_settings.delay = TEST_REPEAT_DELAY;
 		param.misc.repeat_settings.interval = TEST_REPEAT_INTERVAL;
+		param.misc.repeat_settings.double_click_delay =
+		  TEST_DOUBLE_CLICK_DELAY;
 		param.misc.log_timeout = TEST_LOG_TIMEOUT;
 		lw6dsp_update (display, &param);
 		sleep_and_report (display, TEST_SLEEP_LONG);
@@ -494,6 +505,7 @@ lw6dsp_test (int mode)
       lw6map_test (mode);
       lw6ker_test (mode);
       lw6gui_test (mode);
+      lw6vox_test (mode);
       lw6gfx_test (mode);
     }
 
