@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@ static void
 _warning (const char *func_name)
 {
   lw6sys_log (LW6SYS_LOG_WARNING,
-	      _("background backend function \"%s\" is not defined"));
+	      _x_ ("background backend function \"%s\" is not defined"));
 }
 
 int
