@@ -24,12 +24,11 @@
 #include "config.h"
 #endif
 
-#include <math.h>
-
 #include "../../mod-gl.h"
 #include "gl-cylinder-internal.h"
 
 #define TEST_MENU_SIZE 8
+#define _DESC_MENU "menu"
 
 /*
  * OpenGL wizardry, to prepare view parameters.
@@ -141,7 +140,7 @@ draw_button (mod_gl_utils_context_t * utils_context,
 {
   SDL_Surface *text_surface = NULL;
   mod_gl_utils_bitmap_t *bitmap = NULL;
-  char *utf8;
+  char *utf8 = NULL;
   SDL_Color bg_color;
   SDL_Color fg_color;
   int ret = 0;
@@ -177,7 +176,8 @@ draw_button (mod_gl_utils_context_t * utils_context,
 		2 * utils_context->const_data.menu_font_size;
 	      bitmap =
 		mod_gl_utils_bitmap_new (utils_context, bitmap_w,
-					 MOD_GL_UTILS_MENU_TEXTURE_H);
+					 MOD_GL_UTILS_MENU_TEXTURE_H,
+					 _DESC_MENU);
 	      if (bitmap != NULL)
 		{
 		  text_rect.x = 0;
@@ -379,8 +379,11 @@ mod_gl_menu_cylinder_display_menu (mod_gl_utils_context_t * utils_context,
 				     menu_position),
 				   &(utils_context->input.mouse.menu_scroll),
 				   &(utils_context->input.mouse.menu_esc),
-				   menu, utils_context->input.mouse.x,
-				   utils_context->input.mouse.y);
+				   menu,
+				   utils_context->input.mouse.
+				   screen_pointer.pos_x,
+				   utils_context->input.mouse.
+				   screen_pointer.pos_y);
 }
 
 void
