@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -46,12 +46,13 @@ mod_gl_utils_load_image (mod_gl_utils_context_t * utils_context,
 
   if (image_file)
     {
-      lw6sys_log (LW6SYS_LOG_INFO, _("loading image \"%s\""), image_file);
+      lw6sys_log (LW6SYS_LOG_INFO, _x_ ("loading image \"%s\""), image_file);
       ret = IMG_Load (image_file);
       if (!ret)
 	{
 	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _("SDL_image error \"%s\" while loading image \"%s\""),
+		      _x_
+		      ("SDL_image error \"%s\" while loading image \"%s\""),
 		      IMG_GetError (), image_file);
 	}
       LW6SYS_FREE (image_file);
@@ -95,7 +96,7 @@ load_font (mod_gl_utils_context_t * utils_context, char *filename, int size)
   font_file = lw6sys_path_concat (utils_context->path.data_dir, filename);
   if (font_file)
     {
-      lw6sys_log (LW6SYS_LOG_INFO, _("loading font \"%s\", size %d"),
+      lw6sys_log (LW6SYS_LOG_INFO, _x_ ("loading font \"%s\", size %d"),
 		  font_file, size);
       ret = TTF_OpenFont (font_file, size);
       LW6SYS_FREE (font_file);
@@ -130,7 +131,7 @@ mod_gl_utils_load_fonts (mod_gl_utils_context_t * utils_context)
 {
   int ret = 0;
 
-  lw6sys_log (LW6SYS_LOG_INFO, _("loading fonts"));
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("loading fonts"));
 
   ret =
     ((utils_context->font_data.menu =
