@@ -62,5 +62,11 @@ mod_gl_utils_timer_get_bitmap_refresh (mod_gl_utils_context_t * utils_context)
 extern void
 mod_gl_utils_timer_set_bitmap_refresh (mod_gl_utils_context_t * utils_context)
 {
+#if LW6_MS_WINDOWS || LW6_MAC_OS_X
+  lw6sys_log (LW6SYS_LOG_INFO,
+	      _x_
+	      ("forcing the purge of textures now, OpenGL context might be lost"));
+  mod_gl_utils_bitmap_hash_refresh (utils_context);
+#endif
   utils_context->timer.bitmap_refresh = utils_context->timer.timestamp;
 }
