@@ -23,6 +23,8 @@
 #ifndef LIQUIDWAR6GFX_MOD_GL_UTILS_H
 #define LIQUIDWAR6GFX_MOD_GL_UTILS_H
 
+#include <math.h>
+
 #include "../../gfx.h"
 
 #include <SDL.h>
@@ -36,6 +38,7 @@
 
 #define MOD_GL_UTILS_MENU_TEXTURE_W 512
 #define MOD_GL_UTILS_MENU_TEXTURE_H 128
+#define MOD_GL_UTILS_TRANSPARENCY_SCALE 100
 
 /*
  * We keep 64 menu bitmaps in memory, to avoid redrawing them
@@ -67,7 +70,7 @@
 typedef struct mod_gl_utils_bitmap_s
 {
   u_int32_t id;
-  char *filename;
+  char *desc;
   SDL_Surface *surface;
   int has_alpha;
   SDL_Surface *colorized_surface;
@@ -83,7 +86,8 @@ typedef struct mod_gl_utils_bitmap_s
   float t1;
   float s2;
   float t2;
-  u_int64_t last_refresh;
+  int64_t last_refresh;
+  int need_another_refresh;
 } mod_gl_utils_bitmap_t;
 
 typedef struct mod_gl_utils_shaded_text_s
@@ -101,6 +105,8 @@ typedef struct mod_gl_utils_path_s
 {
   char *data_dir;
   char *capture_dir;
+  char *bitmap_dir;
+  char *bitmap_frame_dir;
 }
 mod_gl_utils_path_t;
 
@@ -125,7 +131,8 @@ typedef enum mod_gl_utils_render_mode_e
   MOD_GL_UTILS_RENDER_2D_BLEND = 2,
   MOD_GL_UTILS_RENDER_3D_MAP = 3,
   MOD_GL_UTILS_RENDER_3D_MENU = 4,
-  MOD_GL_UTILS_RENDER_3D_PICK = 5
+  MOD_GL_UTILS_RENDER_3D_SELECT = 5,
+  MOD_GL_UTILS_RENDER_3D_FEEDBACK = 6
 }
 mod_gl_utils_render_mode_t;
 
@@ -137,20 +144,20 @@ typedef struct mod_gl_utils_render_param_s
 
 typedef struct mod_gl_utils_rect_array_s
 {
-  int n_w;
-  int n_h;
-  int *x0;
-  int *y0;
-  int *w;
-  int *h;
-  float *screen_x;
-  float *screen_y;
+  int tile_size;
+  int border_size;
+  int tile_spacing;
+  int nb_tiles_w;
+  int nb_tiles_h;
+  int nb_tiles;
+  int source_w;
+  int source_h;
 }
 mod_gl_utils_rect_array_t;
 
 typedef struct mod_gl_utils_bitmap_array_s
 {
-  mod_gl_utils_rect_array_t layout;
+  lw6gui_rect_array_t layout;
   mod_gl_utils_bitmap_t **bitmaps;
 }
 mod_gl_utils_bitmap_array_t;
@@ -233,6 +240,10 @@ typedef struct mod_gl_utils_const_data_s
   int keysym2_enter;
   int keysym1_esc;
   int keysym2_esc;
+  int keysym1_ctrl;
+  int keysym2_ctrl;
+  int keysym1_alt;
+  int keysym2_alt;
   int keysym1_pgup;
   int keysym2_pgup;
   int keysym1_pgdown;
@@ -244,11 +255,15 @@ typedef struct mod_gl_utils_const_data_s
   int joystick1_button_b_index;
   int joystick1_button_c_index;
   int joystick1_button_d_index;
+  int joystick1_button_e_index;
+  int joystick1_button_f_index;
   int joystick2_index;
   int joystick2_button_a_index;
   int joystick2_button_b_index;
   int joystick2_button_c_index;
   int joystick2_button_d_index;
+  int joystick2_button_e_index;
+  int joystick2_button_f_index;
   int joystick_all_buttons;
   int smoother_global_zoom_duration;
   int smoother_center_duration;
@@ -285,6 +300,9 @@ typedef struct mod_gl_utils_texture_1x1_s
   mod_gl_utils_bitmap_t *system_color_bg;
   mod_gl_utils_bitmap_t *team_color_dead;
   mod_gl_utils_bitmap_t *team_colors[LW6MAP_NB_TEAM_COLORS];
+    mod_gl_utils_bitmap_t
+    * team_colors_transparency[LW6MAP_NB_TEAM_COLORS]
+    [MOD_GL_UTILS_TRANSPARENCY_SCALE + 1];
 }
 mod_gl_utils_texture_1x1_t;
 
@@ -329,20 +347,20 @@ mod_gl_utils_timer_t;
 typedef struct _mod_gl_utils_smoothers_s
 {
   lw6gui_smoother_t global_zoom;
-  lw6gui_smoother_t center_x;
-  lw6gui_smoother_t center_y;
-  lw6gui_smoother_t drawable_x1;
-  lw6gui_smoother_t drawable_y1;
-  lw6gui_smoother_t drawable_x2;
-  lw6gui_smoother_t drawable_y2;
+  lw6gui_smoother_t map_center_x;
+  lw6gui_smoother_t map_center_y;
+  //lw6gui_smoother_t drawable_x1;
+  //lw6gui_smoother_t drawable_y1;
+  //lw6gui_smoother_t drawable_x2;
+  //lw6gui_smoother_t drawable_y2;
 }
 _mod_gl_utils_smoothers_t;
 
 typedef struct _mod_gl_utils_smoothed_s
 {
   float global_zoom;
-  float center_x;
-  float center_y;
+  float map_center_x;
+  float map_center_y;
   lw6gui_zone_t drawable;
 }
 _mod_gl_utils_smoothed_t;
@@ -367,6 +385,7 @@ typedef struct mod_gl_utils_context_s
   mod_gl_utils_mem_counter_t texture_counter;
   mod_gl_utils_caps_t caps;
   lw6gui_video_mode_t video_mode;
+  lw6gui_zone_t viewport;
   mod_gl_utils_render_param_t render_param;
   mod_gl_utils_texture_data_t texture_data;
   mod_gl_utils_font_data_t font_data;
@@ -383,6 +402,7 @@ typedef struct mod_gl_utils_context_s
   _mod_gl_utils_smoothed_t smoothed;
   mod_gl_utils_icon_t icon;
   mod_gl_utils_counter_t counter;
+  lw6sys_hash_t *bitmap_hash;
 }
 mod_gl_utils_context_t;
 
@@ -391,13 +411,14 @@ mod_gl_utils_context_t;
  */
 extern mod_gl_utils_bitmap_t *mod_gl_utils_bitmap_new (mod_gl_utils_context_t
 						       * utils_context,
-						       int width, int height);
+						       int width, int height,
+						       char *desc);
 extern mod_gl_utils_bitmap_t *mod_gl_utils_bitmap_load (mod_gl_utils_context_t
 							* utils_context,
 							char *filename);
 extern mod_gl_utils_bitmap_t
   * mod_gl_utils_surface2bitmap (mod_gl_utils_context_t * utils_context,
-				 SDL_Surface * surface);
+				 SDL_Surface * surface, char *desc);
 extern void mod_gl_utils_bitmap_free (mod_gl_utils_context_t * utils_context,
 				      mod_gl_utils_bitmap_t * bitmap);
 extern int mod_gl_utils_bitmap_colorize (mod_gl_utils_context_t *
@@ -429,9 +450,12 @@ extern void mod_gl_utils_bitmap_clear_texture_now (mod_gl_utils_context_t *
 extern int mod_gl_utils_bitmap_refresh (mod_gl_utils_context_t *
 					utils_context,
 					mod_gl_utils_bitmap_t * bitmap);
-extern int mod_gl_utils_bitmap_force_refresh (mod_gl_utils_context_t *
+extern int mod_gl_utils_bitmap_refresh_force (mod_gl_utils_context_t *
 					      utils_context,
 					      mod_gl_utils_bitmap_t * bitmap);
+extern void mod_gl_utils_bitmap_bind_no_gen (mod_gl_utils_context_t *
+					     utils_context,
+					     mod_gl_utils_bitmap_t * bitmap);
 extern int mod_gl_utils_bitmap_bind (mod_gl_utils_context_t * utils_context,
 				     mod_gl_utils_bitmap_t * bitmap);
 extern int mod_gl_utils_bitmap_display (mod_gl_utils_context_t *
@@ -451,19 +475,25 @@ extern int mod_gl_utils_bitmap_array_init (mod_gl_utils_context_t *
 					   utils_context,
 					   mod_gl_utils_bitmap_array_t *
 					   bitmap_array, int w, int h,
-					   int tile_size);
+					   int tile_size, int border_size);
 extern int mod_gl_utils_bitmap_array_init_from_surface (mod_gl_utils_context_t
 							* utils_context,
 							mod_gl_utils_bitmap_array_t
 							* bitmap_array,
 							SDL_Surface * surface,
-							int tile_size);
+							int tile_size,
+							int border_size,
+							int x_polarity,
+							int y_polarity);
 extern int mod_gl_utils_bitmap_array_init_from_map (mod_gl_utils_context_t *
 						    utils_context,
 						    mod_gl_utils_bitmap_array_t
 						    * bitmap_array,
 						    lw6map_level_t * level,
-						    int tile_size);
+						    int tile_size,
+						    int border_size,
+						    int x_polarity,
+						    int y_polarity);
 extern int mod_gl_utils_bitmap_array_update (mod_gl_utils_context_t *
 					     utils_context,
 					     mod_gl_utils_bitmap_array_t *
@@ -474,11 +504,28 @@ extern void mod_gl_utils_bitmap_array_clear (mod_gl_utils_context_t *
 					     mod_gl_utils_bitmap_array_t *
 					     bitmap_array);
 extern int mod_gl_utils_bitmap_array_set (mod_gl_utils_bitmap_array_t *
-					  bitmap_array, int n_x, int n_y,
+					  bitmap_array, int i,
 					  mod_gl_utils_bitmap_t * bitmap);
 extern mod_gl_utils_bitmap_t
   * mod_gl_utils_bitmap_array_get (mod_gl_utils_bitmap_array_t * bitmap_array,
-				   int n_x, int n_y);
+				   int i);
+
+/*
+ * In bitmaphash.c
+ */
+extern lw6sys_hash_t *mod_gl_utils_bitmap_hash_init ();
+extern void mod_gl_utils_bitmap_hash_quit (lw6sys_hash_t * bitmap_hash);
+extern int mod_gl_utils_bitmap_hash_register (mod_gl_utils_context_t *
+					      utils_context,
+					      mod_gl_utils_bitmap_t * bitmap);
+extern int mod_gl_utils_bitmap_hash_unregister (mod_gl_utils_context_t *
+						utils_context,
+						mod_gl_utils_bitmap_t *
+						bitmap);
+extern int mod_gl_utils_bitmap_hash_refresh (mod_gl_utils_context_t *
+					     utils_context);
+extern int mod_gl_utils_bitmap_hash_dump2disk (mod_gl_utils_context_t *
+					       utils_context, int force);
 
 /*
  * In capture.c
@@ -572,6 +619,16 @@ extern void mod_gl_utils_display_gradient (mod_gl_utils_context_t *
 /*
  * In display.c
  */
+extern void mod_gl_utils_display_quad_begin (mod_gl_utils_context_t *
+					     utils_context);
+extern void mod_gl_utils_display_quad_end (mod_gl_utils_context_t *
+					   utils_context);
+extern void mod_gl_utils_display_quad_do (mod_gl_utils_context_t *
+					  utils_context, GLuint texture,
+					  float x1, float y1, float x2,
+					  float y2, float texture_x1,
+					  float texture_y1, float texture_x2,
+					  float texture_y2);
 extern void mod_gl_utils_display_texture_full (mod_gl_utils_context_t *
 					       utils_context, GLuint texture,
 					       float x1, float y1, float x2,
@@ -716,8 +773,8 @@ extern int mod_gl_utils_store_button_in_menucache (mod_gl_utils_context_t *
 						   mod_gl_utils_bitmap_t *
 						   bitmap);
 extern mod_gl_utils_bitmap_t
-  * mod_gl_utils_get_button_from_menucache (mod_gl_utils_context_t * context,
-					    lw6gui_look_t * look,
+  * mod_gl_utils_get_button_from_menucache (mod_gl_utils_context_t *
+					    context, lw6gui_look_t * look,
 					    lw6gui_menuitem_t * menuitem);
 extern void mod_gl_utils_clear_menucache (mod_gl_utils_context_t *
 					  utils_context);
@@ -756,6 +813,7 @@ extern void mod_gl_utils_show_mouse (mod_gl_utils_context_t * utils_context,
  */
 extern int mod_gl_utils_path_init (mod_gl_utils_context_t *
 				   utils_context, int argc, char *argv[]);
+extern int mod_gl_utils_path_update (mod_gl_utils_context_t * utils_context);
 extern void mod_gl_utils_path_quit (mod_gl_utils_context_t * utils_context);
 
 /*
@@ -772,19 +830,6 @@ mod_gl_utils_putpixel_4_bytes_per_pixel (SDL_Surface * surface, int x, int y,
 		(x << 2))) = pixel;
 }
 
-/*
- * In rectarray.c
- */
-extern int mod_gl_utils_rect_array_init (mod_gl_utils_context_t *
-					 utils_context,
-					 mod_gl_utils_rect_array_t *
-					 rect_array, int w, int h,
-					 int tile_size);
-extern void mod_gl_utils_rect_array_clear (mod_gl_utils_context_t *
-					   utils_context,
-					   mod_gl_utils_rect_array_t *
-					   rect_array);
-
 /*
  * In render.c
  */
@@ -800,9 +845,11 @@ extern void mod_gl_utils_set_render_mode_3d_map (mod_gl_utils_context_t *
 						 utils_context);
 extern void mod_gl_utils_set_render_mode_3d_menu (mod_gl_utils_context_t *
 						  utils_context);
-extern void mod_gl_utils_set_render_mode_3d_pick (mod_gl_utils_context_t *
-						  utils_context, int x,
-						  int y);
+extern void mod_gl_utils_set_render_mode_3d_select (mod_gl_utils_context_t *
+						    utils_context, int x,
+						    int y);
+extern void mod_gl_utils_set_render_mode_3d_feedback (mod_gl_utils_context_t *
+						      utils_context);
 
 /*
  * In resolution.c
@@ -878,8 +925,6 @@ extern SDL_Surface *mod_gl_utils_map2surface (mod_gl_utils_context_t *
 /*
  * In texture.c
  */
-extern int mod_gl_utils_power_of_two_le (int size);
-extern int mod_gl_utils_power_of_two_ge (int size);
 extern float mod_gl_utils_texture_scale (int size);
 extern GLuint mod_gl_utils_surface2texture_xywh (mod_gl_utils_context_t *
 						 utils_context,
