@@ -65,6 +65,7 @@
 #define TEST_LABEL "fake A letter"
 #define TEST_REPEAT_DELAY 100
 #define TEST_REPEAT_INTERVAL 10
+#define TEST_REPEAT_DOUBLE_CLICK_DELAY 250
 #define TEST_MOUSE_X 12
 #define TEST_MOUSE_Y 34
 #define TEST_JOYSTICK_LIMIT 20
@@ -80,6 +81,29 @@
 #define TEST_SRC_Y0 20.0
 #define TEST_SRC_W 100.0
 #define TEST_SRC_H 50.0
+#define TEST_RECT1_X1 3.0f
+#define TEST_RECT1_Y1 2.0f
+#define TEST_RECT1_X2 30.0f
+#define TEST_RECT1_Y2 20.0f
+#define TEST_RECT2_X -1.0f
+#define TEST_RECT2_Y -1.0f
+#define TEST_RECT2_W 10.0f
+#define TEST_RECT2_H 10.0f
+#define TEST_RECT_ARRAY_W 1333
+#define TEST_RECT_ARRAY_H 666
+#define TEST_RECT_ARRAY_TILE_SIZE 123
+#define TEST_RECT_ARRAY_BORDER_SIZE 7
+#define TEST_RECT_ARRAY_SOURCE_X 500
+#define TEST_RECT_ARRAY_SOURCE_Y 250
+#define TEST_RECT_ARRAY_TILE_I 19
+#define TEST_RECT_ARRAY_QUAD_P1X -10.0f
+#define TEST_RECT_ARRAY_QUAD_P1Y -5.0f
+#define TEST_RECT_ARRAY_QUAD_P2X 1.0f
+#define TEST_RECT_ARRAY_QUAD_P2Y -4.0f
+#define TEST_RECT_ARRAY_QUAD_P3X -8.0f
+#define TEST_RECT_ARRAY_QUAD_P3Y 2.0f
+#define TEST_RECT_ARRAY_QUAD_P4X -1.0f
+#define TEST_RECT_ARRAY_QUAD_P4Y 3.0f
 #define TEST_ZONE1_X1 3.0f
 #define TEST_ZONE1_Y1 2.0f
 #define TEST_ZONE1_X2 30.0f
@@ -88,6 +112,7 @@
 #define TEST_ZONE2_Y -1.0f
 #define TEST_ZONE2_W 10.0f
 #define TEST_ZONE2_H 10.0f
+#define TEST_POWER_OF_TWO 37
 #define TEST_VIEWPORT_SCREEN_W 800
 #define TEST_VIEWPORT_SCREEN_H 600
 #define TEST_VIEWPORT_DRAWABLE_X1 5
@@ -103,6 +128,8 @@
 #define TEST_VIEWPORT_X_WRAP 1
 #define TEST_VIEWPORT_Y_WRAP 1
 #define TEST_VIEWPORT_KEEP_RATIO 1
+#define TEST_VIEWPORT_SCROLL_LIMIT 0.5f
+#define TEST_VIEWPORT_USE_OLD_CENTER 0
 #define TEST_VIEWPORT_GLOBAL_ZOOM_MIN 0.1f
 #define TEST_VIEWPORT_GLOBAL_ZOOM_MAX 10.0f
 #define TEST_VIEWPORT_GLOBAL_ZOOM_STEP 9.9f
@@ -116,6 +143,14 @@
 #define TEST_SMOOTHER_VALUE2 100.0f
 #define TEST_SMOOTHER_VALUE3 -1000.0f
 #define TEST_SMOOTHER_VALUE4 421.0f
+#define TEST_SMOOTHER_STEP 100
+#define TEST_TIMESTAMP 1000000000000LL
+#define TEST_GEOMETRY_POINT_MIN 1
+#define TEST_GEOMETRY_POINT_RANGE 10
+#define TEST_GEOMETRY_RECT_X1 2
+#define TEST_GEOMETRY_RECT_Y1 6
+#define TEST_GEOMETRY_RECT_X2 5
+#define TEST_GEOMETRY_RECT_Y2 9
 
 /*
  * Testing button
@@ -127,21 +162,28 @@ test_button ()
   LW6SYS_TEST_FUNCTION_BEGIN;
 
   {
-    int ticks = 0;
+    u_int64_t timestamp = TEST_TIMESTAMP;
     lw6gui_button_t button;
+    lw6gui_repeat_settings_t repeat_settings;
+
+    repeat_settings.delay = TEST_REPEAT_DELAY;
+    repeat_settings.interval = TEST_REPEAT_INTERVAL;
+    repeat_settings.double_click_delay = TEST_REPEAT_DOUBLE_CLICK_DELAY;
 
     memset (&button, 0, sizeof (lw6gui_button_t));
 
-    lw6gui_button_register_down (&button, ticks++);
+    lw6gui_button_register_down (&button, timestamp++);
     lw6gui_button_register_up (&button);
     if (!lw6gui_button_is_pressed (&button))
       {
 	if (lw6gui_button_pop_press (&button))
 	  {
-	    // ok
+	    lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("button press buffer works"));
 	  }
 	else
 	  {
+	    lw6sys_log (LW6SYS_LOG_WARNING,
+			_x_ ("button press buffer problem"));
 	    ret = 0;
 	  }
       }
@@ -149,6 +191,45 @@ test_button ()
       {
 	ret = 0;
       }
+    if (ret)
+      {
+	ret = 0;
+	lw6gui_button_update_repeat (&button, &repeat_settings, timestamp);
+	if (!lw6gui_button_pop_double_click (&button)
+	    && !lw6gui_button_pop_triple_click (&button))
+	  {
+	    lw6gui_button_register_down (&button, timestamp++);
+	    lw6gui_button_update_repeat (&button, &repeat_settings,
+					 timestamp);
+	    timestamp += 2 * TEST_REPEAT_DOUBLE_CLICK_DELAY;
+	    lw6gui_button_update_repeat (&button, &repeat_settings,
+					 timestamp);
+	    if (lw6gui_button_pop_double_click (&button))
+	      {
+		if (!lw6gui_button_pop_double_click (&button))
+		  {
+		    timestamp += 2 * TEST_REPEAT_DOUBLE_CLICK_DELAY;
+		    lw6gui_button_register_down (&button, timestamp);
+		    lw6gui_button_update_repeat (&button, &repeat_settings,
+						 timestamp);
+		    timestamp += 2 * TEST_REPEAT_DOUBLE_CLICK_DELAY;
+		    lw6gui_button_register_down (&button, timestamp);
+		    lw6gui_button_update_repeat (&button, &repeat_settings,
+						 timestamp);
+		    if (!lw6gui_button_pop_double_click (&button))
+		      {
+			lw6sys_log (LW6SYS_LOG_NOTICE,
+				    _x_ ("double click works"));
+			ret = 1;
+		      }
+		  }
+	      }
+	  }
+	if (!ret)
+	  {
+	    lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("double click problem"));
+	  }
+      }
   }
 
   LW6SYS_TEST_FUNCTION_END;
@@ -219,6 +300,8 @@ test_input ()
 	      {
 		repeat_settings.delay = TEST_REPEAT_DELAY;
 		repeat_settings.interval = TEST_REPEAT_INTERVAL;
+		repeat_settings.double_click_delay =
+		  TEST_REPEAT_DOUBLE_CLICK_DELAY;
 		lw6gui_input_update_repeat (src, &repeat_settings, 0);
 		lw6sys_log (LW6SYS_LOG_NOTICE,
 			    _x_ ("need_sync (before sync) dst=%d src=%d"),
@@ -808,10 +891,15 @@ test_mouse ()
   {
     lw6gui_mouse_t mouse;
     int x = 0, y = 0;
+    int dx = 0, dy = 0, px = 0, py = 0, sx = 0, sy = 0;
 
     memset (&mouse, 0, sizeof (lw6gui_mouse_t));
 
     lw6gui_mouse_register_move (&mouse, TEST_MOUSE_X, TEST_MOUSE_Y, 0);
+    lw6gui_mouse_drag_begin (&mouse);
+    lw6gui_mouse_drag_end (&mouse);
+    lw6gui_mouse_drag_pop (&mouse, &dx, &dy, &px, &py, &sx, &sy);
+
     if (lw6gui_mouse_poll_move (&mouse, &x, &y))
       {
 	if (x == TEST_MOUSE_X && y == TEST_MOUSE_Y)
@@ -834,6 +922,173 @@ test_mouse ()
   return ret;
 }
 
+static void
+log_rect (lw6gui_rect_t * rect, char *comment)
+{
+  lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("%s x1=%d y1=%d x2=%d y2=%d w=%d h=%d"),
+	      comment, rect->x1, rect->y1, rect->x2, rect->y2, rect->w,
+	      rect->h);
+}
+
+/*
+ * Testing poweroftwo
+ */
+static int
+test_power_of_two ()
+{
+  int ret = 1;
+  LW6SYS_TEST_FUNCTION_BEGIN;
+
+  {
+    lw6sys_log (LW6SYS_LOG_NOTICE,
+		_x_ ("input=%d power_of_two_le=%d power_of_two_ge=%d"),
+		TEST_POWER_OF_TWO, lw6gui_power_of_two_le (TEST_POWER_OF_TWO),
+		lw6gui_power_of_two_ge (TEST_POWER_OF_TWO));
+  }
+  LW6SYS_TEST_FUNCTION_END;
+  return ret;
+}
+
+/*
+ * Testing rect
+ */
+static int
+test_rect ()
+{
+  int ret = 1;
+  LW6SYS_TEST_FUNCTION_BEGIN;
+
+  {
+    lw6gui_rect_t rect1;
+    lw6gui_rect_t rect2;
+    lw6gui_rect_t rect3;
+
+    lw6gui_rect_init_x1y1x2y2 (&rect1, TEST_RECT1_X1, TEST_RECT1_Y1,
+			       TEST_RECT1_X2, TEST_RECT1_Y2);
+    log_rect (&rect1, _x_ ("rect1"));
+    lw6gui_rect_init_x1y1x2y2 (&rect1, TEST_RECT2_X, TEST_RECT2_Y,
+			       TEST_RECT2_W, TEST_RECT2_H);
+    log_rect (&rect2, _x_ ("rect2"));
+    lw6gui_rect_clip (&rect3, &rect1, &rect2);
+    log_rect (&rect3, _x_ ("rect3"));
+  }
+  LW6SYS_TEST_FUNCTION_END;
+  return ret;
+}
+
+/*
+ * Testing rect array
+ */
+static int
+test_rect_array ()
+{
+  int ret = 1;
+  LW6SYS_TEST_FUNCTION_BEGIN;
+
+  {
+    lw6gui_rect_array_t rect_array;
+    lw6gui_rect_t rect;
+    int i = 0;
+    int x_polarity, y_polarity;
+    lw6gui_quad_t quad;
+    lw6gui_quad_t source_quad;
+
+    lw6gui_rect_array_init (&rect_array, TEST_RECT_ARRAY_W, TEST_RECT_ARRAY_H,
+			    TEST_RECT_ARRAY_TILE_SIZE,
+			    TEST_RECT_ARRAY_BORDER_SIZE);
+    lw6sys_log (LW6SYS_LOG_NOTICE,
+		_x_
+		("rect_array source=%dx%d limits=(%d,%d),(%d,%d) tile_size=%d border_size=%d tile_spacing=%d nb_tiles_w=%d nb_tiles_h=%d nb_tiles=%d"),
+		rect_array.source.w, rect_array.source.h,
+		rect_array.limits.x1, rect_array.limits.y1,
+		rect_array.limits.x2, rect_array.limits.y2,
+		rect_array.tile_size, rect_array.border_size,
+		rect_array.tile_spacing, rect_array.nb_tiles_w,
+		rect_array.nb_tiles_h, rect_array.nb_tiles);
+    if (lw6gui_rect_array_get_tile_by_source_xy
+	(&rect_array, &rect, &i, TEST_RECT_ARRAY_SOURCE_X,
+	 TEST_RECT_ARRAY_SOURCE_Y))
+      {
+	lw6sys_log (LW6SYS_LOG_NOTICE,
+		    _x_
+		    ("tile for source %d,%d is index %d corners=(%d,%d),(%d,%d)"),
+		    TEST_RECT_ARRAY_SOURCE_X, TEST_RECT_ARRAY_SOURCE_Y, i,
+		    rect.x1, rect.y1, rect.x2, rect.y2);
+	if (lw6gui_rect_array_get_tile_by_i
+	    (&rect_array, &rect, TEST_RECT_ARRAY_TILE_I))
+	  {
+	    lw6sys_log (LW6SYS_LOG_NOTICE,
+			_x_ ("tile i=%d corners=(%d,%d),(%d,%d)"),
+			TEST_RECT_ARRAY_TILE_I, rect.x1, rect.y1, rect.x2,
+			rect.y2);
+	    source_quad.p1.x = TEST_RECT_ARRAY_QUAD_P1X;
+	    source_quad.p1.y = TEST_RECT_ARRAY_QUAD_P1Y;
+	    source_quad.p2.x = TEST_RECT_ARRAY_QUAD_P2X;
+	    source_quad.p2.y = TEST_RECT_ARRAY_QUAD_P2Y;
+	    source_quad.p3.x = TEST_RECT_ARRAY_QUAD_P3X;
+	    source_quad.p3.y = TEST_RECT_ARRAY_QUAD_P3Y;
+	    source_quad.p4.x = TEST_RECT_ARRAY_QUAD_P4X;
+	    source_quad.p4.y = TEST_RECT_ARRAY_QUAD_P4Y;
+	    for (y_polarity = LW6MAP_RULES_MIN_Y_POLARITY;
+		 y_polarity <= LW6MAP_RULES_MAX_Y_POLARITY; ++y_polarity)
+	      {
+		for (x_polarity = LW6MAP_RULES_MIN_X_POLARITY;
+		     x_polarity <= LW6MAP_RULES_MAX_X_POLARITY; ++x_polarity)
+		  {
+		    if (lw6gui_rect_array_get_tile_and_quad
+			(&rect_array, &rect, &i, &quad, &source_quad,
+			 x_polarity, y_polarity))
+		      {
+			lw6sys_log (LW6SYS_LOG_NOTICE,
+				    _x_
+				    ("polarity x=%d y=%d tile corners=(%d,%d),(%d,%d) quad=(%f,%f),(%f,%f),(%f,%f),(%f,%f)"),
+				    x_polarity, y_polarity, rect.x1, rect.y1,
+				    rect.x2, rect.y2, quad.p1.x, quad.p1.y,
+				    quad.p2.x, quad.p2.y, quad.p3.x,
+				    quad.p3.y, quad.p4.x, quad.p4.y);
+		      }
+		    else
+		      {
+			ret = 0;
+		      }
+		  }
+	      }
+	  }
+	else
+	  {
+	    lw6sys_log (LW6SYS_LOG_WARNING,
+			_x_ ("unable to find tile for i=%d"),
+			TEST_RECT_ARRAY_TILE_I);
+	    ret = 0;
+	  }
+      }
+    else
+      {
+	lw6sys_log (LW6SYS_LOG_WARNING,
+		    _x_ ("unable to find tile for source %d,%d"),
+		    TEST_RECT_ARRAY_SOURCE_X, TEST_RECT_ARRAY_SOURCE_Y);
+	ret = 0;
+      }
+    /*
+       #define TEST_RECT_ARRAY_SOURCE_X 500
+       #define TEST_RECT_ARRAY_SOURCE_Y 250
+       #define TEST_RECT_ARRAY_TILE_I 19
+       #define TEST_RECT_ARRAY_QUAD_P1X 2000.0f
+       #define TEST_RECT_ARRAY_QUAD_P1Y 3000.0f
+       #define TEST_RECT_ARRAY_QUAD_P2X 2100.0f
+       #define TEST_RECT_ARRAY_QUAD_P2Y 3100.0f
+       #define TEST_RECT_ARRAY_QUAD_P3X 2050.0f
+       #define TEST_RECT_ARRAY_QUAD_P3Y 3100.0f
+       #define TEST_RECT_ARRAY_QUAD_P4X 2050.0f
+       #define TEST_RECT_ARRAY_QUAD_P4Y 2100.0f
+       #define TEST_RECT_ARRAY_X_POLARITY -1
+       #define TEST_RECT_ARRAY_Y_POLARITY 1
+     */
+  }
+  LW6SYS_TEST_FUNCTION_END;
+  return ret;
+}
+
 /*
  * Testing video more
  */
@@ -873,6 +1128,7 @@ test_smoother ()
 					       lw6sys_get_timestamp ()));
 	lw6sys_delay (TEST_SMOOTHER_DELAY);
       }
+    lw6gui_smoother_fix_overflow (&smoother, TEST_SMOOTHER_STEP);
   }
   LW6SYS_TEST_FUNCTION_END;
   return ret;
@@ -1021,7 +1277,9 @@ test_viewport ()
 			      TEST_VIEWPORT_Y_POLARITY,
 			      TEST_VIEWPORT_X_WRAP,
 			      TEST_VIEWPORT_Y_WRAP,
-			      TEST_VIEWPORT_KEEP_RATIO, global_zoom);
+			      TEST_VIEWPORT_KEEP_RATIO, global_zoom,
+			      TEST_VIEWPORT_SCROLL_LIMIT,
+			      TEST_VIEWPORT_USE_OLD_CENTER);
 	log_zone (&viewport.drawable, _x_ ("drawable"));
 	log_zone (&viewport.map_main, _x_ ("map_main"));
 	log_zone (&viewport.map_main_clipped, _x_ ("map_main_clipped"));
@@ -1047,6 +1305,8 @@ test_viewport ()
 			_x_ ("screen ( %f , %f ) -> map ( %f , %f )"),
 			screen_x, screen_y, map_x, map_y);
 	  }
+	lw6gui_viewport_calc_drag (&viewport, &map_x, &map_y, map_x, map_y,
+				   screen_x, screen_y);
       }
   }
   LW6SYS_TEST_FUNCTION_END;
@@ -1080,6 +1340,79 @@ test_zone ()
   return ret;
 }
 
+/*
+ * Testing point, segment, triangle, quad
+ */
+static int
+test_geometry ()
+{
+  int ret = 1;
+  LW6SYS_TEST_FUNCTION_BEGIN;
+
+  {
+    lw6gui_point_t point;
+    lw6gui_segment_t segment;
+    lw6gui_triangle_t triangle;
+    lw6gui_quad_t quad;
+    lw6gui_rect_t rect;
+
+    point.x =
+      TEST_GEOMETRY_POINT_MIN + lw6sys_random (TEST_GEOMETRY_POINT_RANGE);
+    point.y =
+      TEST_GEOMETRY_POINT_MIN + lw6sys_random (TEST_GEOMETRY_POINT_RANGE);
+    segment.p1.x =
+      TEST_GEOMETRY_POINT_MIN + lw6sys_random (TEST_GEOMETRY_POINT_RANGE);
+    segment.p1.y =
+      TEST_GEOMETRY_POINT_MIN + lw6sys_random (TEST_GEOMETRY_POINT_RANGE);
+    segment.p2.x =
+      TEST_GEOMETRY_POINT_MIN + lw6sys_random (TEST_GEOMETRY_POINT_RANGE);
+    segment.p2.y =
+      TEST_GEOMETRY_POINT_MIN + lw6sys_random (TEST_GEOMETRY_POINT_RANGE);
+    triangle.p1.x =
+      TEST_GEOMETRY_POINT_MIN + lw6sys_random (TEST_GEOMETRY_POINT_RANGE);
+    triangle.p1.y =
+      TEST_GEOMETRY_POINT_MIN + lw6sys_random (TEST_GEOMETRY_POINT_RANGE);
+    triangle.p2.x =
+      TEST_GEOMETRY_POINT_MIN + lw6sys_random (TEST_GEOMETRY_POINT_RANGE);
+    triangle.p2.y =
+      TEST_GEOMETRY_POINT_MIN + lw6sys_random (TEST_GEOMETRY_POINT_RANGE);
+    triangle.p3.x =
+      TEST_GEOMETRY_POINT_MIN + lw6sys_random (TEST_GEOMETRY_POINT_RANGE);
+    triangle.p3.y =
+      TEST_GEOMETRY_POINT_MIN + lw6sys_random (TEST_GEOMETRY_POINT_RANGE);
+    quad.p1.x =
+      TEST_GEOMETRY_POINT_MIN + lw6sys_random (TEST_GEOMETRY_POINT_RANGE);
+    quad.p1.y =
+      TEST_GEOMETRY_POINT_MIN + lw6sys_random (TEST_GEOMETRY_POINT_RANGE);
+    quad.p2.x =
+      TEST_GEOMETRY_POINT_MIN + lw6sys_random (TEST_GEOMETRY_POINT_RANGE);
+    quad.p2.y =
+      TEST_GEOMETRY_POINT_MIN + lw6sys_random (TEST_GEOMETRY_POINT_RANGE);
+    quad.p3.x =
+      TEST_GEOMETRY_POINT_MIN + lw6sys_random (TEST_GEOMETRY_POINT_RANGE);
+    quad.p3.y =
+      TEST_GEOMETRY_POINT_MIN + lw6sys_random (TEST_GEOMETRY_POINT_RANGE);
+    quad.p4.x =
+      TEST_GEOMETRY_POINT_MIN + lw6sys_random (TEST_GEOMETRY_POINT_RANGE);
+    quad.p4.y =
+      TEST_GEOMETRY_POINT_MIN + lw6sys_random (TEST_GEOMETRY_POINT_RANGE);
+    lw6gui_rect_init_x1y1x2y2 (&rect, TEST_GEOMETRY_RECT_X1,
+			       TEST_GEOMETRY_RECT_Y1, TEST_GEOMETRY_RECT_X2,
+			       TEST_GEOMETRY_RECT_Y2);
+
+    lw6sys_log (LW6SYS_LOG_NOTICE,
+		_x_
+		("point_is_inside=%d segment_is_inside=%d triangle_is_inside=%d quad_is_inside=%d"),
+		lw6gui_point_is_inside_rect (point, &rect),
+		lw6gui_segment_is_inside_rect (&segment, &rect),
+		lw6gui_triangle_is_inside_rect (&triangle, &rect),
+		lw6gui_quad_is_inside_rect (&quad, &rect));
+  }
+
+  LW6SYS_TEST_FUNCTION_END;
+  return ret;
+}
+
 /**
  * lw6gui_test
  *
@@ -1103,14 +1436,14 @@ lw6gui_test (int mode)
       lw6hlp_test (mode);
       lw6cfg_test (mode);
       lw6map_test (mode);
-      lw6ldr_test (mode);
     }
 
   ret = test_button () && test_coord () && test_input () && test_joystick ()
     && test_keyboard () && test_keypress ()
     && test_look () && test_menuitem () && test_menu () && test_mouse ()
+    && test_power_of_two () && test_rect () && test_rect_array ()
     && test_smoother () && test_video_mode () && test_viewport ()
-    && test_zone ();
+    && test_zone () && test_geometry ();
 
   return ret;
 }
