@@ -27,13 +27,18 @@
 #include "../cfg/cfg.h"
 #include "../sys/sys.h"
 #include "../map/map.h"
-#include "../ldr/ldr.h"
 
 #define LW6GUI_NB_KEYS 512
 #define LW6GUI_NB_JOYSTICKS 2
 #define LW6GUI_JOYSTICK1_ID 0
 #define LW6GUI_JOYSTICK2_ID 1
-#define LW6GUI_NB_JOYSTICK_BUTTONS 4
+#define LW6GUI_NB_JOYSTICK_BUTTONS 6
+#define LW6GUI_JOYSTICK_BUTTON_ID_A 0
+#define LW6GUI_JOYSTICK_BUTTON_ID_B 1
+#define LW6GUI_JOYSTICK_BUTTON_ID_C 2
+#define LW6GUI_JOYSTICK_BUTTON_ID_D 3
+#define LW6GUI_JOYSTICK_BUTTON_ID_E 4
+#define LW6GUI_JOYSTICK_BUTTON_ID_F 5
 
 #define LW6GUI_DEFAULT_LOW_WIDTH 320
 #define LW6GUI_DEFAULT_LOW_HEIGHT 200
@@ -71,6 +76,11 @@
 #define LW6GUI_GFX_QUALITY_STANDARD 1
 #define LW6GUI_GFX_QUALITY_HIGH     2
 
+#define LW6GUI_MIN_TILE_SIZE 16
+#define LW6GUI_MAX_TILE_SIZE 4096
+#define LW6GUI_MIN_BORDER_SIZE 1
+#define LW6GUI_MAX_BORDER_SIZE 256
+
 typedef struct lw6gui_video_mode_s
 {
   int width;
@@ -90,6 +100,7 @@ typedef struct lw6gui_repeat_settings_s
 {
   int delay;
   int interval;
+  int double_click_delay;
 } lw6gui_repeat_settings_t;
 
 typedef void (*lw6gui_resize_callback_func_t) (lw6gui_video_mode_t *
@@ -125,19 +136,27 @@ typedef struct lw6gui_button_s
 {
   int is_pressed;
   int press_queue;
+  int simple_click_queue;
+  int double_click_queue;
+  int triple_click_queue;
   int64_t last_press;
   int64_t last_repeat;
+  int64_t double_click_t1;
+  int64_t double_click_t2;
+  int64_t double_click_t3;
 }
 lw6gui_button_t;
 
 typedef struct lw6gui_keyboard_s
 {
-  lw6gui_button_t key_up;
-  lw6gui_button_t key_down;
-  lw6gui_button_t key_left;
-  lw6gui_button_t key_right;
+  lw6gui_button_t arrow_up;
+  lw6gui_button_t arrow_down;
+  lw6gui_button_t arrow_left;
+  lw6gui_button_t arrow_right;
   lw6gui_button_t key_enter;
   lw6gui_button_t key_esc;
+  lw6gui_button_t key_ctrl;
+  lw6gui_button_t key_alt;
   lw6gui_button_t key_pgup;
   lw6gui_button_t key_pgdown;
   lw6sys_list_t *queue;
@@ -145,19 +164,37 @@ typedef struct lw6gui_keyboard_s
 }
 lw6gui_keyboard_t;
 
+typedef enum lw6gui_drag_mode_e
+{
+  LW6GUI_DRAG_MODE_OFF = 0,
+  LW6GUI_DRAG_MODE_ON = 1,
+  LW6GUI_DRAG_MODE_DONE = 2
+}
+lw6gui_drag_mode_t;
+
+typedef struct lw6gui_mouse_pointer_s
+{
+  int pos_x;
+  int pos_y;
+  int speed_x;
+  int speed_y;
+}
+lw6gui_mouse_pointer_t;
+
 typedef struct lw6gui_mouse_s
 {
-  int x;
-  int y;
   int moved;
   int64_t last_moved;
-  int map_x;
-  int map_y;
+  lw6gui_mouse_pointer_t screen_pointer;
+  lw6gui_mouse_pointer_t map_pointer;
+  lw6gui_mouse_pointer_t screen_drag_start;
+  lw6gui_drag_mode_t drag_mode;
   int menu_position;
   int menu_scroll;
   int menu_esc;
   lw6gui_button_t button_left;
   lw6gui_button_t button_right;
+  lw6gui_button_t button_middle;
   lw6gui_button_t wheel_up;
   lw6gui_button_t wheel_down;
 }
@@ -165,14 +202,16 @@ lw6gui_mouse_t;
 
 typedef struct lw6gui_joystick_s
 {
-  lw6gui_button_t button_up;
-  lw6gui_button_t button_down;
-  lw6gui_button_t button_left;
-  lw6gui_button_t button_right;
+  lw6gui_button_t pad_up;
+  lw6gui_button_t pad_down;
+  lw6gui_button_t pad_left;
+  lw6gui_button_t pad_right;
   lw6gui_button_t button_a;
   lw6gui_button_t button_b;
   lw6gui_button_t button_c;
   lw6gui_button_t button_d;
+  lw6gui_button_t button_e;
+  lw6gui_button_t button_f;
 }
 lw6gui_joystick_t;
 
@@ -223,6 +262,59 @@ typedef struct lw6gui_smoother_s
   int duration;
 } lw6gui_smoother_t;
 
+typedef struct lw6gui_rect_s
+{
+  int x1;
+  int y1;
+  int x2;
+  int y2;
+  int w;
+  int h;
+}
+lw6gui_rect_t;
+
+typedef struct lw6gui_rect_array_s
+{
+  lw6sys_whd_t source;
+  lw6gui_rect_t limits;
+  int tile_size;
+  int border_size;
+  int tile_spacing;
+  int nb_tiles_w;
+  int nb_tiles_h;
+  int nb_tiles;
+}
+lw6gui_rect_array_t;
+
+typedef struct lw6gui_point_s
+{
+  float x;
+  float y;
+  float z;
+} lw6gui_point_t;
+
+typedef struct lw6gui_segment_s
+{
+  lw6gui_point_t p1;
+  lw6gui_point_t p2;
+}
+lw6gui_segment_t;
+
+typedef struct lw6gui_triangle_s
+{
+  lw6gui_point_t p1;
+  lw6gui_point_t p2;
+  lw6gui_point_t p3;
+} lw6gui_triangle_t;
+
+typedef struct lw6gui_quad_s
+{
+  lw6gui_point_t p1;
+  lw6gui_point_t p2;
+  lw6gui_point_t p3;
+  lw6gui_point_t p4;
+} lw6gui_quad_t;
+
 typedef struct lw6gui_zone_s
 {
   float x1;
@@ -239,6 +331,10 @@ typedef struct lw6gui_viewport_s
   lw6sys_whd_t screen_shape;
   float center_x;
   float center_y;
+  float old_center_x;
+  float old_center_y;
+  float speed_x;
+  float speed_y;
   int x_polarity;
   int y_polarity;
   int x_wrap;
@@ -256,6 +352,9 @@ extern void lw6gui_button_register_down (lw6gui_button_t * button,
 extern void lw6gui_button_register_up (lw6gui_button_t * button);
 extern int lw6gui_button_is_pressed (lw6gui_button_t * button);
 extern int lw6gui_button_pop_press (lw6gui_button_t * button);
+extern int lw6gui_button_pop_simple_click (lw6gui_button_t * button);
+extern int lw6gui_button_pop_double_click (lw6gui_button_t * button);
+extern int lw6gui_button_pop_triple_click (lw6gui_button_t * button);
 extern void lw6gui_button_update_repeat (lw6gui_button_t * button,
 					 lw6gui_repeat_settings_t *
 					 repeat_settings, int64_t timestamp);
@@ -267,6 +366,9 @@ extern int lw6gui_coord_calc_xy (float *dst_x, float *dst_y, float dst_x0,
 				 float src_x, float src_y, float src_x0,
 				 float src_y0, float src_w, float src_h);
 extern int lw6gui_coord_viewport_setup (lw6gui_viewport_t * viewport);
+extern void lw6gui_coords_fix_xy_float (float *x, float *y, int *x_flipped,
+					int *y_flipped, float w, float h,
+					int x_polarity, int y_polarity);
 
 /* gui-input.c */
 extern int lw6gui_input_init (lw6gui_input_t * input);
@@ -412,13 +514,62 @@ extern lw6gui_menu_t *lw6gui_menu_dup (lw6gui_menu_t * menu);
 extern int lw6gui_menu_sync (lw6gui_menu_t * dst, lw6gui_menu_t * src);
 
 /* gui-mouse.c */
-extern void lw6gui_mouse_register_move (lw6gui_mouse_t * mouse, int x, int y,
+extern void lw6gui_mouse_register_move (lw6gui_mouse_t * mouse,
+					int screen_pos_x, int screen_pos_y,
 					int64_t timestamp);
-extern int lw6gui_mouse_poll_move (lw6gui_mouse_t * mouse, int *x, int *y);
+extern int lw6gui_mouse_poll_move (lw6gui_mouse_t * mouse, int *screen_pos_x,
+				   int *screen_pos_y);
 extern void lw6gui_mouse_update_repeat (lw6gui_mouse_t * mouse,
 					lw6gui_repeat_settings_t *
 					repeat_settings, int64_t timestamp);
 extern int lw6gui_mouse_sync (lw6gui_mouse_t * dst, lw6gui_mouse_t * src);
+extern void lw6gui_mouse_drag_begin (lw6gui_mouse_t * mouse);
+extern void lw6gui_mouse_drag_end (lw6gui_mouse_t * mouse);
+extern int lw6gui_mouse_drag_pop (lw6gui_mouse_t * mouse, int *delta_x,
+				  int *delta_y, int *pos_x, int *pos_y,
+				  int *speed_x, int *speed_y);
+
+/* gui-point.c */
+extern int lw6gui_point_is_inside_rect (lw6gui_point_t point,
+					lw6gui_rect_t * rect);
+
+/* gui-poweroftwo.c */
+extern int lw6gui_power_of_two_le (int size);
+extern int lw6gui_power_of_two_ge (int size);
+
+/* gui-quad.c */
+extern int lw6gui_quad_is_inside_rect (lw6gui_quad_t * quad,
+				       lw6gui_rect_t * rect);
+
+/* gui-rect.c */
+extern void lw6gui_rect_init_xywh (lw6gui_rect_t * rect, int x, int y, int w,
+				   int h);
+extern void lw6gui_rect_init_x1y1x2y2 (lw6gui_rect_t * rect, int x1, int y1,
+				       int x2, int y2);
+extern void lw6gui_rect_clip (lw6gui_rect_t * dst, lw6gui_rect_t * src,
+			      lw6gui_rect_t * clip);
+
+/* gui-rectarray.c */
+extern int lw6gui_rect_array_init (lw6gui_rect_array_t * rect_array, int w,
+				   int h, int tile_size, int border_size);
+extern int lw6gui_rect_array_get_tile_by_source_xy (lw6gui_rect_array_t *
+						    rect_array,
+						    lw6gui_rect_t * rect,
+						    int *i, int source_x,
+						    int source_y);
+extern int lw6gui_rect_array_get_tile_by_i (lw6gui_rect_array_t * rect_array,
+					    lw6gui_rect_t * rect, int i);
+extern int lw6gui_rect_array_get_tile_and_quad (lw6gui_rect_array_t *
+						rect_array,
+						lw6gui_rect_t * rect, int *i,
+						lw6gui_quad_t * quad,
+						lw6gui_quad_t * source_quad,
+						int x_polarity,
+						int y_polarity);
+
+/* gui-segment.c */
+extern int lw6gui_segment_is_inside_rect (lw6gui_segment_t * segment,
+					  lw6gui_rect_t * rect);
 
 /* gui-smoother.c */
 extern void lw6gui_smoother_init (lw6gui_smoother_t * smoother, float value,
@@ -429,10 +580,16 @@ extern void lw6gui_smoother_set_target (lw6gui_smoother_t * smoother,
 					float value, int64_t now);
 extern float lw6gui_smoother_get_value (lw6gui_smoother_t * smoother,
 					int64_t now);
+extern void lw6gui_smoother_fix_overflow (lw6gui_smoother_t * smoother,
+					  int step);
 
 /* gui-test.c */
 extern int lw6gui_test (int mode);
 
+/* gui-triangle.c */
+extern int lw6gui_triangle_is_inside_rect (lw6gui_triangle_t * triangle,
+					   lw6gui_rect_t * rect);
+
 /* gui-videomode.c */
 extern int lw6gui_video_mode_find_closest (lw6gui_video_mode_t * closest,
 					   lw6gui_video_mode_t * wished,
@@ -450,7 +607,8 @@ extern int lw6gui_viewport_init (lw6gui_viewport_t * viewport, int screen_w,
 				 float center_y, int map_w, int map_h,
 				 int x_polarity, int y_polarity, int x_wrap,
 				 int y_wrap, int keep_ratio,
-				 float global_zoom);
+				 float global_zoom, float scroll_limit,
+				 int use_old_center);
 extern void lw6gui_viewport_map_to_screen (lw6gui_viewport_t * viewport,
 					   float *screen_x, float *screen_y,
 					   float map_x, float map_y,
@@ -459,6 +617,10 @@ extern void lw6gui_viewport_screen_to_map (lw6gui_viewport_t * viewport,
 					   float *map_x, float *map_y,
 					   float screen_x, float screen_y,
 					   int wrap);
+extern void lw6gui_viewport_calc_drag (lw6gui_viewport_t * viewport,
+				       float *map_dst_x, float *map_dst_y,
+				       float map_src_x, float map_src_y,
+				       int screen_dx, int screen_dy);
 
 /* gui-zone.c */
 extern void lw6gui_zone_init_x1y1x2y2 (lw6gui_zone_t * zone, float x1,
