@@ -77,6 +77,7 @@ update_doc (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_LIST_MAP_RULES);
   lw6sys_list_push_back (list, LW6DEF_LIST_MAP_HINTS);
   lw6sys_list_push_back (list, LW6DEF_LIST_MAP_STYLE);
+  lw6sys_list_push_back (list, LW6DEF_LIST_MAP_TEAMS);
   lw6sys_list_push_back (list, LW6DEF_LIST_FUNCS);
   lw6sys_list_push_back (list, LW6DEF_LIST_HOOKS);
   lw6sys_list_push_back (list, LW6DEF_LIST_ADVANCED);
@@ -84,6 +85,7 @@ update_doc (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_EXAMPLE_RULES_XML);
   lw6sys_list_push_back (list, LW6DEF_EXAMPLE_HINTS_XML);
   lw6sys_list_push_back (list, LW6DEF_EXAMPLE_STYLE_XML);
+  lw6sys_list_push_back (list, LW6DEF_EXAMPLE_TEAMS_XML);
 
   return ((*list) != NULL);
 }
@@ -143,6 +145,7 @@ update_show (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_ENABLE_MOD_CSOUND);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_ENABLE_MOD_OGG);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_ENABLE_MOD_HTTP);
+  lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_ENABLE_OPENMP);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_ENABLE_OPTIMIZE);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_ENABLE_ALLINONE);
   lw6sys_list_push_back (list, LW6DEF_SHOW_BUILD_ENABLE_FULLSTATIC);
@@ -242,14 +245,6 @@ update_players (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_PLAYER2_CONTROL);
   lw6sys_list_push_back (list, LW6DEF_PLAYER3_CONTROL);
   lw6sys_list_push_back (list, LW6DEF_PLAYER4_CONTROL);
-  lw6sys_list_push_back (list, LW6DEF_PLAYER1_BOT);
-  lw6sys_list_push_back (list, LW6DEF_PLAYER2_BOT);
-  lw6sys_list_push_back (list, LW6DEF_PLAYER3_BOT);
-  lw6sys_list_push_back (list, LW6DEF_PLAYER4_BOT);
-  lw6sys_list_push_back (list, LW6DEF_PLAYER1_COLOR);
-  lw6sys_list_push_back (list, LW6DEF_PLAYER2_COLOR);
-  lw6sys_list_push_back (list, LW6DEF_PLAYER3_COLOR);
-  lw6sys_list_push_back (list, LW6DEF_PLAYER4_COLOR);
 
   return ((*list) != NULL);
 }
@@ -276,12 +271,16 @@ update_input (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_MAX_CURSOR_SPEED);
   lw6sys_list_push_back (list, LW6DEF_REPEAT_DELAY);
   lw6sys_list_push_back (list, LW6DEF_REPEAT_INTERVAL);
+  lw6sys_list_push_back (list, LW6DEF_DOUBLE_CLICK_DELAY);
+  lw6sys_list_push_back (list, LW6DEF_USE_DOUBLE_CLICK);
   lw6sys_list_push_back (list, LW6DEF_CUSTOM_UP);
   lw6sys_list_push_back (list, LW6DEF_CUSTOM_DOWN);
   lw6sys_list_push_back (list, LW6DEF_CUSTOM_LEFT);
   lw6sys_list_push_back (list, LW6DEF_CUSTOM_RIGHT);
   lw6sys_list_push_back (list, LW6DEF_CUSTOM_ESC);
   lw6sys_list_push_back (list, LW6DEF_CUSTOM_ENTER);
+  lw6sys_list_push_back (list, LW6DEF_CUSTOM_CTRL);
+  lw6sys_list_push_back (list, LW6DEF_CUSTOM_ALT);
   lw6sys_list_push_back (list, LW6DEF_CUSTOM_PGUP);
   lw6sys_list_push_back (list, LW6DEF_CUSTOM_PGDOWN);
   lw6sys_list_push_back (list, LW6DEF_CLICK_TO_FOCUS);
@@ -403,6 +402,7 @@ update_map (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_USE_RULES_XML);
   lw6sys_list_push_back (list, LW6DEF_USE_HINTS_XML);
   lw6sys_list_push_back (list, LW6DEF_USE_STYLE_XML);
+  lw6sys_list_push_back (list, LW6DEF_USE_TEAMS_XML);
   lw6sys_list_push_back (list, LW6DEF_USE_MUSIC_FILE);
   lw6sys_list_push_back (list, LW6DEF_FORCE);
 
@@ -429,6 +429,7 @@ update_map_rules (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_TOTAL_TIME);
   lw6sys_list_push_back (list, LW6DEF_RESPAWN_TEAM);
   lw6sys_list_push_back (list, LW6DEF_RESPAWN_POSITION_MODE);
+  lw6sys_list_push_back (list, LW6DEF_RESPAWN_DELAY);
   lw6sys_list_push_back (list, LW6DEF_MOVES_PER_ROUND);
   lw6sys_list_push_back (list, LW6DEF_SPREADS_PER_ROUND);
   lw6sys_list_push_back (list, LW6DEF_ROUNDS_PER_SEC);
@@ -442,11 +443,15 @@ update_map_rules (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_NB_ATTACK_TRIES);
   lw6sys_list_push_back (list, LW6DEF_NB_DEFENSE_TRIES);
   lw6sys_list_push_back (list, LW6DEF_VERTICAL_MOVE);
+  lw6sys_list_push_back (list, LW6DEF_SPREAD_MODE);
   lw6sys_list_push_back (list, LW6DEF_SINGLE_ARMY_SIZE);
   lw6sys_list_push_back (list, LW6DEF_TOTAL_ARMIES_SIZE);
   lw6sys_list_push_back (list, LW6DEF_MAX_NB_TEAMS);
   lw6sys_list_push_back (list, LW6DEF_MAX_NB_CURSORS);
   lw6sys_list_push_back (list, LW6DEF_MAX_NB_NODES);
+  lw6sys_list_push_back (list, LW6DEF_EXP);
+  lw6sys_list_push_back (list, LW6DEF_HIGHEST_TEAM_COLOR_ALLOWED);
+  lw6sys_list_push_back (list, LW6DEF_HIGHEST_WEAPON_ALLOWED);
   lw6sys_list_push_back (list, LW6DEF_X_POLARITY);
   lw6sys_list_push_back (list, LW6DEF_Y_POLARITY);
   lw6sys_list_push_back (list, LW6DEF_Z_POLARITY);
@@ -527,6 +532,46 @@ update_map_rules (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_TEAM_PROFILE_LIGHTBLUE_FAST);
   lw6sys_list_push_back (list, LW6DEF_TEAM_PROFILE_PURPLE_FAST);
   lw6sys_list_push_back (list, LW6DEF_TEAM_PROFILE_PINK_FAST);
+  lw6sys_list_push_back (list, LW6DEF_TEAM_PROFILE_RED_WEAPON_ID);
+  lw6sys_list_push_back (list, LW6DEF_TEAM_PROFILE_GREEN_WEAPON_ID);
+  lw6sys_list_push_back (list, LW6DEF_TEAM_PROFILE_BLUE_WEAPON_ID);
+  lw6sys_list_push_back (list, LW6DEF_TEAM_PROFILE_YELLOW_WEAPON_ID);
+  lw6sys_list_push_back (list, LW6DEF_TEAM_PROFILE_CYAN_WEAPON_ID);
+  lw6sys_list_push_back (list, LW6DEF_TEAM_PROFILE_MAGENTA_WEAPON_ID);
+  lw6sys_list_push_back (list, LW6DEF_TEAM_PROFILE_ORANGE_WEAPON_ID);
+  lw6sys_list_push_back (list, LW6DEF_TEAM_PROFILE_LIGHTBLUE_WEAPON_ID);
+  lw6sys_list_push_back (list, LW6DEF_TEAM_PROFILE_PURPLE_WEAPON_ID);
+  lw6sys_list_push_back (list, LW6DEF_TEAM_PROFILE_PINK_WEAPON_ID);
+  lw6sys_list_push_back (list, LW6DEF_TEAM_PROFILE_RED_WEAPON_ALTERNATE_ID);
+  lw6sys_list_push_back (list, LW6DEF_TEAM_PROFILE_GREEN_WEAPON_ALTERNATE_ID);
+  lw6sys_list_push_back (list, LW6DEF_TEAM_PROFILE_BLUE_WEAPON_ALTERNATE_ID);
+  lw6sys_list_push_back (list,
+			 LW6DEF_TEAM_PROFILE_YELLOW_WEAPON_ALTERNATE_ID);
+  lw6sys_list_push_back (list, LW6DEF_TEAM_PROFILE_CYAN_WEAPON_ALTERNATE_ID);
+  lw6sys_list_push_back (list,
+			 LW6DEF_TEAM_PROFILE_MAGENTA_WEAPON_ALTERNATE_ID);
+  lw6sys_list_push_back (list,
+			 LW6DEF_TEAM_PROFILE_ORANGE_WEAPON_ALTERNATE_ID);
+  lw6sys_list_push_back (list,
+			 LW6DEF_TEAM_PROFILE_LIGHTBLUE_WEAPON_ALTERNATE_ID);
+  lw6sys_list_push_back (list,
+			 LW6DEF_TEAM_PROFILE_PURPLE_WEAPON_ALTERNATE_ID);
+  lw6sys_list_push_back (list, LW6DEF_TEAM_PROFILE_PINK_WEAPON_ALTERNATE_ID);
+  lw6sys_list_push_back (list, LW6DEF_TEAM_PROFILE_RED_WEAPON_MODE);
+  lw6sys_list_push_back (list, LW6DEF_TEAM_PROFILE_GREEN_WEAPON_MODE);
+  lw6sys_list_push_back (list, LW6DEF_TEAM_PROFILE_BLUE_WEAPON_MODE);
+  lw6sys_list_push_back (list, LW6DEF_TEAM_PROFILE_YELLOW_WEAPON_MODE);
+  lw6sys_list_push_back (list, LW6DEF_TEAM_PROFILE_CYAN_WEAPON_MODE);
+  lw6sys_list_push_back (list, LW6DEF_TEAM_PROFILE_MAGENTA_WEAPON_MODE);
+  lw6sys_list_push_back (list, LW6DEF_TEAM_PROFILE_ORANGE_WEAPON_MODE);
+  lw6sys_list_push_back (list, LW6DEF_TEAM_PROFILE_LIGHTBLUE_WEAPON_MODE);
+  lw6sys_list_push_back (list, LW6DEF_TEAM_PROFILE_PURPLE_WEAPON_MODE);
+  lw6sys_list_push_back (list, LW6DEF_TEAM_PROFILE_PINK_WEAPON_MODE);
+  lw6sys_list_push_back (list, LW6DEF_WEAPON_DURATION);
+  lw6sys_list_push_back (list, LW6DEF_WEAPON_CHARGE_DELAY);
+  lw6sys_list_push_back (list, LW6DEF_WEAPON_CHARGE_MAX);
+  lw6sys_list_push_back (list, LW6DEF_WEAPON_TUNE_BERZERK_POWER);
+  lw6sys_list_push_back (list, LW6DEF_WEAPON_TUNE_TURBO_POWER);
 
   return ((*list) != NULL);
 }
@@ -646,6 +691,7 @@ update_map_style (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_MUSIC_FILE);
   lw6sys_list_push_back (list, LW6DEF_MUSIC_FILTER);
   lw6sys_list_push_back (list, LW6DEF_MUSIC_EXCLUDE);
+  lw6sys_list_push_back (list, LW6DEF_WAVES);
 
   return ((*list) != NULL);
 }
@@ -664,6 +710,52 @@ lw6hlp_list_map_style ()
   return list;
 }
 
+static int
+update_map_teams (lw6sys_list_t ** list)
+{
+  lw6sys_list_push_back (list, LW6DEF_PLAYER1_COLOR);
+  lw6sys_list_push_back (list, LW6DEF_PLAYER2_COLOR);
+  lw6sys_list_push_back (list, LW6DEF_PLAYER3_COLOR);
+  lw6sys_list_push_back (list, LW6DEF_PLAYER4_COLOR);
+  lw6sys_list_push_back (list, LW6DEF_NB_BOTS);
+  lw6sys_list_push_back (list, LW6DEF_BOT_SPEED);
+  lw6sys_list_push_back (list, LW6DEF_BOT_IQ);
+  lw6sys_list_push_back (list, LW6DEF_BOT1_COLOR);
+  lw6sys_list_push_back (list, LW6DEF_BOT2_COLOR);
+  lw6sys_list_push_back (list, LW6DEF_BOT3_COLOR);
+  lw6sys_list_push_back (list, LW6DEF_BOT4_COLOR);
+  lw6sys_list_push_back (list, LW6DEF_BOT5_COLOR);
+  lw6sys_list_push_back (list, LW6DEF_BOT6_COLOR);
+  lw6sys_list_push_back (list, LW6DEF_BOT7_COLOR);
+  lw6sys_list_push_back (list, LW6DEF_BOT8_COLOR);
+  lw6sys_list_push_back (list, LW6DEF_BOT9_COLOR);
+  lw6sys_list_push_back (list, LW6DEF_BOT1_AI);
+  lw6sys_list_push_back (list, LW6DEF_BOT2_AI);
+  lw6sys_list_push_back (list, LW6DEF_BOT3_AI);
+  lw6sys_list_push_back (list, LW6DEF_BOT4_AI);
+  lw6sys_list_push_back (list, LW6DEF_BOT5_AI);
+  lw6sys_list_push_back (list, LW6DEF_BOT6_AI);
+  lw6sys_list_push_back (list, LW6DEF_BOT7_AI);
+  lw6sys_list_push_back (list, LW6DEF_BOT8_AI);
+  lw6sys_list_push_back (list, LW6DEF_BOT9_AI);
+
+  return ((*list) != NULL);
+}
+
+lw6sys_list_t *
+lw6hlp_list_map_teams ()
+{
+  lw6sys_list_t *list = NULL;
+
+  list = lw6sys_list_new (NULL);
+  if (list)
+    {
+      update_map_teams (&list);
+    }
+
+  return list;
+}
+
 static int
 update_funcs (lw6sys_list_t ** list)
 {
@@ -707,6 +799,7 @@ update_funcs (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_C_LW6SYS_BUILD_GET_ENABLE_MOD_CSOUND);
   lw6sys_list_push_back (list, LW6DEF_C_LW6SYS_BUILD_GET_ENABLE_MOD_OGG);
   lw6sys_list_push_back (list, LW6DEF_C_LW6SYS_BUILD_GET_ENABLE_MOD_HTTP);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6SYS_BUILD_GET_ENABLE_OPENMP);
   lw6sys_list_push_back (list, LW6DEF_C_LW6SYS_BUILD_GET_ENABLE_OPTIMIZE);
   lw6sys_list_push_back (list, LW6DEF_C_LW6SYS_BUILD_GET_ENABLE_ALLINONE);
   lw6sys_list_push_back (list, LW6DEF_C_LW6SYS_BUILD_GET_ENABLE_FULLSTATIC);
@@ -783,6 +876,7 @@ update_funcs (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_C_LW6HLP_LIST_MAP_RULES);
   lw6sys_list_push_back (list, LW6DEF_C_LW6HLP_LIST_MAP_HINTS);
   lw6sys_list_push_back (list, LW6DEF_C_LW6HLP_LIST_MAP_STYLE);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6HLP_LIST_MAP_TEAMS);
   lw6sys_list_push_back (list, LW6DEF_C_LW6HLP_LIST_FUNCS);
   lw6sys_list_push_back (list, LW6DEF_C_LW6HLP_LIST_HOOKS);
   lw6sys_list_push_back (list, LW6DEF_C_LW6HLP_LIST_ADVANCED);
@@ -823,32 +917,42 @@ update_funcs (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_JOYSTICK2_GET_MOVE_PAD);
   lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_MOUSE_POP_BUTTON_LEFT);
   lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_MOUSE_POP_BUTTON_RIGHT);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_MOUSE_POP_BUTTON_MIDDLE);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_MOUSE_POP_SIMPLE_CLICK);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_MOUSE_POP_DOUBLE_CLICK);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_MOUSE_POP_TRIPLE_CLICK);
   lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_MOUSE_POP_WHEEL_UP);
   lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_MOUSE_POP_WHEEL_DOWN);
-  lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_KEYBOARD_POP_KEY_UP);
-  lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_KEYBOARD_POP_KEY_DOWN);
-  lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_KEYBOARD_POP_KEY_LEFT);
-  lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_KEYBOARD_POP_KEY_RIGHT);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_KEYBOARD_POP_ARROW_UP);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_KEYBOARD_POP_ARROW_DOWN);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_KEYBOARD_POP_ARROW_LEFT);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_KEYBOARD_POP_ARROW_RIGHT);
   lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_KEYBOARD_POP_KEY_ENTER);
   lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_KEYBOARD_POP_KEY_ESC);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_KEYBOARD_POP_KEY_CTRL);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_KEYBOARD_POP_KEY_ALT);
   lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_KEYBOARD_POP_KEY_PGUP);
   lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_KEYBOARD_POP_KEY_PGDOWN);
-  lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_JOYSTICK1_POP_BUTTON_UP);
-  lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_JOYSTICK1_POP_BUTTON_DOWN);
-  lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_JOYSTICK1_POP_BUTTON_LEFT);
-  lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_JOYSTICK1_POP_BUTTON_RIGHT);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_JOYSTICK1_POP_PAD_UP);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_JOYSTICK1_POP_PAD_DOWN);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_JOYSTICK1_POP_PAD_LEFT);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_JOYSTICK1_POP_PAD_RIGHT);
   lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_JOYSTICK1_POP_BUTTON_A);
   lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_JOYSTICK1_POP_BUTTON_B);
   lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_JOYSTICK1_POP_BUTTON_C);
   lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_JOYSTICK1_POP_BUTTON_D);
-  lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_JOYSTICK2_POP_BUTTON_UP);
-  lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_JOYSTICK2_POP_BUTTON_DOWN);
-  lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_JOYSTICK2_POP_BUTTON_LEFT);
-  lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_JOYSTICK2_POP_BUTTON_RIGHT);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_JOYSTICK1_POP_BUTTON_E);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_JOYSTICK1_POP_BUTTON_F);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_JOYSTICK2_POP_PAD_UP);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_JOYSTICK2_POP_PAD_DOWN);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_JOYSTICK2_POP_PAD_LEFT);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_JOYSTICK2_POP_PAD_RIGHT);
   lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_JOYSTICK2_POP_BUTTON_A);
   lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_JOYSTICK2_POP_BUTTON_B);
   lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_JOYSTICK2_POP_BUTTON_C);
   lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_JOYSTICK2_POP_BUTTON_D);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_JOYSTICK2_POP_BUTTON_E);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6GUI_JOYSTICK2_POP_BUTTON_F);
   lw6sys_list_push_back (list, LW6DEF_C_LW6GFX_GET_BACKENDS);
   lw6sys_list_push_back (list, LW6DEF_C_LW6DSP_NEW);
   lw6sys_list_push_back (list, LW6DEF_C_LW6DSP_RELEASE);
@@ -864,15 +968,23 @@ update_funcs (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_C_LW6LDR_READ_RELATIVE);
   lw6sys_list_push_back (list, LW6DEF_C_LW6LDR_PRINT_EXAMPLES);
   lw6sys_list_push_back (list, LW6DEF_C_LW6LDR_HINTS_GET_DEFAULT);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6LDR_EXP_VALIDATE);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6LDR_CHAIN_ENTRY);
   lw6sys_list_push_back (list, LW6DEF_C_LW6MAP_GET_LOOK);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6MAP_PARAM_GET);
   lw6sys_list_push_back (list, LW6DEF_C_LW6MAP_GET_MUSIC_DIR);
   lw6sys_list_push_back (list, LW6DEF_C_LW6MAP_TEAM_COLOR_INDEX_TO_KEY);
   lw6sys_list_push_back (list, LW6DEF_C_LW6MAP_TEAM_COLOR_KEY_TO_INDEX);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6MAP_TEAM_COLOR_LIST);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6MAP_WEAPON_INDEX_TO_KEY);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6MAP_WEAPON_KEY_TO_INDEX);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6MAP_WEAPON_LIST);
   lw6sys_list_push_back (list, LW6DEF_C_LW6MAP_RULES_GET_DEFAULT);
   lw6sys_list_push_back (list, LW6DEF_C_LW6MAP_RULES_GET_MIN);
   lw6sys_list_push_back (list, LW6DEF_C_LW6MAP_RULES_GET_MAX);
   lw6sys_list_push_back (list, LW6DEF_C_LW6MAP_RULES_GET_INT);
   lw6sys_list_push_back (list, LW6DEF_C_LW6MAP_STYLE_GET_DEFAULT);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6MAP_TEAMS_GET_DEFAULT);
   lw6sys_list_push_back (list, LW6DEF_C_LW6KER_BUILD_GAME_STRUCT);
   lw6sys_list_push_back (list, LW6DEF_C_LW6KER_BUILD_GAME_STATE);
   lw6sys_list_push_back (list, LW6DEF_C_LW6KER_SYNC_GAME_STATE);
@@ -892,12 +1004,14 @@ update_funcs (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_C_LW6KER_GET_SPREADS);
   lw6sys_list_push_back (list, LW6DEF_C_LW6KER_GET_ROUNDS);
   lw6sys_list_push_back (list, LW6DEF_C_LW6KER_IS_OVER);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6KER_DID_CURSOR_WIN);
   lw6sys_list_push_back (list, LW6DEF_C_LW6PIL_BENCH);
   lw6sys_list_push_back (list, LW6DEF_C_LW6PIL_BUILD_PILOT);
   lw6sys_list_push_back (list, LW6DEF_C_LW6PIL_SEND_COMMAND);
   lw6sys_list_push_back (list, LW6DEF_C_LW6PIL_LOCAL_COMMAND);
   lw6sys_list_push_back (list, LW6DEF_C_LW6PIL_COMMIT);
   lw6sys_list_push_back (list, LW6DEF_C_LW6PIL_FIX_COORDS);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6PIL_FIX_COORDS_X10);
   lw6sys_list_push_back (list, LW6DEF_C_LW6PIL_EXECUTE_COMMAND);
   lw6sys_list_push_back (list, LW6DEF_C_LW6PIL_LOCAL_CURSORS_SET_MAIN);
   lw6sys_list_push_back (list,
@@ -915,6 +1029,7 @@ update_funcs (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_C_LW6PIL_GET_REFERENCE_TARGET_ROUND);
   lw6sys_list_push_back (list, LW6DEF_C_LW6PIL_GET_MAX_ROUND);
   lw6sys_list_push_back (list, LW6DEF_C_LW6PIL_IS_OVER);
+  lw6sys_list_push_back (list, LW6DEF_C_LW6PIL_DID_CURSOR_WIN);
   lw6sys_list_push_back (list, LW6DEF_C_LW6SND_GET_BACKENDS);
   lw6sys_list_push_back (list, LW6DEF_C_LW6SND_NEW);
   lw6sys_list_push_back (list, LW6DEF_C_LW6SND_POLL);
@@ -1026,11 +1141,11 @@ update_advanced (lw6sys_list_t ** list)
   lw6sys_list_push_back (list, LW6DEF_DEMO);
   lw6sys_list_push_back (list, LW6DEF_BENCH);
   lw6sys_list_push_back (list, LW6DEF_BENCH_VALUE);
+  lw6sys_list_push_back (list, LW6DEF_MAX_LOCAL_BENCH_VALUE);
+  lw6sys_list_push_back (list, LW6DEF_MAX_NETWORK_BENCH_VALUE);
   lw6sys_list_push_back (list, LW6DEF_MAGIC_NUMBER);
   lw6sys_list_push_back (list, LW6DEF_BIN_ID);
   lw6sys_list_push_back (list, LW6DEF_CHECK);
-  lw6sys_list_push_back (list, LW6DEF_BOT_SPEED);
-  lw6sys_list_push_back (list, LW6DEF_BOT_IQ);
   lw6sys_list_push_back (list, LW6DEF_DEBUG_TEAM_ID);
   lw6sys_list_push_back (list, LW6DEF_DEBUG_LAYER_ID);
   lw6sys_list_push_back (list, LW6DEF_LOG_TIMEOUT);
@@ -1117,8 +1232,9 @@ lw6hlp_list ()
 	&& update_sound (&list) && update_network (&list)
 	&& update_map (&list) && update_map_rules (&list)
 	&& update_map_hints (&list) && update_map_style (&list)
-	&& update_funcs (&list) && update_hooks (&list)
-	&& update_advanced (&list) && update_aliases (&list);
+	&& update_map_teams (&list) && update_funcs (&list)
+	&& update_hooks (&list) && update_advanced (&list)
+	&& update_aliases (&list);
     }
 
   if (!ok)
