@@ -969,18 +969,21 @@ _lw6ker_game_state_set_cursor (_lw6ker_game_state_t * game_state,
 			       lw6ker_cursor_t * cursor)
 {
   int ret = 0;
-  int x, y;
+  int x, y, fire, fire2;
 
   if (check_node_id (game_state, cursor->node_id))
     {
       x = cursor->pos.x;
       y = cursor->pos.y;
+      fire = cursor->fire;
+      fire2 = cursor->fire2;
       lw6map_coords_fix_xy (&(game_state->game_struct->rules),
 			    &(game_state->map_state.shape), &x, &y);
       ret =
 	_lw6ker_cursor_array_update (&(game_state->map_state.cursor_array),
 				     cursor->node_id, cursor->cursor_id, x, y,
-				     0, &(game_state->map_state.shape),
+				     fire, fire2, 0,
+				     &(game_state->map_state.shape),
 				     &(game_state->game_struct->rules));
     }
 
@@ -996,8 +999,9 @@ _lw6ker_game_state_set_cursor (_lw6ker_game_state_t * game_state,
  * Sets a cursor, that is, changes its position, this is pretty much
  * anything we can do about a cursor except adding or removing it, just
  * because of Liquid War very simple rules. The passed pointer may be
- * freed after the call, only the cursor_id, node_id, x and y fields
- * are used, others are ignored.
+ * freed after the call, only the @cursor_id, @node_id, @x, @y and @fire fields
+ * are used, others are ignored. More precisely, the @enabled will be ignored,
+ * it's not a valid way to add/remove teams.
  *
  * Return value: 1 on success, 0 on failure
  */
@@ -1085,6 +1089,7 @@ _lw6ker_game_state_add_team_internal (_lw6ker_game_state_t * game_state,
 	  _lw6ker_map_state_remove_fighters (&(game_state->map_state),
 					     total_fighters_to_remove);
 	}
+      game_state->map_state.teams[team_color].offline = 0;
       /*
        * Do add people.
        */
@@ -1233,7 +1238,6 @@ _lw6ker_game_state_remove_team_internal (_lw6ker_game_state_t * game_state,
 		    }
 		}
 	    }
-
 	  _lw6ker_map_state_cancel_team (&(game_state->map_state),
 					 team_color);
 	}
@@ -1326,16 +1330,17 @@ _lw6ker_game_state_get_team_info (_lw6ker_game_state_t *
 		game_state->map_state.armies.fighters_per_team[team_color];
 	    }
 	}
-      else
+    }
+
+  if (!ret)
+    {
+      if (nb_cursors)
 	{
-	  if (nb_cursors)
-	    {
-	      (*nb_cursors) = 0;
-	    }
-	  if (nb_fighters)
-	    {
-	      (*nb_fighters) = 0;
-	    }
+	  (*nb_cursors) = 0;
+	}
+      if (nb_fighters)
+	{
+	  (*nb_fighters) = 0;
 	}
     }
 
@@ -1432,11 +1437,21 @@ void
 _lw6ker_game_state_do_move (_lw6ker_game_state_t *
 			    game_state, u_int32_t team_mask)
 {
+  int rounds;
+
+  rounds = _lw6ker_game_state_get_rounds (game_state);
+
   if (!game_state->over)
     {
+      _lw6ker_map_state_charge (&(game_state->map_state),
+				&(game_state->game_struct->rules), rounds);
+      _lw6ker_map_state_process_fire (&(game_state->map_state),
+				      &(game_state->game_struct->rules),
+				      rounds);
       _lw6ker_map_state_move_fighters (&(game_state->map_state),
+				       rounds,
 				       lw6sys_checksum_int32
-				       (game_state->rounds) %
+				       (rounds) %
 				       LW6KER_NB_PARITIES,
 				       &(game_state->game_struct->rules),
 				       game_state->game_struct->rules.
@@ -1470,6 +1485,7 @@ void
 _lw6ker_game_state_finish_round (_lw6ker_game_state_t * game_state)
 {
   int total_rounds;
+  int rounds;
   int nb_teams;
   int team_color;
   int32_t nb_cursors = 0;
@@ -1478,6 +1494,7 @@ _lw6ker_game_state_finish_round (_lw6ker_game_state_t * game_state)
   int i;
 
   total_rounds = _lw6ker_game_state_get_total_rounds (game_state);
+  rounds = _lw6ker_game_state_get_rounds (game_state);
   nb_teams = _lw6ker_game_state_get_nb_teams (game_state);
 
   game_state->max_reached_teams =
@@ -1489,14 +1506,18 @@ _lw6ker_game_state_finish_round (_lw6ker_game_state_t * game_state)
 					&nb_fighters);
       if (nb_cursors == 0)
 	{
-	  /*
-	   * This should be a rare case, how come there are no cursors for a team?
-	   * Still, with an alliance system, it could theorically happen.
-	   */
-	  lw6sys_log (LW6SYS_LOG_DEBUG,
-		      _x_ ("no cursors for team %d, removing it"),
-		      team_color);
-	  _lw6ker_game_state_remove_team_internal (game_state, team_color);
+	  if (game_state->map_state.teams[team_color].active)
+	    {
+	      /*
+	       * This should be a rare case, how come there are no cursors for a team?
+	       * Still, with an alliance system, it could theorically happen.
+	       */
+	      lw6sys_log (LW6SYS_LOG_DEBUG,
+			  _x_ ("no cursors for team %d, removing it"),
+			  team_color);
+	      _lw6ker_game_state_remove_team_internal (game_state,
+						       team_color);
+	    }
 	}
       else
 	{
@@ -1504,47 +1525,73 @@ _lw6ker_game_state_finish_round (_lw6ker_game_state_t * game_state)
 	    {
 	      if (game_state->game_struct->rules.respawn_team)
 		{
-		  _lw6ker_map_state_frag (&(game_state->map_state),
-					  team_color,
-					  game_state->game_struct->rules.
-					  frags_mode,
-					  game_state->game_struct->rules.
-					  frags_to_distribute,
-					  game_state->game_struct->rules.
-					  frags_fade_out);
-		}
-	      _lw6ker_game_state_remove_team_internal (game_state,
-						       team_color);
-	      if (game_state->game_struct->rules.respawn_team)
-		{
-		  /*
-		   * We don't delete more than half of the fighters but still,
-		   * we do need to delete some.
-		   */
-		  nb_fighters_to_delete =
-		    lw6sys_min (lw6ker_per100_2
-				(game_state->map_state.map_struct->
-				 room_for_armies,
-				 game_state->game_struct->rules.
-				 single_army_size),
-				_lw6ker_game_state_get_nb_active_fighters
-				(game_state) / 2);
-		  _lw6ker_map_state_remove_fighters (&(game_state->map_state),
-						     nb_fighters_to_delete);
-		  /*
-		   * Cancelling then adding will have the effect to repopulate the team
-		   */
-		  _lw6ker_game_state_add_team_internal (game_state,
-							team_color,
-							game_state->game_struct->
-							rules.respawn_position_mode);
+		  if (game_state->map_state.teams[team_color].respawn_round ==
+		      0)
+		    {
+		      /*
+		       * We unset all weapons once someone looses to avoid
+		       * artificial killing sprees on unfair settings.
+		       */
+		      _lw6ker_weapon_unset_all (&(game_state->map_state));
+
+		      _lw6ker_map_state_frag (&(game_state->map_state),
+					      team_color,
+					      game_state->game_struct->rules.
+					      frags_mode,
+					      game_state->game_struct->rules.
+					      frags_to_distribute,
+					      game_state->game_struct->rules.
+					      frags_fade_out);
+
+		      game_state->map_state.teams[team_color].respawn_round =
+			rounds +
+			(game_state->game_struct->rules.respawn_delay *
+			 game_state->game_struct->rules.rounds_per_sec);
+		    }
+		  if (game_state->map_state.teams[team_color].respawn_round <=
+		      rounds)
+		    {
+		      _lw6ker_game_state_remove_team_internal (game_state,
+							       team_color);
+		      game_state->map_state.teams[team_color].respawn_round =
+			0;
+		      /*
+		       * We don't delete more than half of the fighters but still,
+		       * we do need to delete some.
+		       */
+		      nb_fighters_to_delete =
+			lw6sys_min (lw6ker_per100_2
+				    (game_state->map_state.map_struct->
+				     room_for_armies,
+				     game_state->game_struct->rules.
+				     single_army_size),
+				    _lw6ker_game_state_get_nb_active_fighters
+				    (game_state) / 2);
+		      _lw6ker_map_state_remove_fighters (&
+							 (game_state->map_state),
+							 nb_fighters_to_delete);
+		      /*
+		       * Cancelling then adding will have the effect to repopulate the team
+		       */
+		      _lw6ker_game_state_add_team_internal (game_state,
+							    team_color,
+							    game_state->game_struct->
+							    rules.respawn_position_mode);
+		    }
 		}
 	      else
 		{
+		  /*
+		   * We unset all weapons once someone looses to avoid
+		   * artificial killing sprees on unfair settings.
+		   */
+		  _lw6ker_weapon_unset_all (&(game_state->map_state));
 		  /*
 		   * OK this is hell we do it manually but high-level functions
 		   * all require a node-id...
 		   */
+		  _lw6ker_game_state_remove_team_internal (game_state,
+							   team_color);
 		  for (i = 0; i < LW6MAP_MAX_NB_CURSORS; ++i)
 		    {
 		      if (game_state->map_state.cursor_array.cursors[i].
@@ -1562,7 +1609,7 @@ _lw6ker_game_state_finish_round (_lw6ker_game_state_t * game_state)
     }
 
   // First good reason to finish : time up
-  if (game_state->rounds >= total_rounds)
+  if (rounds >= total_rounds)
     {
       game_state->over = 1;
     }
@@ -1578,8 +1625,7 @@ _lw6ker_game_state_finish_round (_lw6ker_game_state_t * game_state)
     {
       _lw6ker_history_set (&(game_state->global_history),
 			   &(game_state->map_state.armies),
-			   (game_state->rounds * LW6KER_HISTORY_SIZE) /
-			   total_rounds);
+			   (rounds * LW6KER_HISTORY_SIZE) / total_rounds);
       _lw6ker_history_add (&(game_state->latest_history),
 			   &(game_state->map_state.armies));
       game_state->moves += game_state->game_struct->rules.moves_per_round;
@@ -1752,6 +1798,165 @@ lw6ker_game_state_is_over (lw6ker_game_state_t * game_state)
   return _lw6ker_game_state_is_over ((_lw6ker_game_state_t *) game_state);
 }
 
+int
+_lw6ker_game_state_did_cursor_win (_lw6ker_game_state_t * game_state,
+				   u_int16_t cursor_id)
+{
+  int ret = 0;
+  lw6ker_score_array_t score_array;
+  int winner_team_color = LW6MAP_TEAM_COLOR_INVALID;
+  lw6ker_cursor_t cursor;
+
+  if (_lw6ker_game_state_is_over (game_state))
+    {
+      if (_lw6ker_game_state_get_cursor (game_state, &cursor, cursor_id))
+	{
+	  if (_lw6ker_score_array_update (&score_array, game_state))
+	    {
+	      winner_team_color = score_array.scores[0].team_color;
+	      if (winner_team_color == cursor.team_color)
+		{
+		  lw6sys_log (LW6SYS_LOG_DEBUG,
+			      _x_ ("cursor %x with color %d won"),
+			      (int) cursor_id, winner_team_color);
+		  ret = 1;
+		}
+	    }
+	}
+    }
+
+  if (!ret)
+    {
+      lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("cursor %x didn't win"),
+		  (int) cursor_id);
+    }
+
+  return ret;
+}
+
+/**
+ * lw6ker_game_state_did_cursor_win
+ *
+ * @game_state: game_state to query
+ * @cursor_id: the cursor to test
+ *
+ * Tells wether a cursor was the winner after a game is over.
+ *
+ * Return value: 1 if cursor is in winning team, 0 if not.
+ */
+int
+lw6ker_game_state_did_cursor_win (lw6ker_game_state_t * game_state,
+				  u_int16_t cursor_id)
+{
+  return _lw6ker_game_state_did_cursor_win ((_lw6ker_game_state_t *)
+					    game_state, cursor_id);
+}
+
+int
+_lw6ker_game_state_get_winner (_lw6ker_game_state_t * game_state,
+			       int excluded_team)
+{
+  int nb_active_fighters_min;
+  int nb_active_fighters;
+  int nb_teams;
+  int i;
+  int ret = LW6MAP_TEAM_COLOR_INVALID;
+
+  nb_active_fighters_min =
+    _lw6ker_game_state_get_nb_active_fighters (game_state);
+  nb_teams = _lw6ker_game_state_get_nb_teams (game_state);
+  for (i = 0; i < nb_teams; ++i)
+    {
+      nb_active_fighters = 0;
+      _lw6ker_game_state_get_team_info (game_state, i, NULL,
+					&nb_active_fighters);
+      if (nb_active_fighters < nb_active_fighters_min
+	  && nb_active_fighters > 0 && i != excluded_team)
+	{
+	  ret = i;
+	  nb_active_fighters_min = nb_active_fighters;
+	}
+    }
+
+  return ret;
+}
+
+/**
+ * lw6ker_game_state_get_winner
+ *
+ * @game_state: the game_state to query
+ * @excluded_team: a team to exclude
+ *
+ * Returns the winner, if you set excluded_team to something else
+ * than a valid team number (for instance -1, but 0 is a valid team)
+ * then this team will be excluded from search. This is usefull if
+ * you want to find out who's the best positionned player while
+ * excluding yourself, for instance if you're a bot.
+ *
+ * Return value: the winner team number, note that it can be
+ * invalid (-1) if there's no winner (for example, there are no
+ * teams on the map).
+ */
+int
+lw6ker_game_state_get_winner (lw6ker_game_state_t * game_state,
+			      int excluded_team)
+{
+  return _lw6ker_game_state_get_winner ((_lw6ker_game_state_t *) game_state,
+					excluded_team);
+}
+
+int
+_lw6ker_game_state_get_looser (_lw6ker_game_state_t * game_state,
+			       int excluded_team)
+{
+  int nb_active_fighters_max;
+  int nb_active_fighters;
+  int nb_teams;
+  int i;
+  int ret = LW6MAP_TEAM_COLOR_INVALID;
+
+  nb_active_fighters_max = 0;
+  nb_teams = _lw6ker_game_state_get_nb_teams (game_state);
+  for (i = 0; i < nb_teams; ++i)
+    {
+      nb_active_fighters = 0;
+      _lw6ker_game_state_get_team_info (game_state, i, NULL,
+					&nb_active_fighters);
+      if (nb_active_fighters > nb_active_fighters_max
+	  && nb_active_fighters > 0 && i != excluded_team)
+	{
+	  ret = i;
+	  nb_active_fighters_max = nb_active_fighters;
+	}
+    }
+
+  return ret;
+}
+
+/**
+ * lw6ker_game_state_get_looser
+ *
+ * @game_state: the game_state to query
+ * @excluded_team: a team to exclude
+ *
+ * Returns the looser, if you set excluded_team to something else
+ * than a valid team number (for instance -1, but 0 is a valid team)
+ * then this team will be excluded from search. This is usefull if
+ * you want to find out who's the worst positionned player while
+ * excluding yourself, for instance if you're a bot.
+ *
+ * Return value: the looser team number, note that it can be
+ * invalid (-1) if there's no looser (for example, there are no
+ * teams on the map).
+ */
+int
+lw6ker_game_state_get_looser (lw6ker_game_state_t * game_state,
+			      int excluded_team)
+{
+  return _lw6ker_game_state_get_looser ((_lw6ker_game_state_t *) game_state,
+					excluded_team);
+}
+
 int32_t
 _lw6ker_game_state_get_nb_active_fighters (_lw6ker_game_state_t * game_state)
 {
@@ -2066,7 +2271,7 @@ lw6ker_game_state_get_fighter_unsafe (lw6ker_game_state_t * game_state,
  * lw6ker_game_state_get_zone_potential
  *
  * @game_state: the game_state to query
- * @i: the zone index
+ * @zone_i: the zone index
  * @team_id: the team id (color)
  *
  * Gets the potential of a zone. In practice this is not needed to
@@ -2082,3 +2287,81 @@ lw6ker_game_state_get_zone_potential (lw6ker_game_state_t * game_state,
   return ((_lw6ker_game_state_t *) game_state)->map_state.
     teams[team_id].gradient[i].potential;
 }
+
+/**
+ * lw6ker_game_state_get_charge_per1000
+ *
+ * @game_state: game_state to query
+ * @team_color: the team color to query
+ *
+ * Returns the charge ratio for a given team/color. A value of 100
+ * means fire is enabled, more than 1000 means super-charge, under 100
+ * means you have to wait.
+ *
+ * Return value: integer value.
+ */
+int
+lw6ker_game_state_get_charge_per1000 (lw6ker_game_state_t * game_state,
+				      int team_color)
+{
+  return
+    _lw6ker_team_get_charge_per1000 (&
+				     (((_lw6ker_game_state_t *)
+				       game_state)->map_state.
+				      teams[team_color]));
+}
+
+/**
+ * lw6ker_game_state_get_weapon_per1000_left
+ *
+ * @game_state: game_state to query
+ * @team_color: the team color to query
+ *
+ * Returns how much of the weapon is yet to be consumed for a given
+ * team. More than 1000 means extra time, 1000 is standard time to
+ * be elapsed, 0 means it's over.
+ *
+ * Return value: integer value.
+ */
+int
+lw6ker_game_state_get_weapon_per1000_left (lw6ker_game_state_t * game_state,
+					   int team_color)
+{
+  return
+    _lw6ker_map_state_get_weapon_per1000_left (&
+					       (((_lw6ker_game_state_t *)
+						 game_state)->map_state),
+					       lw6ker_game_state_get_rounds
+					       (game_state), team_color);
+}
+
+/**
+ * lw6ker_game_state_get_weapon_per1000_left
+ *
+ * @game_state: game_state to query
+ * @team_color: the team color corresponding to last weapon (out param)
+ * @weapon_id: the corresponding weapon_id (out param)
+ * @per1000_left: how much of the weapon is yet to be spent (out param)
+ *
+ * Returns informations about the latest weapon, this is typically
+ * for drawing purposes, just query this and you know if you need
+ * to paint everything in red, green, whatever, as far as the default
+ * backend is concerned. In case there's no weapon, well, parameters
+ * are untouched. Pointers can be passed as NULL.
+ *
+ * Return value: 1 if found, 0 if not.
+ */
+int
+lw6ker_game_state_get_latest_weapon (lw6ker_game_state_t *
+				     game_state,
+				     int *team_color,
+				     int *weapon_id, int *per1000_left)
+{
+  return
+    _lw6ker_weapon_get_latest_weapon (&
+				      (((_lw6ker_game_state_t *)
+					game_state)->map_state),
+				      lw6ker_game_state_get_rounds
+				      (game_state), team_color, weapon_id,
+				      per1000_left);
+}
