@@ -29,6 +29,11 @@
 #define _LW6KER_STRAIGHT_DIR_DOWN 0x04;
 #define _LW6KER_STRAIGHT_DIR_LEFT 0x08;
 
+#define _LW6KER_ACT_LIMIT 100
+#define _LW6KER_CHARGE_LIMIT 1000000
+
+#define _LW6KER_BERZERK_ROUNDS_TO_KILL 2
+
 typedef int32_t _lw6ker_tables_move_offset_t[LW6KER_NB_DIRS];
 typedef int32_t _lw6ker_tables_move_dir_tries_t[LW6MAP_MAX_NB_DIR_TRIES];
 typedef _lw6ker_tables_move_dir_tries_t
@@ -160,10 +165,17 @@ _lw6ker_cursor_array_t;
 typedef struct _lw6ker_team_s
 {
   int active;
+  int has_been_active;
+  int respawn_round;
+  int offline;
   _lw6ker_map_struct_t *map_struct;
   _lw6ker_zone_state_t *gradient;
   int32_t cursor_ref_pot;
   int32_t last_spread_dir;
+  int32_t charge;
+  int32_t weapon_id;
+  int32_t weapon_first_round;
+  int32_t weapon_last_round;
 }
 _lw6ker_team_t;
 
@@ -218,7 +230,6 @@ typedef struct _lw6ker_map_state_s
   _lw6ker_slot_state_t *slots;
 }
 _lw6ker_map_state_t;
-
 typedef struct _lw6ker_history_s
 {
   int nb_entries;
@@ -285,6 +296,8 @@ typedef struct _lw6ker_move_context_s
   int32_t per_team_nb_move_tries[LW6MAP_MAX_NB_TEAMS];
   int32_t per_team_nb_attack_tries[LW6MAP_MAX_NB_TEAMS];
   int32_t per_team_nb_defense_tries[LW6MAP_MAX_NB_TEAMS];
+  int32_t per_team_fast[LW6MAP_MAX_NB_TEAMS];
+  int32_t per_team_weapon_id[LW6MAP_MAX_NB_TEAMS];
   lw6sys_whd_t shape;
   int32_t *move_dir_table;
   int32_t enemy_id;
@@ -332,8 +345,8 @@ extern int _lw6ker_cursor_enable (lw6ker_cursor_t * cursor,
 				  int team_color, int32_t x, int32_t y);
 extern int _lw6ker_cursor_disable (lw6ker_cursor_t * cursor);
 extern int _lw6ker_cursor_update (lw6ker_cursor_t * cursor, int32_t x,
-				  int32_t y, int32_t pot_offset,
-				  lw6sys_whd_t * shape,
+				  int32_t y, int fire, int fire2,
+				  int32_t pot_offset, lw6sys_whd_t * shape,
 				  lw6map_rules_t * rules);
 extern int _lw6ker_cursor_sanity_check (lw6ker_cursor_t * cursor,
 					lw6sys_whd_t * shape,
@@ -367,7 +380,8 @@ extern int _lw6ker_cursor_array_disable (_lw6ker_cursor_array_t *
 extern int _lw6ker_cursor_array_update (_lw6ker_cursor_array_t * cursor_array,
 					u_int64_t node_id,
 					u_int16_t cursor_id, int32_t x,
-					int32_t y, int32_t pot_offset,
+					int32_t y, int fire, int fire2,
+					int32_t pot_offset,
 					lw6sys_whd_t * shape,
 					lw6map_rules_t * rules);
 extern int _lw6ker_cursor_array_sanity_check (_lw6ker_cursor_array_t *
@@ -489,6 +503,13 @@ extern u_int32_t _lw6ker_game_state_get_rounds (_lw6ker_game_state_t *
 extern u_int32_t _lw6ker_game_state_get_total_rounds (_lw6ker_game_state_t *
 						      game_state);
 extern int _lw6ker_game_state_is_over (_lw6ker_game_state_t * game_state);
+extern int _lw6ker_game_state_did_cursor_win (_lw6ker_game_state_t *
+					      game_state,
+					      u_int16_t cursor_id);
+extern int _lw6ker_game_state_get_winner (_lw6ker_game_state_t * game_state,
+					  int excluded_team);
+extern int _lw6ker_game_state_get_looser (_lw6ker_game_state_t * game_state,
+					  int excluded_team);
 extern int32_t _lw6ker_game_state_get_nb_active_fighters (_lw6ker_game_state_t
 							  * game_state);
 extern int32_t _lw6ker_game_state_get_time_elapsed (_lw6ker_game_state_t *
@@ -627,13 +648,26 @@ extern void _lw6ker_map_state_spread_gradient (_lw6ker_map_state_t *
 					       int32_t nb_spreads,
 					       u_int32_t team_mask);
 extern void _lw6ker_map_state_move_fighters (_lw6ker_map_state_t * map_state,
-					     int parity,
+					     int round, int parity,
 					     lw6map_rules_t * rules,
 					     int32_t nb_moves,
 					     u_int32_t team_mask);
 extern void _lw6ker_map_state_apply_cursors (_lw6ker_map_state_t * map_state,
 					     lw6map_rules_t * rules,
 					     u_int32_t team_mask);
+extern void _lw6ker_map_state_process_fire (_lw6ker_map_state_t * map_state,
+					    lw6map_rules_t * rules,
+					    int round);
+extern void _lw6ker_map_state_charge (_lw6ker_map_state_t * map_state,
+				      lw6map_rules_t * rules, int round);
+extern int _lw6ker_map_state_is_this_weapon_active (_lw6ker_map_state_t *
+						    map_state, int round,
+						    int weapon_id,
+						    int team_color);
+extern int _lw6ker_map_state_get_weapon_per1000_left (_lw6ker_map_state_t *
+						      map_state,
+						      int round,
+						      int team_color);
 
 /*
  * In mapstruct.c
@@ -722,6 +756,11 @@ extern void _lw6ker_move_adjust_health (lw6ker_fighter_t * fighter,
 					int32_t health_correction);
 extern void _lw6ker_move_update_fighters_universal (_lw6ker_move_context_t *
 						    context);
+extern int
+_lw6ker_move_get_best_next_pos (_lw6ker_game_state_t * game_state,
+				lw6sys_xyz_t * next_pos,
+				lw6sys_xyz_t * current_pos, int team_color);
+
 
 /* ker-placestruct.c */
 extern void _lw6ker_place_struct_update_checksum (_lw6ker_place_struct_t *
@@ -808,6 +847,12 @@ extern void _lw6ker_team_activate (_lw6ker_team_t * team, lw6sys_xyz_t pos);
 extern void _lw6ker_team_unactivate (_lw6ker_team_t * team);
 extern void _lw6ker_team_normalize_pot (_lw6ker_team_t * team,
 					lw6map_rules_t * rules);
+extern int _lw6ker_team_get_charge_per1000 (_lw6ker_team_t * team);
+extern void _lw6ker_team_reset_charge (_lw6ker_team_t * team);
+extern int _lw6ker_team_is_this_weapon_active (_lw6ker_team_t * team,
+					       int round, int weapon_id);
+extern int _lw6ker_team_get_weapon_per1000_left (_lw6ker_team_t * team,
+						 int round);
 
 /*
  * In slotstate.c
@@ -827,8 +872,118 @@ extern void _lw6ker_slot_struct_update_checksum (_lw6ker_slot_struct_t *
  * In spread.c
  */
 extern int32_t _lw6ker_spread_next_dir (int32_t dir);
+extern void _lw6ker_spread_do_all_dirs_incr_xy (_lw6ker_zone_struct_t *
+						zone_structs,
+						_lw6ker_zone_state_t *
+						zone_states, int nb_zones);
+extern void _lw6ker_spread_do_all_dirs_decr_xy (_lw6ker_zone_struct_t *
+						zone_structs,
+						_lw6ker_zone_state_t *
+						zone_states, int nb_zones);
+extern void _lw6ker_spread_do_one_dir_incr_xy (_lw6ker_zone_struct_t *
+					       zone_structs,
+					       _lw6ker_zone_state_t *
+					       zone_states, int nb_zones,
+					       int dir);
+extern void _lw6ker_spread_do_one_dir_incr_z (_lw6ker_zone_struct_t *
+					      zone_structs,
+					      _lw6ker_zone_state_t *
+					      zone_states, int nb_zones,
+					      int dir);
+extern void _lw6ker_spread_do_one_dir_decr_xy (_lw6ker_zone_struct_t *
+					       zone_structs,
+					       _lw6ker_zone_state_t *
+					       zone_states, int nb_zones,
+					       int dir);
+extern void _lw6ker_spread_do_one_dir_decr_z (_lw6ker_zone_struct_t *
+					      zone_structs,
+					      _lw6ker_zone_state_t *
+					      zone_states, int nb_zones,
+					      int dir);
+
 extern void _lw6ker_spread_update_gradient (_lw6ker_team_t * team,
-					    int skip_vertical);
+					    int skip_vertical,
+					    int spread_mode);
+
+/* ker-weapon.c */
+extern void _lw6ker_weapon_unset_by_weapon_id (_lw6ker_map_state_t *
+					       map_state, int weapon_id);
+extern void _lw6ker_weapon_unset_all (_lw6ker_map_state_t * map_state);
+extern int _lw6ker_weapon_find_team_by_weapon_id (_lw6ker_map_state_t *
+						  map_state, int round,
+						  int weapon_id);
+extern int _lw6ker_weapon_get_latest_weapon (_lw6ker_map_state_t * map_state,
+					     int round, int *team_color,
+					     int *weapon_id,
+					     int *per1000_left);
+extern int _lw6ker_weapon_fire (_lw6ker_map_state_t * map_state,
+				lw6map_rules_t * rules, int round,
+				int team_color, int charge_percent);
+extern int _lw6ker_weapon_fire2 (_lw6ker_map_state_t * map_state,
+				 lw6map_rules_t * rules, int round,
+				 int team_color, int charge_percent);
+extern int _lw6ker_weapon_fire_berzerk (_lw6ker_map_state_t * map_state,
+					lw6map_rules_t * rules, int round,
+					int team_color, int charge_percent);
+extern int _lw6ker_weapon_fire_invincible (_lw6ker_map_state_t * map_state,
+					   lw6map_rules_t * rules, int round,
+					   int team_color,
+					   int charge_percent);
+extern int _lw6ker_weapon_fire_escape (_lw6ker_map_state_t * map_state,
+				       lw6map_rules_t * rules, int round,
+				       int team_color, int charge_percent);
+extern int _lw6ker_weapon_fire_turbo (_lw6ker_map_state_t * map_state,
+				      lw6map_rules_t * rules, int round,
+				      int team_color, int charge_percent);
+extern int _lw6ker_weapon_fire_teleport (_lw6ker_map_state_t * map_state,
+					 lw6map_rules_t * rules, int round,
+					 int team_color, int charge_percent);
+extern int _lw6ker_weapon_fire_scatter (_lw6ker_map_state_t * map_state,
+					lw6map_rules_t * rules, int round,
+					int team_color, int charge_percent);
+extern int _lw6ker_weapon_fire_fix (_lw6ker_map_state_t * map_state,
+				    lw6map_rules_t * rules, int round,
+				    int team_color, int charge_percent);
+extern int _lw6ker_weapon_fire_mix (_lw6ker_map_state_t * map_state,
+				    lw6map_rules_t * rules, int round,
+				    int team_color, int charge_percent);
+extern int _lw6ker_weapon_fire_control (_lw6ker_map_state_t * map_state,
+					lw6map_rules_t * rules, int round,
+					int team_color, int charge_percent);
+extern int _lw6ker_weapon_fire_permutation (_lw6ker_map_state_t * map_state,
+					    lw6map_rules_t * rules, int round,
+					    int team_color,
+					    int charge_percent);
+extern int _lw6ker_weapon_fire_steal (_lw6ker_map_state_t * map_state,
+				      lw6map_rules_t * rules, int round,
+				      int team_color, int charge_percent);
+extern int _lw6ker_weapon_fire_atomic (_lw6ker_map_state_t * map_state,
+				       lw6map_rules_t * rules, int round,
+				       int team_color, int charge_percent);
+extern int _lw6ker_weapon_fire_reverse (_lw6ker_map_state_t * map_state,
+					lw6map_rules_t * rules, int round,
+					int team_color, int charge_percent);
+extern int _lw6ker_weapon_fire_crazy (_lw6ker_map_state_t * map_state,
+				      lw6map_rules_t * rules, int round,
+				      int team_color, int charge_percent);
+extern int _lw6ker_weapon_fire_rewind (_lw6ker_map_state_t * map_state,
+				       lw6map_rules_t * rules, int round,
+				       int team_color, int charge_percent);
+extern int _lw6ker_weapon_fire_attract (_lw6ker_map_state_t * map_state,
+					lw6map_rules_t * rules, int round,
+					int team_color, int charge_percent);
+extern int _lw6ker_weapon_fire_shrink (_lw6ker_map_state_t * map_state,
+				       lw6map_rules_t * rules, int round,
+				       int team_color, int charge_percent);
+extern int _lw6ker_weapon_fire_kamikaze (_lw6ker_map_state_t * map_state,
+					 lw6map_rules_t * rules, int round,
+					 int team_color, int charge_percent);
+extern int _lw6ker_weapon_fire_disappear (_lw6ker_map_state_t * map_state,
+					  lw6map_rules_t * rules, int round,
+					  int team_color, int charge_percent);
+extern int _lw6ker_weapon_fire_plague (_lw6ker_map_state_t * map_state,
+				       lw6map_rules_t * rules, int round,
+				       int team_color, int charge_percent);
 
 /*
  * In zonestate.c
