@@ -601,23 +601,52 @@ _lw6ker_map_state_spread_gradient (_lw6ker_map_state_t * map_state,
 				   lw6map_rules_t * rules, int32_t nb_spreads,
 				   u_int32_t team_mask)
 {
-  int i, j;
+  int i;
+  int teams_concerned[LW6MAP_MAX_NB_TEAMS];
+  int n = 0;
 
   _lw6ker_map_state_apply_cursors (map_state, rules, team_mask);
+  /*
+   * We first construct a list of the concerned teams, this is to
+   * (hopefully) optimize the following OpenMP pragma, so that it's
+   * fed with threads that do somethings only...
+   */
   for (i = 0; i < map_state->max_nb_teams; ++i)
     {
       if (map_state->teams[i].active)
 	{
 	  if (lw6ker_team_mask_is_concerned (i, team_mask))
 	    {
-	      for (j = 0; j < nb_spreads; ++j)
-		{
-		  _lw6ker_spread_update_gradient (&(map_state->teams[i]),
-						  map_state->shape.d == 1);
-		}
+	      teams_concerned[n] = i;
+	      n++;
 	    }
 	}
     }
+  /*
+   * Now gradients can be calculated independently, OpenMP should
+   * really help us here, as it's a time consuming operation
+   */
+#ifdef LW6_OPENMP
+#pragma omp parallel for
+#endif
+  for (i = 0; i < n; ++i)
+    {
+      /*
+       * Now it's important to define j *now* and only *now*
+       * inside the above for loop, since when running parrallel,
+       * every thread needs its own copy of j.
+       */
+      int j;
+
+      for (j = 0; j < nb_spreads; ++j)
+	{
+	  _lw6ker_spread_update_gradient (&
+					  (map_state->teams
+					   [teams_concerned[i]]),
+					  map_state->shape.d == 1,
+					  rules->spread_mode);
+	}
+    }
 }
 
 int
@@ -638,7 +667,7 @@ _lw6ker_map_state_get_nb_teams (_lw6ker_map_state_t * map_state)
 }
 
 void
-_lw6ker_map_state_move_fighters (_lw6ker_map_state_t * map_state,
+_lw6ker_map_state_move_fighters (_lw6ker_map_state_t * map_state, int round,
 				 int parity, lw6map_rules_t * rules,
 				 int32_t nb_moves, u_int32_t team_mask)
 {
@@ -656,11 +685,11 @@ _lw6ker_map_state_move_fighters (_lw6ker_map_state_t * map_state,
   context.armies = &(map_state->armies);
   context.active_fighters = context.armies->active_fighters;
 
-  for (i = 0; i < LW6MAP_MAX_NB_TEAMS; ++i)
+  if (context.rules.use_team_profiles)
     {
-      for (j = 0; j < LW6MAP_MAX_NB_TEAMS; ++j)
+      for (i = 0; i < LW6MAP_MAX_NB_TEAMS; ++i)
 	{
-	  if (context.rules.use_team_profiles)
+	  for (j = 0; j < LW6MAP_MAX_NB_TEAMS; ++j)
 	    {
 	      context.fighter_attack[i][j] =
 		lw6ker_percent (lw6ker_percent
@@ -668,13 +697,19 @@ _lw6ker_map_state_move_fighters (_lw6ker_map_state_t * map_state,
 				 rules->team_profile_aggressive[i]),
 				rules->team_profile_vulnerable[j]);
 	    }
-	  else
+	}
+    }
+  else
+    {
+      for (i = 0; i < LW6MAP_MAX_NB_TEAMS; ++i)
+	{
+	  for (j = 0; j < LW6MAP_MAX_NB_TEAMS; ++j)
 	    {
 	      context.fighter_attack[i][j] = rules->fighter_attack;
+	      context.fighter_side_attack[i][j] =
+		lw6ker_percent (context.fighter_attack[i][j],
+				rules->side_attack_factor);
 	    }
-	  context.fighter_side_attack[i][j] =
-	    lw6ker_percent (context.fighter_attack[i][j],
-			    rules->side_attack_factor);
 	}
     }
 
@@ -688,9 +723,9 @@ _lw6ker_map_state_move_fighters (_lw6ker_map_state_t * map_state,
    * Here we initialize a per-team array with nb_..._tries values so
    * that we don't calculate it each time.
    */
-  for (i = 0; i < LW6MAP_MAX_NB_TEAMS; ++i)
+  if (context.rules.use_team_profiles)
     {
-      if (context.rules.use_team_profiles)
+      for (i = 0; i < LW6MAP_MAX_NB_TEAMS; ++i)
 	{
 	  context.per_team_nb_move_tries[i] =
 	    context.rules.nb_move_tries +
@@ -720,13 +755,60 @@ _lw6ker_map_state_move_fighters (_lw6ker_map_state_t * map_state,
 	  context.per_team_nb_defense_tries[i] =
 	    lw6sys_min (context.per_team_nb_defense_tries[i],
 			LW6MAP_RULES_MAX_NB_DEFENSE_TRIES);
+
+	  context.per_team_fast[i] = context.rules.team_profile_fast[i];
+
+	  if (map_state->teams[i].weapon_first_round <= round
+	      && map_state->teams[i].weapon_last_round >= round
+	      && map_state->teams[i].weapon_id >= LW6MAP_MIN_WEAPON_ID
+	      && map_state->teams[i].weapon_id <= LW6MAP_MAX_WEAPON_ID)
+	    {
+	      context.per_team_weapon_id[i] = map_state->teams[i].weapon_id;
+	    }
+	  else
+	    {
+	      context.per_team_weapon_id[i] = LW6MAP_WEAPON_NONE;
+	    }
 	}
-      else
+      /*
+       * Post-processing attack values due to weapons and such
+       */
+      for (i = 0; i < LW6MAP_MAX_NB_TEAMS; ++i)
+	{
+	  if (context.per_team_weapon_id[i] == LW6MAP_WEAPON_BERZERK)
+	    {
+	      for (j = 0; j < LW6MAP_MAX_NB_TEAMS; ++j)
+		{
+		  context.fighter_attack[i][j] =
+		    lw6sys_min (context.fighter_attack[i][j] *
+				context.rules.weapon_tune_berzerk_power,
+				LW6MAP_RULES_MAX_FIGHTER_ATTACK);
+		}
+	    }
+	  if (context.per_team_weapon_id[i] == LW6MAP_WEAPON_INVINCIBLE)
+	    {
+	      for (j = 0; j < LW6MAP_MAX_NB_TEAMS; ++j)
+		{
+		  context.fighter_attack[j][i] = 0;
+		}
+	    }
+	  if (context.per_team_weapon_id[i] == LW6MAP_WEAPON_TURBO)
+	    {
+	      context.per_team_fast[i] = context.per_team_fast[i] *
+		context.rules.weapon_tune_turbo_power;
+	    }
+	}
+    }
+  else
+    {
+      for (i = 0; i < LW6MAP_MAX_NB_TEAMS; ++i)
 	{
 	  context.per_team_nb_move_tries[i] = context.rules.nb_move_tries;
 	  context.per_team_nb_attack_tries[i] = context.rules.nb_attack_tries;
 	  context.per_team_nb_defense_tries[i] =
 	    context.rules.nb_defense_tries;
+	  context.per_team_fast[i] = LW6MAP_RULES_DEFAULT_TEAM_PROFILE_FAST;
+	  context.per_team_weapon_id[i] = LW6MAP_WEAPON_NONE;
 	}
     }
 
@@ -872,6 +954,80 @@ _lw6ker_map_state_apply_cursors (_lw6ker_map_state_t * map_state,
     }
 }
 
+void
+_lw6ker_map_state_process_fire (_lw6ker_map_state_t * map_state,
+				lw6map_rules_t * rules, int round)
+{
+  int32_t i, team_color;
+  int charge_percent;
+
+  for (i = 0; i < LW6MAP_MAX_NB_CURSORS; ++i)
+    {
+      if (map_state->cursor_array.cursors[i].enabled
+	  && (map_state->cursor_array.cursors[i].fire
+	      || map_state->cursor_array.cursors[i].fire2))
+	{
+	  team_color = map_state->cursor_array.cursors[i].team_color;
+	  charge_percent =
+	    _lw6ker_team_get_charge_per1000 (&(map_state->teams[team_color]))
+	    / 10;
+	  if (charge_percent >= 100)
+	    {
+	      if (map_state->cursor_array.cursors[i].fire)
+		{
+		  lw6sys_log (LW6SYS_LOG_DEBUG,
+			      _x_
+			      ("primary fire team_color=%d charge_percent=%d"),
+			      team_color, charge_percent);
+		  if (_lw6ker_weapon_fire
+		      (map_state, rules, round, team_color, charge_percent))
+		    {
+		      _lw6ker_team_reset_charge (&
+						 (map_state->teams
+						  [team_color]));
+		    }
+		  else if (map_state->cursor_array.cursors[i].fire2)
+		    {
+		      lw6sys_log (LW6SYS_LOG_DEBUG,
+				  _x_
+				  ("secondary fire team_color=%d charge_percent=%d (primary failed)"),
+				  team_color, charge_percent);
+		      if (_lw6ker_weapon_fire2
+			  (map_state, rules, round, team_color,
+			   charge_percent))
+			{
+			  _lw6ker_team_reset_charge (&
+						     (map_state->teams
+						      [team_color]));
+			}
+		    }
+		}
+	      else if (map_state->cursor_array.cursors[i].fire2)
+		{
+		  lw6sys_log (LW6SYS_LOG_DEBUG,
+			      _x_
+			      ("secondary fire team_color=%d charge_percent=%d"),
+			      team_color, charge_percent);
+		  if (_lw6ker_weapon_fire2
+		      (map_state, rules, round, team_color, charge_percent))
+		    {
+		      _lw6ker_team_reset_charge (&
+						 (map_state->teams
+						  [team_color]));
+		    }
+		}
+	    }
+	  else
+	    {
+	      lw6sys_log (LW6SYS_LOG_DEBUG,
+			  _x_ ("can't fire not enough charge for color %d"),
+			  team_color);
+	    }
+	}
+      map_state->cursor_array.cursors[i].fire = 0;
+    }
+}
+
 void
 _lw6ker_map_state_frag (_lw6ker_map_state_t * map_state, int team_color,
 			int frags_mode, int frags_to_distribute,
@@ -905,11 +1061,12 @@ _lw6ker_map_state_frag (_lw6ker_map_state_t * map_state, int team_color,
 
   for (i = 0; i < LW6MAP_MAX_NB_TEAMS; ++i)
     {
-      if (map_state->teams[i].active)
+      if (map_state->teams[i].active && (!map_state->teams[i].offline))
 	{
 	  if (armies->fighters_per_team[i] <= 0)
 	    {
 	      nb_loosers++;
+	      map_state->teams[i].offline = 1;
 	    }
 	  else
 	    {
@@ -985,14 +1142,14 @@ _lw6ker_map_state_frag (_lw6ker_map_state_t * map_state, int team_color,
 		}
 	      else
 		{
-		  lw6sys_log (LW6SYS_LOG_WARNING,
+		  lw6sys_log (LW6SYS_LOG_DEBUG,
 			      _x_
 			      ("can't calculate frags when there are no winners"));
 		}
 	    }
 	  else
 	    {
-	      lw6sys_log (LW6SYS_LOG_WARNING,
+	      lw6sys_log (LW6SYS_LOG_DEBUG,
 			  _x_
 			  ("can't calculate frags when there are no loosers"));
 	    }
@@ -1052,3 +1209,91 @@ _lw6ker_map_state_frag (_lw6ker_map_state_t * map_state, int team_color,
 	}
     }
 }
+
+void
+_lw6ker_map_state_charge (_lw6ker_map_state_t * map_state,
+			  lw6map_rules_t * rules, int round)
+{
+  int32_t team_color;
+  int charge_incr = 0;
+  int charge_percent = 0;
+  int charge_max = 0;
+  int nb_teams;
+
+  if (rules->use_team_profiles)
+    {
+      nb_teams = _lw6ker_map_state_get_nb_teams (map_state);
+      charge_max =
+	lw6ker_percent (_LW6KER_CHARGE_LIMIT, rules->weapon_charge_max);
+
+      if (rules->weapon_charge_delay > 0 && rules->rounds_per_sec > 0)
+	{
+	  if (nb_teams > 0)
+	    {
+	      for (team_color = 0; team_color < LW6MAP_MAX_NB_TEAMS;
+		   ++team_color)
+		{
+		  if (map_state->teams[team_color].active
+		      && rules->team_profile_weapon_mode[team_color] !=
+		      LW6MAP_RULES_TEAM_PROFILE_WEAPON_MODE_NONE &&
+		      _lw6ker_map_state_get_weapon_per1000_left (map_state,
+								 round,
+								 team_color)
+		      <= 0 && !map_state->teams[team_color].offline)
+		    {
+		      charge_incr =
+			_LW6KER_CHARGE_LIMIT / (rules->weapon_charge_delay *
+						rules->rounds_per_sec);
+		      if (map_state->armies.active_fighters > 0)
+			{
+			  charge_percent =
+			    (map_state->armies.fighters_per_team[team_color] *
+			     nb_teams * 100) /
+			    map_state->armies.active_fighters;
+			}
+		      else
+			{
+			  charge_percent = 100;
+			}
+		      charge_percent = (charge_percent + 100) / 2;
+		      charge_incr =
+			lw6ker_percent (charge_incr, charge_percent);
+		      map_state->teams[team_color].charge += charge_incr;
+		      map_state->teams[team_color].charge =
+			lw6sys_min (map_state->teams[team_color].charge,
+				    charge_max);
+		      lw6sys_log (LW6SYS_LOG_DEBUG,
+				  _x_ ("new charge for team %d is %d"),
+				  team_color,
+				  map_state->teams[team_color].charge);
+		    }
+		}
+	    }
+	}
+      else
+	{
+	  lw6sys_log (LW6SYS_LOG_WARNING,
+		      _x_
+		      ("bad rules weapon_charge_delay=%d rounds_per_sec=%d"),
+		      rules->weapon_charge_delay, rules->rounds_per_sec);
+	}
+    }
+}
+
+int
+_lw6ker_map_state_is_this_weapon_active (_lw6ker_map_state_t * map_state,
+					 int round, int weapon_id,
+					 int team_color)
+{
+  return _lw6ker_team_is_this_weapon_active (&(map_state->teams[team_color]),
+					     round, weapon_id);
+}
+
+int
+_lw6ker_map_state_get_weapon_per1000_left (_lw6ker_map_state_t * map_state,
+					   int round, int team_color)
+{
+  return
+    _lw6ker_team_get_weapon_per1000_left (&(map_state->teams[team_color]),
+					  round);
+}
