@@ -31,10 +31,10 @@
 #define TEST_MAP_NB_LAYERS 5
 #define TEST_MAP_NOISE_PERCENT 20
 #define TEST_NB_ROUNDS 100
-#define TEST_GAME_STRUCT_CHECKSUM 0x1acceb44
-#define TEST_GAME_STATE_CHECKSUM 0x96e97c98
-#define TEST_GAME_STATE_POPULATE_CHECKSUM 0xc23516a9
-#define TEST_GAME_STATE_ALGORITHM_CHECKSUM 0x331c5e34
+#define TEST_GAME_STRUCT_CHECKSUM 0x17f35dd0
+#define TEST_GAME_STATE_CHECKSUM 0x1ef268d8
+#define TEST_GAME_STATE_POPULATE_CHECKSUM 0x199361e2
+#define TEST_GAME_STATE_ALGORITHM_CHECKSUM 0x4ec89314
 #define TEST_NODE_ID 0x1234123412341234LL
 #define TEST_CURSOR1_ID 0x1234
 #define TEST_CURSOR2_ID 0x2345
@@ -56,6 +56,9 @@ print_game_struct_repr (lw6ker_game_struct_t * game_struct)
   int is_fg, is_bg;
   lw6sys_xyz_t zone_pos;
   int zone_size;
+  int zone_id;
+  lw6sys_xyz_t here = { 0, 0, 0 };
+  lw6sys_xyz_t there = { 0, 0, 0 };
 
   lw6ker_game_struct_get_shape (game_struct, &shape);
   x = lw6sys_random (lw6ker_game_struct_get_w (game_struct));
@@ -63,15 +66,21 @@ print_game_struct_repr (lw6ker_game_struct_t * game_struct)
   z = lw6sys_random (lw6ker_game_struct_get_d (game_struct));
   is_fg = lw6ker_game_struct_is_fg (game_struct, x, y, z);
   is_bg = lw6ker_game_struct_is_bg (game_struct, x, y, z);
-  lw6sys_log (LW6SYS_LOG_NOTICE, _("%d,%d,%d is_fg=%d is_bg=%d"), x,
+  lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("%d,%d,%d is_fg=%d is_bg=%d"), x,
 	      y, z, is_fg, is_bg);
 
   lw6ker_game_struct_get_zones_info (game_struct, &nb_zones, &max_zone_size);
-  lw6sys_log (LW6SYS_LOG_NOTICE, _("nb_zones=%d max_zone_size=%d"), nb_zones,
-	      max_zone_size);
-  lw6ker_game_struct_get_zone_info (game_struct, 0, &zone_pos, &zone_size);
-  lw6sys_log (LW6SYS_LOG_NOTICE, _("zone_pos=%d,%d,%d zone_size=%d"),
+  lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("nb_zones=%d max_zone_size=%d"),
+	      nb_zones, max_zone_size);
+  zone_id =
+    lw6ker_game_struct_get_zone_id (game_struct, shape.w / 2, shape.h / 2,
+				    shape.d / 2);
+  lw6ker_game_struct_get_zone_info (game_struct, zone_id, &zone_pos,
+				    &zone_size);
+  lw6sys_log (LW6SYS_LOG_NOTICE,
+	      _x_ ("zone_id=%d zone_pos=%d,%d,%d zone_size=%d"), zone_id,
 	      zone_pos.x, zone_pos.y, zone_pos.z, zone_size);
+  lw6ker_game_struct_find_free_slot_near (game_struct, &there, here);
 
   repr = lw6ker_game_struct_repr (game_struct);
   if (repr)
@@ -99,6 +108,12 @@ print_game_state_repr (lw6ker_game_state_t * game_state)
   int x, y, z;
   lw6ker_cursor_t cursor;
   int potential;
+  int winner, looser;
+  lw6sys_xyz_t current_pos = { 0, 0, 0 };
+  lw6sys_xyz_t next_pos = { 0, 0, 0 };
+  int team_color = 0;
+  int weapon_id = 0;
+  int per1000_left = 0;
 
   repr = lw6ker_game_state_repr (game_state);
   if (repr)
@@ -133,7 +148,7 @@ print_game_state_repr (lw6ker_game_state_t * game_state)
 	  potential =
 	    lw6ker_game_state_get_zone_potential (game_state, 0,
 						  LW6MAP_TEAM_COLOR_RED);
-	  lw6sys_log (LW6SYS_LOG_DEBUG, _("potential of zone 0 is %d"),
+	  lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("potential of zone 0 is %d"),
 		      potential);
 	  fighter_id = lw6ker_game_state_get_fighter_id (game_state, x, y, z);
 	  if (fighter_id >= 0)
@@ -164,6 +179,20 @@ print_game_state_repr (lw6ker_game_state_t * game_state)
 			  _x_ ("no fighter in x,y,z (%d)"), x, y, z,
 			  fighter_id);
 	    }
+	  winner =
+	    lw6ker_game_state_get_winner (game_state,
+					  LW6MAP_TEAM_COLOR_INVALID);
+	  looser =
+	    lw6ker_game_state_get_looser (game_state,
+					  LW6MAP_TEAM_COLOR_INVALID);
+	  lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("winner=%d looser=%d"), winner,
+		      looser);
+	  lw6ker_move_get_best_next_pos (game_state, &next_pos, &current_pos,
+					 0);
+	  lw6ker_game_state_get_charge_per1000 (game_state, 0);
+	  lw6ker_game_state_get_weapon_per1000_left (game_state, 0);
+	  lw6ker_game_state_get_latest_weapon (game_state, &team_color,
+					       &weapon_id, &per1000_left);
 	}
     }
 
