@@ -28,20 +28,26 @@
 
 #define LW6KER_NB_DIRS 14
 
-#define LW6KER_DIR_NNE 0
-#define LW6KER_DIR_NE 1
-#define LW6KER_DIR_ENE 2
-#define LW6KER_DIR_ESE 3
-#define LW6KER_DIR_SE 4
-#define LW6KER_DIR_SSE 5
-#define LW6KER_DIR_SSW 6
-#define LW6KER_DIR_SW 7
-#define LW6KER_DIR_WSW 8
-#define LW6KER_DIR_WNW 9
-#define LW6KER_DIR_NW 10
-#define LW6KER_DIR_NNW 11
-#define LW6KER_DIR_UP 12
-#define LW6KER_DIR_DOWN 13
+/*
+ * Historically, first dir (0) was NNE, but it happened
+ * a minor optimization is to have ENE being 0, this allows
+ * dirs 0-2, 3-5, 6-8 and 9-11 to be consider 4 packs of
+ * alike dirs when spreading.
+ */
+#define LW6KER_DIR_NNE 10
+#define LW6KER_DIR_NE 11
+#define LW6KER_DIR_ENE 0
+#define LW6KER_DIR_ESE 1
+#define LW6KER_DIR_SE 2
+#define LW6KER_DIR_SSE 3
+#define LW6KER_DIR_SSW 4
+#define LW6KER_DIR_SW 5
+#define LW6KER_DIR_WSW 6
+#define LW6KER_DIR_WNW 7
+#define LW6KER_DIR_NW 8
+#define LW6KER_DIR_NNW 9
+#define LW6KER_DIR_DOWN 12
+#define LW6KER_DIR_UP 13
 
 #define LW6KER_NB_PARITIES 2
 
@@ -62,8 +68,6 @@
 
 #define LW6KER_HISTORY_SIZE 512
 
-#define LW6KER_ACT_LIMIT 100
-
 #include "ker-trigo.h"
 
 typedef struct lw6ker_fighter_s
@@ -77,6 +81,13 @@ typedef struct lw6ker_fighter_s
 }
 lw6ker_fighter_t;
 
+typedef struct lw6ker_cursor_control_s
+{
+  lw6sys_xyz_t pos;
+  int fire;
+  int fire2;
+} lw6ker_cursor_control_t;
+
 typedef struct lw6ker_cursor_s
 {
   u_int64_t node_id;
@@ -85,6 +96,8 @@ typedef struct lw6ker_cursor_s
   int enabled;
   int team_color;
   lw6sys_xyz_t pos;
+  int fire;
+  int fire2;
   lw6sys_xyz_t apply_pos;
   int32_t pot_offset;
 }
@@ -146,9 +159,7 @@ extern char *lw6ker_capture_str (lw6ker_game_state_t * game_state);
  */
 extern void lw6ker_cursor_reset (lw6ker_cursor_t * cursor);
 
-/*
- * in gamestate.c
- */
+/* ker-gamestate.c */
 extern lw6ker_game_state_t *lw6ker_game_state_new (lw6ker_game_struct_t *
 						   game_struct,
 						   lw6sys_progress_t *
@@ -222,6 +233,12 @@ extern u_int32_t lw6ker_game_state_get_rounds (lw6ker_game_state_t *
 extern u_int32_t lw6ker_game_state_get_total_rounds (lw6ker_game_state_t *
 						     game_state);
 extern int lw6ker_game_state_is_over (lw6ker_game_state_t * game_state);
+extern int lw6ker_game_state_did_cursor_win (lw6ker_game_state_t * game_state,
+					     u_int16_t cursor_id);
+extern int lw6ker_game_state_get_winner (lw6ker_game_state_t * game_state,
+					 int excluded_team);
+extern int lw6ker_game_state_get_looser (lw6ker_game_state_t * game_state,
+					 int excluded_team);
 extern int32_t lw6ker_game_state_get_nb_active_fighters (lw6ker_game_state_t *
 							 game_state);
 extern int32_t lw6ker_game_state_get_time_elapsed (lw6ker_game_state_t *
@@ -251,12 +268,19 @@ extern lw6ker_fighter_t
   * lw6ker_game_state_get_fighter_unsafe (lw6ker_game_state_t * game_state,
 					  int32_t x, int32_t y, int32_t z);
 extern int lw6ker_game_state_get_zone_potential (lw6ker_game_state_t *
-						 game_state, int i,
+						 game_state, int zone_i,
 						 int team_id);
+extern int lw6ker_game_state_get_charge_per1000 (lw6ker_game_state_t *
+						 game_state, int team_color);
+extern int lw6ker_game_state_get_weapon_per1000_left (lw6ker_game_state_t *
+						      game_state,
+						      int team_color);
+extern int lw6ker_game_state_get_latest_weapon (lw6ker_game_state_t *
+						game_state, int *team_color,
+						int *weapon_id,
+						int *per1000_left);
 
-/*
- * In gamestruct.c
- */
+/* ker-gamestruct.c */
 extern lw6ker_game_struct_t *lw6ker_game_struct_new (lw6map_level_t * level,
 						     lw6sys_progress_t *
 						     progress);
@@ -288,7 +312,19 @@ extern void lw6ker_game_struct_get_zone_info (lw6ker_game_struct_t *
 					      game_struct, int i,
 					      lw6sys_xyz_t * zone_pos,
 					      int *zone_size);
+extern int32_t lw6ker_game_struct_get_zone_id (lw6ker_game_struct_t *
+					       game_struct, int32_t x,
+					       int32_t y, int32_t z);
+extern void lw6ker_game_struct_find_free_slot_near (lw6ker_game_struct_t *
+						    game_struct,
+						    lw6sys_xyz_t * there,
+						    lw6sys_xyz_t here);
 
+/* ker-move.c */
+extern int lw6ker_move_get_best_next_pos (lw6ker_game_state_t * game_state,
+					  lw6sys_xyz_t * next_pos,
+					  lw6sys_xyz_t * current_pos,
+					  int team_color);
 /*
  * in scorearray.c
  */
