@@ -33,15 +33,25 @@
 typedef struct for_all_entries_callback_data_s
 {
   char *map_path;
+  int player_exp;
   int recursive;
   lw6sys_list_callback_func_t callback_func;
   void *func_data;
 } for_all_entries_callback_data_t;
 
+typedef struct _chain_ret_s
+{
+  int exp;
+  lw6ldr_entry_t *found_entry;
+}
+_chain_ret_t;
+
 static lw6ldr_entry_t *
-new_entry (char *absolute_path, char *relative_path, char *entry_path)
+new_entry (char *absolute_path, char *relative_path, char *entry_path,
+	   int player_exp)
 {
   lw6ldr_entry_t *entry = NULL;
+  lw6map_rules_t rules;
   char *map_filename = NULL;
 
   if (entry_path[0] != '.')
@@ -49,6 +59,7 @@ new_entry (char *absolute_path, char *relative_path, char *entry_path)
       entry = (lw6ldr_entry_t *) LW6SYS_CALLOC (sizeof (lw6ldr_entry_t));
       if (entry)
 	{
+	  entry->exp = LW6MAP_RULES_DEFAULT_EXP;
 	  entry->absolute_path =
 	    lw6sys_path_concat (absolute_path, entry_path);
 	  if (entry->absolute_path)
@@ -79,6 +90,15 @@ new_entry (char *absolute_path, char *relative_path, char *entry_path)
 			   */
 			  entry->has_subdirs = 1;
 			}
+		      else
+			{
+			  lw6map_rules_defaults (&rules);
+			  if (lw6ldr_rules_read
+			      (&rules, entry->absolute_path))
+			    {
+			      entry->exp = rules.exp;
+			    }
+			}
 		      LW6SYS_FREE (map_filename);
 		    }
 		}
@@ -90,11 +110,26 @@ new_entry (char *absolute_path, char *relative_path, char *entry_path)
 	}
     }
 
-  if (entry
-      && (!entry->title || !entry->absolute_path || !entry->relative_path))
+  if (entry)
     {
-      lw6ldr_free_entry (entry);
-      entry = NULL;
+      if (!entry->title || !entry->absolute_path || !entry->relative_path)
+	{
+	  lw6ldr_free_entry (entry);
+	  entry = NULL;
+	}
+    }
+
+  if (entry)
+    {
+      if ((entry->exp > player_exp) && (entry->absolute_path != NULL))
+	{
+	  lw6sys_log (LW6SYS_LOG_INFO,
+		      _x_
+		      ("not enough exp to load \"%s\", excluded from list"),
+		      entry->absolute_path);
+	  lw6ldr_free_entry (entry);
+	  entry = NULL;
+	}
     }
 
   if (entry)
@@ -153,13 +188,47 @@ lw6ldr_free_entry (lw6ldr_entry_t * entry)
   LW6SYS_FREE (entry);
 }
 
+/**
+ * lw6ldr_dup_entry
+ *
+ * @entry: the entry to dup
+ *
+ * Dup a map entry.
+ *
+ * Return value: newly allocated object.
+ */
+lw6ldr_entry_t *
+lw6ldr_dup_entry (lw6ldr_entry_t * entry)
+{
+  lw6ldr_entry_t *ret;
+
+  ret = (lw6ldr_entry_t *) LW6SYS_CALLOC (sizeof (lw6ldr_entry_t));
+  if (ret)
+    {
+      memcpy (ret, entry, sizeof (lw6ldr_entry_t));
+
+      ret->title = lw6sys_str_copy (ret->title);
+      ret->absolute_path = lw6sys_str_copy (ret->absolute_path);
+      ret->relative_path = lw6sys_str_copy (ret->relative_path);
+
+      if (!ret->title || !ret->absolute_path || !ret->relative_path)
+	{
+	  lw6ldr_free_entry (ret);
+	  ret = NULL;
+	}
+    }
+
+  return ret;
+}
+
 static void
 add_entry (lw6sys_list_t ** entries, lw6sys_assoc_t ** entries_index,
-	   char *absolute_path, char *relative_path, char *entry_path, int *n)
+	   char *absolute_path, char *relative_path, char *entry_path, int *n,
+	   int player_exp)
 {
   lw6ldr_entry_t *entry = NULL;
 
-  entry = new_entry (absolute_path, relative_path, entry_path);
+  entry = new_entry (absolute_path, relative_path, entry_path, player_exp);
   if (entry)
     {
       if (!lw6sys_assoc_has_key (*entries_index, entry->relative_path))
@@ -182,7 +251,7 @@ add_entry (lw6sys_list_t ** entries, lw6sys_assoc_t ** entries_index,
 
 static void
 add_subdirs (lw6sys_list_t ** entries, lw6sys_assoc_t ** entries_index,
-	     char *absolute_path, char *relative_path)
+	     char *absolute_path, char *relative_path, int player_exp)
 {
 #ifdef LW6_MS_WINDOWS
   WIN32_FIND_DATA dir_entry;
@@ -213,7 +282,7 @@ add_subdirs (lw6sys_list_t ** entries, lw6sys_assoc_t ** entries_index,
       while (!eod)
 	{
 	  add_entry (entries, entries_index, absolute_path, relative_path,
-		     dir_entry.cFileName, &n);
+		     dir_entry.cFileName, &n, player_exp);
 	  memset (&dir_entry, 0, sizeof (WIN32_FIND_DATA));
 	  if (!FindNextFile (dir_handle, &dir_entry))
 	    {
@@ -241,7 +310,8 @@ add_subdirs (lw6sys_list_t ** entries, lw6sys_assoc_t ** entries_index,
 	      if (dir_entry_result && (dir_entry_result == dir_entry))
 		{
 		  add_entry (entries, entries_index, absolute_path,
-			     relative_path, dir_entry->d_name, &n);
+			     relative_path, dir_entry->d_name, &n,
+			     player_exp);
 		}
 	      else
 		{
@@ -283,6 +353,14 @@ entries_sort_callback (lw6sys_list_t ** list_a, lw6sys_list_t ** list_b)
     {
       ret = 1;
     }
+  else if (entry_a->exp < entry_b->exp)
+    {
+      ret = -1;
+    }
+  else if (entry_a->exp > entry_b->exp)
+    {
+      ret = 1;
+    }
   else
     {
       ret = strcmp (entry_a->title, entry_b->title);
@@ -291,21 +369,8 @@ entries_sort_callback (lw6sys_list_t ** list_a, lw6sys_list_t ** list_b)
   return ret;
 }
 
-/**
- * lw6ldr_get_entries
- *
- * @map_path: the map_path environment config variable, delimited path list
- * @relative_path: the relative path to use to find the map directory
- *
- * Lists all maps in a given directory. Returns a list of lw6ldr_entry_t
- * which can contain both directories with subdirs and actual maps. Maps
- * are sorted before being returned, first directories, then maps, sorted
- * in alphabetical order.
- *
- * Return value: a list of dynamically allocated lw6ldr_entry_t.
- */
-lw6sys_list_t *
-lw6ldr_get_entries (char *map_path, char *relative_path)
+static lw6sys_list_t *
+_get_entries (char *map_path, char *relative_path, int player_exp)
 {
   lw6sys_list_t *entries = NULL;
   lw6sys_assoc_t *entries_index = NULL;
@@ -335,7 +400,8 @@ lw6ldr_get_entries (char *map_path, char *relative_path)
 			      if (lw6sys_dir_exists (absolute_path))
 				{
 				  add_subdirs (&entries, &entries_index,
-					       absolute_path, relative_path);
+					       absolute_path, relative_path,
+					       player_exp);
 				}
 			      LW6SYS_FREE (absolute_path);
 			    }
@@ -356,6 +422,33 @@ lw6ldr_get_entries (char *map_path, char *relative_path)
   return entries;
 }
 
+
+/**
+ * lw6ldr_get_entries
+ *
+ * @map_path: the map_path environment config variable, delimited path list
+ * @relative_path: the relative path to use to find the map directory
+ * @user_dir: the user directory
+ *
+ * Lists all maps in a given directory. Returns a list of lw6ldr_entry_t
+ * which can contain both directories with subdirs and actual maps. Maps
+ * are sorted before being returned, first directories, then maps, sorted
+ * in alphabetical order.
+ *
+ * Return value: a list of dynamically allocated lw6ldr_entry_t.
+ */
+lw6sys_list_t *
+lw6ldr_get_entries (char *map_path, char *relative_path, char *user_dir)
+{
+  int player_exp = 0;
+  lw6sys_list_t *entries = NULL;
+
+  lw6cfg_load_exp (user_dir, &player_exp);
+  entries = _get_entries (map_path, relative_path, player_exp);
+
+  return entries;
+}
+
 static void
 for_all_entries_callback_func (void *func_data, void *data)
 {
@@ -371,8 +464,9 @@ for_all_entries_callback_func (void *func_data, void *data)
 	  if (callback_data->recursive)
 	    {
 	      entries =
-		lw6ldr_get_entries (callback_data->map_path,
-				    entry->relative_path);
+		_get_entries (callback_data->map_path,
+			      entry->relative_path,
+			      callback_data->player_exp);
 	      if (entries)
 		{
 		  lw6sys_list_map (entries, for_all_entries_callback_func,
@@ -393,6 +487,7 @@ for_all_entries_callback_func (void *func_data, void *data)
  *
  * @map_path: the map_path environment config variable, delimited path list
  * @relative_path: the relative path to use to find the map directory
+ * @user_dir: the user directory
  * @recursive: if non-zero, map search will recurse in subdirs
  * @callback_func: the function which will be called on each entry
  * @func_data: an extra pointer to pass data to callback_func
@@ -403,18 +498,22 @@ for_all_entries_callback_func (void *func_data, void *data)
  * Return value: none.
  */
 void
-lw6ldr_for_all_entries (char *map_path, char *relative_path, int recursive,
+lw6ldr_for_all_entries (char *map_path, char *relative_path, char *user_dir,
+			int recursive,
 			lw6sys_list_callback_func_t callback_func,
 			void *func_data)
 {
   lw6sys_list_t *entries = NULL;
   for_all_entries_callback_data_t callback_data;
+  int player_exp;
 
   memset (&callback_data, 0, sizeof (for_all_entries_callback_data_t));
-  entries = lw6ldr_get_entries (map_path, relative_path);
+  lw6cfg_load_exp (user_dir, &player_exp);
+  entries = _get_entries (map_path, relative_path, player_exp);
   if (entries)
     {
       callback_data.map_path = map_path;
+      callback_data.player_exp = player_exp;
       callback_data.recursive = recursive;
       callback_data.callback_func = callback_func;
       callback_data.func_data = func_data;
@@ -423,3 +522,64 @@ lw6ldr_for_all_entries (char *map_path, char *relative_path, int recursive,
       lw6sys_list_free (entries);
     }
 }
+
+static void
+_chain_func (void *func_data, void *data)
+{
+  _chain_ret_t *chain_ret = (_chain_ret_t *) func_data;
+  lw6ldr_entry_t *entry = (lw6ldr_entry_t *) data;
+
+  lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("analyzing \"%s\" exp=%d"),
+	      entry->absolute_path, entry->exp);
+
+  if (!(chain_ret->found_entry))
+    {
+      /*
+       * We only search for the case where exps are the same
+       * if map exp is inferior means this is a level we're likely
+       * to have already done, if map exp is greater, there's a bug
+       * or we're cheating.
+       */
+      if (entry->exp == chain_ret->exp)
+	{
+	  lw6sys_log (LW6SYS_LOG_DEBUG,
+		      _x_ ("ok, found \"%s\" exp=%d which is suitable"),
+		      entry->absolute_path, entry->exp);
+	  chain_ret->found_entry = lw6ldr_dup_entry (entry);
+	}
+    }
+}
+
+/**
+ * lw6ldr_chain_entry
+ *
+ * @map_path: the map_path environment config variable, delimited path list
+ * @relative_path: the relative path to use to find the map directory
+ * @user_dir: the user directory
+ *
+ * Gets the next entry
+ * used in test programs.
+ *
+ * Return value: none.
+ */
+lw6ldr_entry_t *
+lw6ldr_chain_entry (char *map_path, char *relative_path, char *user_dir)
+{
+  char *parent = NULL;
+  lw6ldr_entry_t *ret = NULL;
+  _chain_ret_t chain_ret;
+
+  chain_ret.exp = LW6MAP_RULES_MIN_EXP;
+  chain_ret.found_entry = NULL;
+  lw6cfg_load_exp (user_dir, &chain_ret.exp);
+  parent = lw6sys_path_parent (relative_path);
+  if (parent)
+    {
+      lw6ldr_for_all_entries (map_path, parent, user_dir, 0, &_chain_func,
+			      &chain_ret);
+      ret = chain_ret.found_entry;
+      LW6SYS_FREE (parent);
+    }
+
+  return ret;
+}
