@@ -51,6 +51,7 @@
 #define _LW6LDR_FILE_RULES_XML "rules.xml"
 #define _LW6LDR_FILE_HINTS_XML "hints.xml"
 #define _LW6LDR_FILE_STYLE_XML "style.xml"
+#define _LW6LDR_FILE_TEAMS_XML "teams.xml"
 
 typedef struct _lw6ldr_image_bw_s
 {
@@ -90,6 +91,9 @@ extern int
 _lw6ldr_cursor_texture_layer_read_png (lw6map_cursor_texture_layer_t *
 				       cursor_texture_layer, char *png_file);
 
+/* ldr-exp.c */
+extern void _lw6ldr_exp_fix (lw6map_rules_t * rules, int exp);
+
 /*
  * In rgba.c
  */
