@@ -38,6 +38,7 @@
  * @display_h: the height of the display output (resolution)
  * @bench_value: the bench value (depends on computer capacity)
  * @magic_number: arbitrary constant
+ * @user_dir: the user directory
  * @progress: information used to handle the progress bar
  *
  * Loads a map from dist. The default_param and forced_param can contain
@@ -56,7 +57,8 @@
 lw6map_level_t *
 lw6ldr_read (char *dirname, lw6sys_assoc_t * default_param,
 	     lw6sys_assoc_t * forced_param, int display_w, int display_h,
-	     int bench_value, int magic_number, lw6sys_progress_t * progress)
+	     int bench_value, int magic_number, char *user_dir,
+	     lw6sys_progress_t * progress)
 {
   lw6map_level_t *level = NULL;
   int ok = 0;
@@ -66,7 +68,10 @@ lw6ldr_read (char *dirname, lw6sys_assoc_t * default_param,
   lw6sys_progress_t progress_body;
   lw6sys_progress_t progress_color;
   lw6ldr_hints_t hints;
+  lw6map_rules_t rules_tmp;
   lw6ldr_use_t use;
+  int player_exp = LW6MAP_RULES_DEFAULT_EXP;
+  int map_exp = LW6MAP_RULES_DEFAULT_EXP;
 
   lw6sys_log (LW6SYS_LOG_INFO, _x_ ("loading map \"%s\""), dirname);
 
@@ -78,23 +83,51 @@ lw6ldr_read (char *dirname, lw6sys_assoc_t * default_param,
     {
       ok = 1;
 
-      lw6map_rules_defaults (&(level->param.rules));
+      lw6cfg_load_exp (user_dir, &player_exp);
+      lw6map_param_defaults (&(level->param));
       lw6ldr_hints_defaults (&hints);
-      lw6map_style_defaults (&(level->param.style));
       lw6ldr_use_defaults (&use);
 
       ok = ok && lw6ldr_metadata_read (&level->metadata, dirname);
       ok = ok
 	&& lw6map_local_info_set_music_dir (&level->local_info, dirname);
       lw6ldr_rules_update (&(level->param.rules), default_param);
+      level->param.rules.exp = LW6MAP_RULES_DEFAULT_EXP;
       lw6ldr_hints_update (&hints, default_param);
       lw6ldr_style_update (&(level->param.style), default_param);
+      lw6ldr_teams_update (&(level->param.teams), default_param);
       lw6ldr_use_update (&use, default_param);
       if (use.use_rules_xml)
 	{
 	  ok = ok && lw6ldr_rules_read (&level->param.rules, dirname);
+	  map_exp = level->param.rules.exp;
 	  lw6ldr_rules_update (&(level->param.rules), forced_param);
+	  level->param.rules.exp = map_exp;
 	}
+      else
+	{
+	  /*
+	   * OK we don't use rules, but still we need to know
+	   * the "exp" associated to the level...
+	   */
+	  lw6map_rules_defaults (&rules_tmp);
+	  lw6ldr_rules_read (&rules_tmp, dirname);
+	  map_exp = rules_tmp.exp;
+	}
+      // following is important else exp increase won't work
+      level->metadata.vanilla_exp = map_exp;
+
+      level->param.rules.highest_team_color_allowed =
+	lw6sys_min (LW6MAP_MAX_NB_TEAMS - 1,
+		    lw6sys_min (level->param.rules.highest_team_color_allowed,
+				lw6map_exp_get_highest_team_color_allowed
+				(player_exp)));
+      level->param.rules.highest_weapon_allowed =
+	lw6sys_min (LW6MAP_MAX_WEAPON_ID,
+		    lw6sys_min (level->param.rules.highest_weapon_allowed,
+				lw6map_exp_get_highest_weapon_allowed
+				(player_exp)));
+
       if (use.use_hints_xml)
 	{
 	  ok = ok && lw6ldr_hints_read (&hints, dirname);
@@ -102,9 +135,14 @@ lw6ldr_read (char *dirname, lw6sys_assoc_t * default_param,
 	}
       if (use.use_style_xml)
 	{
-	  ok = ok && lw6ldr_style_read (&level->param.style, dirname);
+	  ok = ok && lw6ldr_style_read (&(level->param.style), dirname);
 	  lw6ldr_style_update (&(level->param.style), forced_param);
 	}
+      if (use.use_teams_xml)
+	{
+	  ok = ok && lw6ldr_teams_read (&(level->param.teams), dirname);
+	  lw6ldr_teams_update (&(level->param.teams), forced_param);
+	}
       if (use.use_texture)
 	{
 	  lw6ldr_auto_colors (&level->param.style, &hints);
@@ -150,6 +188,24 @@ lw6ldr_read (char *dirname, lw6sys_assoc_t * default_param,
 	}
       lw6ldr_auto_colors (&level->param.style, &hints);
       level->texture.has_alpha = lw6map_texture_has_alpha (&(level->texture));
+      if (ok)
+	{
+	  if (player_exp >= map_exp)
+	    {
+	      lw6sys_log (LW6SYS_LOG_DEBUG,
+			  _x_
+			  ("OK, can load \"%s\" with exp=%d, requires only %d"),
+			  dirname, player_exp, map_exp);
+	      _lw6ldr_exp_fix (&(level->param.rules), player_exp);
+	    }
+	  else
+	    {
+	      lw6sys_log (LW6SYS_LOG_WARNING,
+			  _x_ ("can't load \"%s\" with exp=%d, requires %d"),
+			  dirname, player_exp, map_exp);
+	      ok = 0;
+	    }
+	}
     }
 
   if (!ok)
@@ -174,6 +230,7 @@ lw6ldr_read (char *dirname, lw6sys_assoc_t * default_param,
  * @display_h: the height of the display output (resolution)
  * @bench_value: the bench value (depends on computer capacity)
  * @magic_number: arbitrary constant
+ * @user_dir: the user directory
  * @progress: information used to handle the progress bar
  *
  * Reads a map from disk, using the map-path value, which is a collection
@@ -188,7 +245,8 @@ lw6ldr_read_relative (char *map_path, char *relative_path,
 		      lw6sys_assoc_t * default_param,
 		      lw6sys_assoc_t * forced_param,
 		      int display_w, int display_h, int bench_value,
-		      int magic_number, lw6sys_progress_t * progress)
+		      int magic_number, char *user_dir,
+		      lw6sys_progress_t * progress)
 {
   lw6map_level_t *ret = NULL;
   lw6sys_list_t *dirs = NULL;
@@ -210,7 +268,7 @@ lw6ldr_read_relative (char *map_path, char *relative_path,
 		      ret =
 			lw6ldr_read (full_dir, default_param, forced_param,
 				     display_w, display_h, bench_value,
-				     magic_number, progress);
+				     magic_number, user_dir, progress);
 		    }
 		}
 	      LW6SYS_FREE (full_dir);
