@@ -49,17 +49,64 @@
 static void
 _check_limits (lw6ldr_hints_t * hints, int *w, int *h)
 {
+  int surface = 0;
+  float coeff = 1.0f;
+
+  surface = (*w) * (*h);
+
+  if (surface > 0)
+    {
+      if (hints->max_map_surface > 0)
+	{
+	  if (surface > hints->max_map_surface)
+	    {
+	      coeff =
+		sqrt (((float) hints->max_map_surface) / ((float) surface));
+	      *w = ((float) (*w)) * coeff;
+	      *h = ((float) (*h)) * coeff;
+	      surface = (*w) * (*h);
+	    }
+	}
+      if (hints->min_map_surface > 0)
+	{
+	  if (surface < hints->min_map_surface)
+	    {
+	      coeff =
+		sqrt (((float) hints->min_map_surface) / ((float) surface));
+	      *w = ((float) (*w)) * coeff;
+	      *h = ((float) (*h)) * coeff;
+	      surface = (*w) * (*h);
+	    }
+	}
+      if (surface > LW6MAP_MAX_BODY_SURFACE)
+	{
+	  coeff =
+	    sqrt (((float) LW6MAP_MAX_BODY_SURFACE) / ((float) surface));
+	  *w = ((float) (*w)) * coeff;
+	  *h = ((float) (*h)) * coeff;
+	  surface = (*w) * (*h);
+	}
+      if (surface < LW6MAP_MIN_BODY_SURFACE)
+	{
+	  coeff =
+	    sqrt (((float) LW6MAP_MIN_BODY_SURFACE) / ((float) surface));
+	  *w = ((float) (*w)) * coeff;
+	  *h = ((float) (*h)) * coeff;
+	  surface = (*w) * (*h);
+	}
+    }
+
   *w = lw6sys_min (*w, hints->max_map_width);
   *h = lw6sys_min (*h, hints->max_map_height);
 
   *w = lw6sys_max (*w, hints->min_map_width);
   *h = lw6sys_max (*h, hints->min_map_height);
 
-  *w = lw6sys_min (*w, LW6MAP_MAX_SIDE);
-  *h = lw6sys_min (*h, LW6MAP_MAX_SIDE);
+  *w = lw6sys_min (*w, LW6MAP_MAX_BODY_WIDTH);
+  *h = lw6sys_min (*h, LW6MAP_MAX_BODY_HEIGHT);
 
-  *w = lw6sys_max (*w, LW6MAP_MIN_SIDE);
-  *h = lw6sys_max (*h, LW6MAP_MIN_SIDE);
+  *w = lw6sys_max (*w, LW6MAP_MIN_BODY_WIDTH);
+  *h = lw6sys_max (*h, LW6MAP_MIN_BODY_HEIGHT);
 }
 
 static float
@@ -246,8 +293,8 @@ lw6ldr_resampler_init (lw6ldr_resampler_t * resampler,
 	      f = 1.0f;
 	      if (hints->downsize_using_bench_value && capacity < required)
 		{
-		  while (capacity < required && tmp_w > LW6MAP_MIN_SIDE
-			 && tmp_h > LW6MAP_MIN_SIDE)
+		  while (capacity < required && tmp_w > LW6MAP_MIN_BODY_WIDTH
+			 && tmp_h > LW6MAP_MIN_BODY_HEIGHT)
 		    {
 		      f *= _RESAMPLER_DOWNSIZE;
 		      tmp_w = target_w * f;
@@ -270,8 +317,8 @@ lw6ldr_resampler_init (lw6ldr_resampler_t * resampler,
 		}
 	      else if (hints->upsize_using_bench_value && capacity > required)
 		{
-		  while (capacity < required && tmp_w < LW6MAP_MAX_SIDE
-			 && tmp_h < LW6MAP_MAX_SIDE)
+		  while (capacity < required && tmp_w < LW6MAP_MAX_BODY_WIDTH
+			 && tmp_h < LW6MAP_MAX_BODY_HEIGHT)
 		    {
 		      f *= _RESAMPLER_UPSIZE;
 		      tmp_w = target_w * f;
