@@ -44,6 +44,7 @@ lw6ldr_use_defaults (lw6ldr_use_t * use)
   use->use_rules_xml = LW6LDR_USE_DEFAULT_USE_RULES_XML;
   use->use_hints_xml = LW6LDR_USE_DEFAULT_USE_HINTS_XML;
   use->use_style_xml = LW6LDR_USE_DEFAULT_USE_STYLE_XML;
+  use->use_teams_xml = LW6LDR_USE_DEFAULT_USE_TEAMS_XML;
   use->use_music_file = LW6LDR_USE_DEFAULT_USE_MUSIC_FILE;
 }
 
@@ -78,6 +79,10 @@ lw6ldr_use_set (lw6ldr_use_t * use, char *key, char *value)
     {
       use->use_style_xml = lw6sys_atob (value);
     }
+  else if (lw6sys_arg_match (LW6DEF_USE_TEAMS_XML, key))
+    {
+      use->use_teams_xml = lw6sys_atob (value);
+    }
   else if (lw6sys_arg_match (LW6DEF_USE_MUSIC_FILE, key))
     {
       use->use_music_file = lw6sys_atob (value);
