@@ -27,7 +27,7 @@
  * This is the main Liquid War 6 header file.
  */
 
-#define LW6_VERSION "0.0.10beta"
+#define LW6_VERSION "0.0.11beta"
 
 #include <pthread.h>
 #include <libguile.h>
@@ -57,6 +57,7 @@
 #include "srv/srv.h"
 #include "dat/dat.h"
 #include "p2p/p2p.h"
+#include "scm/scm.h"
 
 typedef struct lw6_smob_types_s
 {
@@ -235,6 +236,7 @@ extern void lw6_print_list_map ();
 extern void lw6_print_list_map_hints ();
 extern void lw6_print_list_map_rules ();
 extern void lw6_print_list_map_style ();
+extern void lw6_print_list_map_teams ();
 extern void lw6_print_list_funcs ();
 extern void lw6_print_list_hooks ();
 extern void lw6_print_list_advanced ();
