@@ -148,12 +148,12 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 		&& lw6ker_test (1) && DYN_TEST && lw6bot_test (1)
 		&& lw6cns_test (1)
 		&& lw6hlp_test (1) && lw6cfg_test (1) && lw6ldr_test (1)
-		&& lw6tsk_test (1) && lw6gui_test (1) && lw6gfx_test (1)
-		&& lw6dsp_test (1) && lw6snd_test (1) && lw6img_test (1)
-		&& lw6pil_test (1) && lw6net_test (1) && lw6nod_test (1)
-		&& lw6cnx_test (1) && lw6msg_test (1) && lw6cli_test (1)
-		&& lw6srv_test (1) && lw6dat_test (1) && lw6p2p_test (1)
-		&& lw6_test (1);
+		&& lw6tsk_test (1) && lw6gui_test (1) && lw6vox_test (1)
+		&& lw6gfx_test (1) && lw6dsp_test (1) && lw6snd_test (1)
+		&& lw6img_test (1) && lw6pil_test (1) && lw6net_test (1)
+		&& lw6nod_test (1) && lw6cnx_test (1) && lw6msg_test (1)
+		&& lw6cli_test (1) && lw6srv_test (1) && lw6dat_test (1)
+		&& lw6p2p_test (1) && lw6scm_test (1) && lw6_test (1);
 	      if (ret)
 		{
 		  lw6sys_log (LW6SYS_LOG_NOTICE, _("all tests SUCCESSFULL!"));
@@ -182,12 +182,12 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 		&& lw6ker_test (0) && DYN_TEST && lw6bot_test (0)
 		&& lw6cns_test (0)
 		&& lw6hlp_test (0) && lw6cfg_test (0) && lw6ldr_test (0)
-		&& lw6tsk_test (0) && lw6gui_test (0) && lw6gfx_test (0)
-		&& lw6dsp_test (0) && lw6snd_test (0) && lw6img_test (0)
-		&& lw6pil_test (0) && lw6net_test (0) && lw6nod_test (0)
-		&& lw6cnx_test (0) && lw6msg_test (0) && lw6cli_test (0)
-		&& lw6srv_test (0) && lw6dat_test (0) && lw6p2p_test (0)
-		&& lw6_test (0);
+		&& lw6tsk_test (0) && lw6gui_test (0) && lw6vox_test (0)
+		&& lw6gfx_test (0) && lw6dsp_test (0) && lw6snd_test (0)
+		&& lw6img_test (0) && lw6pil_test (0) && lw6net_test (0)
+		&& lw6nod_test (0) && lw6cnx_test (0) && lw6msg_test (0)
+		&& lw6cli_test (0) && lw6srv_test (0) && lw6dat_test (0)
+		&& lw6p2p_test (0) && lw6scm_test (0) && lw6_test (0);
 	      if (ret)
 		{
 		  lw6sys_log (LW6SYS_LOG_NOTICE,
@@ -331,6 +331,11 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	  lw6_print_list_map_style ();
 	  (*run_game) = 0;
 	}
+      else if (lw6sys_arg_match (LW6DEF_LIST_MAP_TEAMS, argv[i]))
+	{
+	  lw6_print_list_map_teams ();
+	  (*run_game) = 0;
+	}
       else if (lw6sys_arg_match (LW6DEF_LIST_FUNCS, argv[i]))
 	{
 	  lw6_print_list_funcs ();
@@ -366,6 +371,11 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	  lw6ldr_print_example_style_xml (stdout);
 	  (*run_game) = 0;
 	}
+      else if (lw6sys_arg_match (LW6DEF_EXAMPLE_TEAMS_XML, argv[i]))
+	{
+	  lw6ldr_print_example_teams_xml (stdout);
+	  (*run_game) = 0;
+	}
       /*
        * Show any build_XXX LW specific value
        */
@@ -563,6 +573,11 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	  printf ("%s\n", lw6sys_build_get_enable_mod_http ());
 	  (*run_game) = 0;
 	}
+      else if (lw6sys_arg_match (LW6DEF_SHOW_BUILD_ENABLE_OPENMP, argv[i]))
+	{
+	  printf ("%s\n", lw6sys_build_get_enable_openmp ());
+	  (*run_game) = 0;
+	}
       else if (lw6sys_arg_match (LW6DEF_SHOW_BUILD_ENABLE_OPTIMIZE, argv[i]))
 	{
 	  printf ("%s\n", lw6sys_build_get_enable_optimize ());
