@@ -428,6 +428,7 @@ lw6_print_modules ()
   printf ("enable-mod-csound: %s\n", lw6sys_build_get_enable_mod_csound ());
   printf ("enable-mod-ogg: %s\n", lw6sys_build_get_enable_mod_ogg ());
   printf ("enable-mod-http: %s\n", lw6sys_build_get_enable_mod_http ());
+  printf ("enable-openmp: %s\n", lw6sys_build_get_enable_openmp ());
   printf ("enable-optimize: %s\n", lw6sys_build_get_enable_optimize ());
   printf ("enable-allinone: %s\n", lw6sys_build_get_enable_allinone ());
   printf ("enable-fullstatic: %s\n", lw6sys_build_get_enable_fullstatic ());
@@ -684,7 +685,7 @@ lw6_print_list_map_hints ()
 /**
  * lw6_print_list_map_style
  *
- * Displays the list of 'amp style' options.
+ * Displays the list of 'map style' options.
  *
  * Return value: none
  */
@@ -701,6 +702,26 @@ lw6_print_list_map_style ()
     }
 }
 
+/**
+ * lw6_print_list_map_teams
+ *
+ * Displays the list of 'map teams' options.
+ *
+ * Return value: none
+ */
+void
+lw6_print_list_map_teams ()
+{
+  lw6sys_list_t *list;
+
+  list = lw6hlp_list_map_teams ();
+  if (list)
+    {
+      lw6hlp_print_keyword (&list, stdout);
+      lw6sys_list_free (list);
+    }
+}
+
 /**
  * lw6_print_list_funcs
  *
