@@ -36,6 +36,9 @@ push_metadata (lw6sys_hexa_serializer_t * hexa_serializer,
     && lw6sys_hexa_serializer_push_str (hexa_serializer, metadata->title);
   ret = ret
     && lw6sys_hexa_serializer_push_str (hexa_serializer, metadata->readme);
+  ret = ret
+    && lw6sys_hexa_serializer_push_int32 (hexa_serializer,
+					  metadata->vanilla_exp);
 
   return ret;
 }
@@ -371,6 +374,9 @@ push_param (lw6sys_hexa_serializer_t * hexa_serializer,
   ret = ret
     && lw6sys_hexa_serializer_push_str (hexa_serializer,
 					param->style.music_exclude);
+  ret = ret
+    && lw6sys_hexa_serializer_push_int32 (hexa_serializer,
+					  param->style.waves);
 
   return ret;
 }
@@ -422,6 +428,9 @@ pop_metadata (lw6sys_hexa_serializer_t * hexa_serializer,
     && lw6sys_hexa_serializer_pop_str (hexa_serializer, &(metadata->title));
   ret = ret
     && lw6sys_hexa_serializer_pop_str (hexa_serializer, &(metadata->readme));
+  ret = ret
+    && lw6sys_hexa_serializer_pop_int32 (hexa_serializer,
+					 &(metadata->vanilla_exp));
 
   return ret;
 }
@@ -524,13 +533,16 @@ pop_body (lw6sys_hexa_serializer_t * hexa_serializer, lw6map_body_t * body)
 {
   int ret = 1;
   int layer;
+  lw6sys_whd_t shape_min =
+    { LW6MAP_MIN_BODY_WIDTH, LW6MAP_MIN_BODY_HEIGHT, LW6MAP_MIN_BODY_DEPTH };
+  lw6sys_whd_t shape_max =
+    { LW6MAP_MAX_BODY_WIDTH, LW6MAP_MAX_BODY_HEIGHT, LW6MAP_MAX_BODY_DEPTH };
 
   ret = ret
     && lw6sys_hexa_serializer_pop_int32 (hexa_serializer, &(body->checksum));
   ret = ret
     && lw6sys_hexa_serializer_pop_whd (hexa_serializer, &(body->shape));
-  if (lw6sys_shape_check_min_max_whd
-      (&body->shape, LW6MAP_MIN_SIDE, LW6MAP_MAX_SIDE, LW6MAP_MAX_DEPTH))
+  if (lw6sys_shape_check_min_max_whd (&body->shape, &shape_min, &shape_max))
     {
       for (layer = 0; layer < body->shape.d; ++layer)
 	{
@@ -585,10 +597,10 @@ pop_texture (lw6sys_hexa_serializer_t * hexa_serializer,
   ret = ret
     && lw6sys_hexa_serializer_pop_int32 (hexa_serializer,
 					 &(texture->has_alpha));
-  if (texture->w >= LW6MAP_MIN_SIDE && texture->w <= LW6MAP_MAX_SIDE
-      && texture->h >= LW6MAP_MIN_SIDE && texture->h <= LW6MAP_MAX_SIDE
-      && texture->w * texture->h >= LW6MAP_MIN_SURFACE
-      && texture->w * texture->h <= LW6MAP_MAX_SURFACE)
+  if (texture->w >= LW6MAP_MIN_TEXTURE_WIDTH
+      && texture->w <= LW6MAP_MAX_TEXTURE_WIDTH
+      && texture->h >= LW6MAP_MIN_TEXTURE_HEIGHT
+      && texture->h <= LW6MAP_MAX_TEXTURE_HEIGHT)
     {
       texture->data =
 	(lw6sys_color_8_t *) LW6SYS_CALLOC (texture->w *
@@ -856,6 +868,9 @@ pop_param (lw6sys_hexa_serializer_t * hexa_serializer, lw6map_param_t * param)
   ret = ret
     && lw6sys_hexa_serializer_pop_str (hexa_serializer,
 				       &(param->style.music_exclude));
+  ret = ret
+    && lw6sys_hexa_serializer_pop_int32 (hexa_serializer,
+					 &(param->style.waves));
 
   return ret;
 }
