@@ -29,14 +29,16 @@
 #include "map.h"
 
 #define TEST_MAP_NB_LAYERS 2
-#define TEST_MAP_WIDTH 8
-#define TEST_MAP_HEIGHT 6
+#define TEST_MAP_WIDTH 20
+#define TEST_MAP_HEIGHT 15
 #define TEST_MAP_NOISE_PERCENT 30
 #define TEST_RULES_KEY LW6DEF_TOTAL_TIME
 #define TEST_RULES_VALUE 3600
-#define TEST_RULES_CHECKSUM 0xca71ce87
+#define TEST_RULES_CHECKSUM 0x8409507b
 #define TEST_STYLE_KEY LW6DEF_ZOOM
 #define TEST_STYLE_VALUE "1.0"
+#define TEST_TEAMS_KEY LW6DEF_BOT_IQ
+#define TEST_TEAMS_VALUE "99"
 #define TEST_COORDS_NB 5
 #define TEST_COORDS_W 100
 #define TEST_COORDS_H 50
@@ -101,6 +103,8 @@ test_color ()
 
   {
     lw6map_color_couple_t color_couple;
+    int i, j;
+    char *key;
 
     color_couple.bg = LW6SYS_COLOR_8_WHITE;
     color_couple.fg = LW6SYS_COLOR_8_BLACK;
@@ -113,6 +117,28 @@ test_color ()
 		    ("color_is_same pretending colors are different, while they should be equal"));
 	ret = 0;
       }
+
+    for (i = 0; i < LW6MAP_MAX_NB_TEAMS; ++i)
+      {
+	key = lw6map_team_color_index_to_key (i);
+	if (key)
+	  {
+	    j = lw6map_team_color_key_to_index (key);
+	    if (i == j)
+	      {
+		lw6sys_log (LW6SYS_LOG_NOTICE,
+			    _x_ ("team_color key for %d is \"%s\""), i, key);
+	      }
+	    else
+	      {
+		ret = 0;
+	      }
+	  }
+	else
+	  {
+	    ret = 0;
+	  }
+      }
   }
 
   LW6SYS_TEST_FUNCTION_END;
@@ -381,6 +407,30 @@ test_dup ()
   return ret;
 }
 
+/*
+ * Testing exp
+ */
+static int
+test_exp ()
+{
+  int ret = 1;
+  LW6SYS_TEST_FUNCTION_BEGIN;
+
+  {
+    int i = 0;
+
+    for (i = LW6MAP_RULES_MIN_EXP; i <= LW6MAP_RULES_MAX_EXP; ++i)
+      {
+	lw6sys_log (LW6SYS_LOG_NOTICE,
+		    _x_ ("exp=%d highest_color=%d highest_weapon=%d"), i,
+		    lw6map_exp_get_highest_team_color_allowed (i),
+		    lw6map_exp_get_highest_weapon_allowed (i));
+      }
+  }
+  LW6SYS_TEST_FUNCTION_END;
+  return ret;
+}
+
 /*
  * Testing hexa
  */
@@ -564,6 +614,53 @@ test_style ()
   return ret;
 }
 
+static int
+test_teams ()
+{
+  int ret = 1;
+  LW6SYS_TEST_FUNCTION_BEGIN;
+
+  {
+    lw6map_teams_t *teams;
+    char *value;
+
+    teams = (lw6map_teams_t *) LW6SYS_CALLOC (sizeof (lw6map_teams_t));
+    if (teams)
+      {
+	lw6map_teams_set (teams, TEST_TEAMS_KEY, TEST_TEAMS_VALUE);
+	value = lw6map_teams_get (teams, TEST_TEAMS_KEY);
+	if (value)
+	  {
+	    lw6sys_log (LW6SYS_LOG_NOTICE,
+			_x_ ("map teams for key \"%s\" is \"%s\""),
+			TEST_TEAMS_KEY, value);
+	    LW6SYS_FREE (value);
+	  }
+	else
+	  {
+	    lw6sys_log (LW6SYS_LOG_WARNING,
+			_x_ ("can't find teams key \"%s\""), TEST_TEAMS_KEY);
+	    ret = 0;
+	  }
+	if (!lw6map_teams_is_same (teams, teams))
+	  {
+	    lw6sys_log (LW6SYS_LOG_WARNING,
+			_x_ ("map teams comparison failed"));
+	    ret = 0;
+	  }
+	lw6map_teams_clear (teams);
+	LW6SYS_FREE (teams);
+      }
+    else
+      {
+	ret = 0;
+      }
+  }
+
+  LW6SYS_TEST_FUNCTION_END;
+  return ret;
+}
+
 static int
 test_local_info ()
 {
@@ -629,6 +726,43 @@ test_meta_layer ()
   return ret;
 }
 
+static int
+test_weapon ()
+{
+  int ret = 1;
+  LW6SYS_TEST_FUNCTION_BEGIN;
+
+  {
+    int i, j;
+    char *key;
+
+    for (i = 0; i <= LW6MAP_MAX_WEAPON_ID; ++i)
+      {
+	key = lw6map_weapon_index_to_key (i);
+	if (key)
+	  {
+	    j = lw6map_weapon_key_to_index (key);
+	    if (i == j)
+	      {
+		lw6sys_log (LW6SYS_LOG_NOTICE,
+			    _x_ ("weapon key for %d is \"%s\""), i, key);
+	      }
+	    else
+	      {
+		ret = 0;
+	      }
+	  }
+	else
+	  {
+	    ret = 0;
+	  }
+      }
+  }
+
+  LW6SYS_TEST_FUNCTION_END;
+  return ret;
+}
+
 /**
  * lw6map_test
  *
@@ -653,9 +787,9 @@ lw6map_test (int mode)
     }
 
   ret = test_new () && test_color () && test_coords ()
-    && test_defaults () && test_dup ()
+    && test_defaults () && test_dup () && test_exp ()
     && test_hexa () && test_local_info () && test_meta_layer ()
-    && test_rules () && test_style ();
+    && test_rules () && test_style () && test_teams () && test_weapon ();
 
   return ret;
 }
