@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -546,7 +546,7 @@ lw6net_last_error ()
   ret = WSAGetLastError ();
   if (ret || errno)
     {
-      lw6sys_log (LW6SYS_LOG_DEBUG, _("winsock error %d \"%s\""), ret,
+      lw6sys_log (LW6SYS_LOG_INFO, _x_ ("winsock error %d \"%s\""), ret,
 		  _lw6net_wsa_str (ret));
     }
 #else
@@ -554,7 +554,7 @@ lw6net_last_error ()
 
   if (ret)
     {
-      lw6sys_log (LW6SYS_LOG_DEBUG, _("socket error %d"), ret);
+      lw6sys_log (LW6SYS_LOG_INFO, _x_ ("socket error %d"), ret);
     }
 #endif
 
