@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -47,67 +47,44 @@ typedef struct _lw6net_const_data_s
   int listen_backlog;
   int chunk_size;
   int line_size;
-  float line_delay;
-  /*  char *httpd_log;
-     int listen_backlog;
-     int chunk_size;
-     int line_size;
-     float protocol_delay;
-     float line_delay;
-     float http_delay;
-     char *http_status;
-     char *http_status_200;
-     char *http_status_404;
-     char *http_status_500;
-     char *http_header_content_type;
-     char *http_header_content_length;
-     char *http_header_last_modified;
-     char *http_header_connection;
-     char *http_header_server;
-     char *http_header_x_powered_by;
-     char *content_type_txt;
-     char *content_type_html;
-     char *content_type_jpeg;
-     char *content_type_ico;
-     char *content_type_css;
-     char *http_request_pattern;
-     char *uri_root;
-     char *uri_index;
-     char *uri_robots;
-     char *uri_favicon;
-     char *uri_more;
-     char *uri_style;
-     char *uri_gnu;
-     char *uri_gpl;
-     char *uri_screenshot;
-     char *uri_status;
-     char *uri_list;
-     char *screenshot_filename;
-     int screenshot_refresh_delay;
-     int screenshot_width;
-     int screenshot_height;
-     int screenshot_quality;
-     char *template_pattern;
-     char *template_format_version;
-     char *template_format_compiled;
-   */
+  int line_delay_msec;
+  int dns_cache_hash_size;
 }
 _lw6net_const_data_t;
 
-typedef struct _lw6net_socket_counters_s
+typedef struct _lw6net_counters_s
 {
+  void *spinlock;
   int open_counter;
   int close_counter;
+  int64_t sent_bytes;
+  int64_t received_bytes;
 }
-_lw6net_socket_counters_t;
+_lw6net_counters_t;
+
+typedef struct _lw6net_log_s
+{
+  char *tcp_recv_filename;
+  char *tcp_send_filename;
+  char *udp_recv_filename;
+  char *udp_send_filename;
+}
+_lw6net_log_t;
+
+typedef struct _lw6net_dns_s
+{
+  void *dns_gethostbyname_mutex;
+  void *dns_cache_mutex;
+  lw6sys_hash_t *dns_cache;
+}
+_lw6net_dns_t;
 
 typedef struct _lw6net_context_s
 {
   _lw6net_const_data_t const_data;
-  _lw6net_socket_counters_t socket_counters;
-  lw6sys_assoc_t *threads;
-  int server_sock;
-  void *dns_mutex;
+  _lw6net_counters_t counters;
+  _lw6net_log_t log;
+  _lw6net_dns_t dns;
 }
 _lw6net_context_t;
 
@@ -131,32 +108,45 @@ extern int _lw6net_inet_aton (struct in_addr *in, char *ip);
 /*
  * In const.c
  */
-extern int _lw6net_const_init (int argc, char *argv[]);
-extern void _lw6net_const_quit ();
+extern int _lw6net_const_init (int argc, char *argv[],
+			       _lw6net_const_data_t * const_data);
+extern void _lw6net_const_quit (_lw6net_const_data_t * const_data);
+
+/* net-counters.c */
+extern int _lw6net_counters_init (int argc, char *argv[],
+				  _lw6net_counters_t * counters);
+extern void _lw6net_counters_quit (_lw6net_counters_t * counters);
+extern void _lw6net_counters_register_socket (_lw6net_counters_t * counters);
+extern void _lw6net_counters_unregister_socket (_lw6net_counters_t *
+						counters);
+extern void _lw6net_counters_register_send (_lw6net_counters_t * counters,
+					    int bytes);
+extern void _lw6net_counters_register_recv (_lw6net_counters_t * counters,
+					    int bytes);
 
 /* net-dns.c */
-extern int _lw6net_dns_init ();
-extern void _lw6net_dns_quit ();
+extern int _lw6net_dns_init (_lw6net_dns_t * dns, int dns_cache_hash_size);
+extern void _lw6net_dns_quit (_lw6net_dns_t * dns);
 
 // net-error.c
 #ifdef LW6_MS_WINDOWS
 extern char *_lw6net_wsa_str (int wsa_int);
 #endif
 
-/*
- * In socket.c
- */
-extern int _lw6net_socket_init ();
-extern void _lw6net_socket_quit ();
+/* net-log.c */
+extern int _lw6net_log_init (int argc, char *argv[], _lw6net_log_t * log,
+			     int net_log);
+extern void _lw6net_log_quit (_lw6net_log_t * log);
+extern int _lw6net_log_tcp_recv (_lw6net_log_t * log, char *buf, int len);
+extern int _lw6net_log_tcp_send (_lw6net_log_t * log, char *buf, int len);
+extern int _lw6net_log_udp_recv (_lw6net_log_t * log, char *buf, int len);
+extern int _lw6net_log_udp_send (_lw6net_log_t * log, char *buf, int len);
+
+/* net-socket.c */
 extern int _lw6net_socket_bind (char *ip, int port, int protocol);
 
-/*
- * In thread.c
- */
-extern int _lw6net_thread_init ();
-extern void _lw6net_thread_quit ();
-extern int _lw6net_thread_register (void *handler);
-extern int _lw6net_thread_unregister (void *handler);
-extern int _lw6net_thread_vacuum ();
+/* net-tcp.c */
+extern void _lw6net_delay_msec_to_timeval (struct timeval *tv,
+					   int delay_msec);
 
 #endif
