@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -34,7 +34,17 @@
 #define CHAR_0 '\0'
 #define TRAIL_SIZE 2
 
+#ifdef LW6_MS_WINDOWS
+/*
+ * Using CR/LF instead of LF only under MS-Windows is clearly
+ * *not* mandatory but... it has a "je-ne-sais-quoi" to keep
+ * using despite everyone else does use LF only with success,
+ * so it's kept here for nothing but style ;)
+ */
 static char trail[TRAIL_SIZE + 1] = { CHAR_CR, CHAR_LF, CHAR_0 };
+#else
+static char trail[TRAIL_SIZE + 1] = { CHAR_LF, CHAR_0, CHAR_0 };
+#endif
 
 /**
  * lw6net_recv_line_tcp:
@@ -56,26 +66,28 @@ lw6net_recv_line_tcp (int sock)
 {
   char *ret = NULL;
   int line_size = 0;
-  float line_delay;
+  int line_delay;
   int wanted_size;
   int available_size;
   int trail_size;
   char *pos_lf;
-  char line_buf[LW6NET_MAX_PACKET_SIZE + 3];
+  char line_buf[LW6NET_MAX_LINE_SIZE + TRAIL_SIZE + 1];
 
   if (sock >= 0)
     {
       line_size = _lw6net_global_context->const_data.line_size;
-      line_delay = _lw6net_global_context->const_data.line_delay;
-      memset (line_buf, 0, line_size + 3);
-      available_size = lw6net_tcp_peek (sock, line_buf, line_size + 2, 0.0f);
+      line_delay = _lw6net_global_context->const_data.line_delay_msec;
+      memset (line_buf, 0, line_size + TRAIL_SIZE + 1);
+      available_size =
+	lw6net_tcp_peek (sock, line_buf, line_size + TRAIL_SIZE, 0.0f);
       if (available_size > 0)
 	{
 	  pos_lf = strchr (line_buf, CHAR_LF);
 	  if (pos_lf)
 	    {
 	      trail_size = (pos_lf > line_buf
-			    && pos_lf[-1] == CHAR_CR) ? 2 : 1;
+			    && pos_lf[-1] ==
+			    CHAR_CR) ? TRAIL_SIZE : TRAIL_SIZE - 1;
 	      wanted_size = (pos_lf + 1 - line_buf);
 	      pos_lf[1 - trail_size] = CHAR_0;
 	      ret = lw6sys_str_copy (line_buf);
@@ -110,25 +122,25 @@ lw6net_send_line_tcp (int sock, char *line)
 {
   int ret = 0;
   int line_size = 0;
-  float line_delay;
+  int line_delay;
   int wanted_size = 0;
 
   if (sock >= 0 && line)
     {
       line_size = _lw6net_global_context->const_data.line_size;
-      line_delay = _lw6net_global_context->const_data.line_delay;
+      line_delay = _lw6net_global_context->const_data.line_delay_msec;
       wanted_size = strlen (line);
       if (wanted_size > line_size)
 	{
 	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _("stripping line \"%s\" of size %d, limit is %d"),
+		      _x_ ("stripping line \"%s\" of size %d, limit is %d"),
 		      line, wanted_size, line_size);
 	  wanted_size = line_size;
 	}
 
       ret =
 	lw6net_tcp_send (sock, line, wanted_size, line_delay, 0)
-	&& lw6net_tcp_send (sock, trail, TRAIL_SIZE, line_delay, 0);
+	&& lw6net_tcp_send (sock, trail, strlen (trail), line_delay, 0);
     }
 
   return ret;
@@ -167,14 +179,16 @@ lw6net_recv_line_udp (int sock, char **incoming_ip, int *incoming_port)
    * can be called by many threads in polling loops (think of broadcast)
    * and allocating memory for this causes bottlenecks in bazooka functions.
    */
-  char line_buf[LW6NET_MAX_PACKET_SIZE + 3];
+  char line_buf[LW6NET_MAX_LINE_SIZE + TRAIL_SIZE + 1];
 
   if (sock >= 0)
     {
-      line_size = _lw6net_global_context->const_data.line_size;
-      memset (line_buf, 0, line_size + 3);
+      line_size =
+	lw6sys_min (_lw6net_global_context->const_data.line_size,
+		    LW6NET_PPPOE_MTU - TRAIL_SIZE);
+      memset (line_buf, 0, line_size + TRAIL_SIZE + 1);
       available_size =
-	lw6net_udp_peek (sock, line_buf, line_size + 2,
+	lw6net_udp_peek (sock, line_buf, line_size + TRAIL_SIZE,
 			 incoming_ip, incoming_port);
       if (incoming_ip && (*incoming_ip))
 	{
@@ -186,7 +200,8 @@ lw6net_recv_line_udp (int sock, char **incoming_ip, int *incoming_port)
 	  if (pos_lf)
 	    {
 	      trail_size = (pos_lf > line_buf
-			    && pos_lf[-1] == CHAR_CR) ? 2 : 1;
+			    && pos_lf[-1] ==
+			    CHAR_CR) ? TRAIL_SIZE : TRAIL_SIZE - 1;
 	      pos_lf[1 - trail_size] = CHAR_0;
 	      ret = lw6sys_str_copy (line_buf);
 	      if (ret)
@@ -233,7 +248,7 @@ lw6net_recv_lines_udp (int sock, char **incoming_ip, int *incoming_port)
   int available_size;
   int trail_size;
   char *pos_lf;
-  char line_buf[LW6NET_MAX_PACKET_SIZE + 3];
+  char line_buf[LW6NET_MAX_LINE_SIZE + TRAIL_SIZE + 1];
   char *seek = NULL;
   int no_lf_at_very_end = 0;
 
@@ -242,10 +257,12 @@ lw6net_recv_lines_udp (int sock, char **incoming_ip, int *incoming_port)
       ret = lw6sys_list_new (lw6sys_free_callback);
       if (ret)
 	{
-	  line_size = _lw6net_global_context->const_data.line_size;
-	  memset (line_buf, 0, line_size + 3);
+	  line_size =
+	    lw6sys_min (_lw6net_global_context->const_data.line_size,
+			LW6NET_PPPOE_MTU - TRAIL_SIZE);
+	  memset (line_buf, 0, line_size + TRAIL_SIZE + 1);
 	  available_size =
-	    lw6net_udp_peek (sock, line_buf, line_size + 2,
+	    lw6net_udp_peek (sock, line_buf, line_size + TRAIL_SIZE,
 			     incoming_ip, incoming_port);
 	  if (incoming_ip && (*incoming_ip))
 	    {
@@ -260,7 +277,8 @@ lw6net_recv_lines_udp (int sock, char **incoming_ip, int *incoming_port)
 		  if (pos_lf)
 		    {
 		      trail_size = (pos_lf > seek
-				    && pos_lf[-1] == CHAR_CR) ? 2 : 1;
+				    && pos_lf[-1] ==
+				    CHAR_CR) ? TRAIL_SIZE : TRAIL_SIZE - 1;
 		      pos_lf[1 - trail_size] = CHAR_0;
 		      line = lw6sys_str_copy (seek);
 		      if (line)
@@ -297,7 +315,7 @@ lw6net_recv_lines_udp (int sock, char **incoming_ip, int *incoming_port)
       if (ret)
 	{
 	  lw6sys_log (LW6SYS_LOG_DEBUG,
-		      _
+		      _x_
 		      ("no lf at the very end of the sequence of lines, message was probably truncated"));
 	  lw6sys_list_free (ret);
 	  ret = NULL;
@@ -335,15 +353,15 @@ lw6net_send_line_udp (int sock, char *line, char *ip, int port)
 {
   int ret = 0;
   int line_size = 0;
-  float line_delay;
   int wanted_size = 0;
   char *copied_line;
   char *trailed_line;
 
   if (sock >= 0 && line)
     {
-      line_size = _lw6net_global_context->const_data.line_size;
-      line_delay = _lw6net_global_context->const_data.line_delay;
+      line_size =
+	lw6sys_min (_lw6net_global_context->const_data.line_size,
+		    LW6NET_PPPOE_MTU - TRAIL_SIZE);
       copied_line = lw6sys_str_copy (line);
       if (copied_line)
 	{
@@ -351,7 +369,8 @@ lw6net_send_line_udp (int sock, char *line, char *ip, int port)
 	  if (wanted_size > line_size)
 	    {
 	      lw6sys_log (LW6SYS_LOG_WARNING,
-			  _("stripping line \"%s\" of size %d, limit is %d"),
+			  _x_
+			  ("stripping line \"%s\" of size %d, limit is %d"),
 			  copied_line, wanted_size, line_size);
 	      lw6sys_str_truncate (copied_line, line_size);
 	    }
