@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -27,8 +27,6 @@
 #include "p2p.h"
 #include "p2p-internal.h"
 
-#define _UDP_MINIMAL_BUF_SIZE 1
-
 static u_int32_t seq_id = 0;
 
 /**
@@ -41,13 +39,16 @@ static u_int32_t seq_id = 0;
  * @server_backends: the list of server backends to use
  * @bind_ip: the IP address to bind on
  * @bind_port: the IP port to listen on
- * @node_id: the server unique ID
+ * @broadcast: wether broadcast is allowed on this node
  * @public_url: the public URL we want to show
- * @password: the password to use
  * @title: the title of the node
  * @description: the description of the node
+ * @password: the password to use
  * @bench: the bench of the node (its power)
+ * @open_relay: act as an open relay or not
  * @known_nodes: list of already known nodes
+ * @network_reliability: drop 1 packet out of X
+ * @trojan: act as a stupid trojan to test out automatic kick-off 
  *
  * Creates a new "pear to pear" node. This will fire the server
  * and allow client access, on demand. A lot of stuff can be done
@@ -58,27 +59,30 @@ static u_int32_t seq_id = 0;
 lw6p2p_node_t *
 lw6p2p_node_new (int argc, char *argv[], lw6p2p_db_t * db,
 		 char *client_backends, char *server_backends, char *bind_ip,
-		 int bind_port, u_int64_t node_id, char *public_url,
-		 char *password, char *title, char *description, int bench,
-		 char *known_nodes)
+		 int bind_port, int broadcast,
+		 char *public_url, char *title,
+		 char *description, char *password, int bench, int open_relay,
+		 char *known_nodes, int network_reliability, int trojan)
 {
   return (lw6p2p_node_t *) _lw6p2p_node_new (argc, argv, (_lw6p2p_db_t *) db,
 					     client_backends, server_backends,
-					     bind_ip, bind_port, node_id,
-					     public_url, password, title,
-					     description, bench, known_nodes);
+					     bind_ip, bind_port, broadcast,
+					     public_url,
+					     title, description, password,
+					     bench, open_relay, known_nodes,
+					     network_reliability, trojan);
 }
 
 _lw6p2p_node_t *
 _lw6p2p_node_new (int argc, char *argv[], _lw6p2p_db_t * db,
 		  char *client_backends, char *server_backends, char *bind_ip,
-		  int bind_port, u_int64_t node_id, char *public_url,
-		  char *password, char *title, char *description, int bench,
-		  char *known_nodes)
+		  int bind_port, int broadcast,
+		  char *public_url, char *title,
+		  char *description, char *password, int bench,
+		  int open_relay, char *known_nodes, int network_reliability,
+		  int trojan)
 {
   _lw6p2p_node_t *node = NULL;
-  lw6sys_list_t *list_backends = NULL;
-  char *backend = NULL;
   char *query = NULL;
   char *escaped_public_url = NULL;
   char *escaped_title = NULL;
@@ -97,8 +101,9 @@ _lw6p2p_node_new (int argc, char *argv[], _lw6p2p_db_t * db,
       node->db = db;
       node->bind_ip = lw6sys_str_copy (bind_ip);
       node->bind_port = bind_port;
-      node->node_id_int = node_id;
-      node->node_id_str = lw6sys_id_ltoa (node_id);
+      node->broadcast = broadcast;
+      node->node_id_int = lw6sys_generate_id_64 ();
+      node->node_id_str = lw6sys_id_ltoa (node->node_id_int);
       if (public_url && strlen (public_url) > 0)
 	{
 	  node->public_url = lw6sys_url_canonize (public_url);
@@ -116,8 +121,12 @@ _lw6p2p_node_new (int argc, char *argv[], _lw6p2p_db_t * db,
 	  node->password = lw6sys_str_copy ("");
 	}
       node->node_info =
-	lw6nod_info_new (node->node_id_int, node->public_url, title,
-			 description, node->password, bench,
+	lw6nod_info_new (lw6sys_build_get_package_tarname (),
+			 lw6sys_build_get_version (),
+			 lw6sys_build_get_codename (),
+			 lw6sys_atoi (lw6sys_build_get_stamp ()),
+			 node->node_id_int, node->public_url, title,
+			 description, node->password, bench, open_relay, 0,
 			 node->db->data.idle_screenshot.size,
 			 node->db->data.idle_screenshot.data);
       if (known_nodes)
@@ -128,6 +137,8 @@ _lw6p2p_node_new (int argc, char *argv[], _lw6p2p_db_t * db,
 	{
 	  node->known_nodes = lw6sys_str_copy ("");
 	}
+      node->network_reliability = network_reliability;
+      node->trojan = trojan;
       ret = (node->bind_ip && node->node_id_str && node->public_url
 	     && node->password && node->node_info);
       if (ret)
@@ -144,134 +155,13 @@ _lw6p2p_node_new (int argc, char *argv[], _lw6p2p_db_t * db,
 	   */
 	  ret = (node->listener != NULL);
 	}
-      if (ret)
-	{
-	  ret = 0;
-	  list_backends = lw6sys_str_split_config_item (client_backends);
-	  if (list_backends)
-	    {
-	      while (list_backends
-		     && ((backend = lw6sys_list_pop_front (&list_backends)) !=
-			 NULL))
-		{
-		  node->nb_cli_backends++;
-		  if (node->cli_backends)
-		    {
-		      node->cli_backends =
-			(lw6cli_backend_t **)
-			LW6SYS_REALLOC (node->cli_backends,
-					node->nb_cli_backends *
-					sizeof (lw6cli_backend_t *));
-		    }
-		  else
-		    {
-		      node->cli_backends =
-			(lw6cli_backend_t **)
-			LW6SYS_MALLOC (node->nb_cli_backends *
-				       sizeof (lw6cli_backend_t *));
-		    }
-		  if (node->cli_backends)
-		    {
-		      node->cli_backends[node->nb_cli_backends - 1] =
-			lw6cli_create_backend (argc, argv, backend);
-		      if (node->cli_backends[node->nb_cli_backends - 1])
-			{
-			  if (lw6cli_init
-			      (node->cli_backends[node->nb_cli_backends - 1]))
-			    {
-			      ret = 1;
-			    }
-			  else
-			    {
-			      lw6cli_destroy_backend (node->cli_backends
-						      [node->nb_cli_backends -
-						       1]);
-			      node->cli_backends[node->nb_cli_backends - 1] =
-				NULL;
-			      node->nb_cli_backends--;
-			    }
-			}
-		      else
-			{
-			  node->nb_cli_backends--;
-			}
-		    }
-		  else
-		    {
-		      node->nb_cli_backends--;
-		    }
-		  LW6SYS_FREE (backend);
-		}
-	      list_backends = NULL;
-	    }
-	}
-      if (ret)
-	{
-	  ret = 0;
-	  list_backends = lw6sys_str_split_config_item (server_backends);
-	  if (list_backends)
-	    {
-	      while (list_backends
-		     && ((backend = lw6sys_list_pop_front (&list_backends)) !=
-			 NULL))
-		{
-		  node->nb_srv_backends++;
-		  if (node->srv_backends)
-		    {
-		      node->srv_backends =
-			(lw6srv_backend_t **)
-			LW6SYS_REALLOC (node->srv_backends,
-					node->nb_srv_backends *
-					sizeof (lw6srv_backend_t *));
-		    }
-		  else
-		    {
-		      node->srv_backends =
-			(lw6srv_backend_t **)
-			LW6SYS_MALLOC (node->nb_srv_backends *
-				       sizeof (lw6srv_backend_t *));
-		    }
-		  if (node->srv_backends)
-		    {
-		      node->srv_backends[node->nb_srv_backends - 1] =
-			lw6srv_create_backend (argc, argv, backend);
-		      if (node->srv_backends[node->nb_srv_backends - 1])
-			{
-			  if (lw6srv_init
-			      (node->srv_backends[node->nb_srv_backends - 1],
-			       node->listener))
-			    {
-			      /*
-			       * OK, at this state, we have at
-			       * least one server backend working,
-			       * we consider it's fine.
-			       */
-			      ret = 1;
-			    }
-			  else
-			    {
-			      lw6srv_destroy_backend (node->srv_backends
-						      [node->nb_srv_backends -
-						       1]);
-			      node->srv_backends[node->nb_srv_backends - 1] =
-				NULL;
-			      node->nb_srv_backends--;
-			    }
-			}
-		      else
-			{
-			  node->nb_srv_backends--;
-			}
-		    }
-		  else
-		    {
-		      node->nb_srv_backends--;
-		    }
-		  LW6SYS_FREE (backend);
-		}
-	      list_backends = NULL;
-	    }
-	}
+
+      ret = ret
+	&& _lw6p2p_backends_init_cli (argc, argv, &(node->backends),
+				      client_backends);
+      ret = ret
+	&& _lw6p2p_backends_init_srv (argc, argv, &(node->backends),
+				      server_backends, node->listener);
 
       if (ret)
 	{
@@ -287,6 +177,13 @@ _lw6p2p_node_new (int argc, char *argv[], _lw6p2p_db_t * db,
 			     _lw6p2p_cli_oob_callback_data_free);
 	  ret = (node->cli_oobs != NULL);
 	}
+      if (ret)
+	{
+	  ret =
+	    lw6cnx_ticket_table_init (&(node->ticket_table),
+				      node->db->data.consts.
+				      ticket_table_hash_size);
+	}
     }
 
   if (node && ret && node->node_id_str && node->public_url && node->node_info
@@ -302,8 +199,8 @@ _lw6p2p_node_new (int argc, char *argv[], _lw6p2p_db_t * db,
 	  if (escaped_title)
 	    {
 	      escaped_description =
-		lw6sys_escape_sql_value (node->node_info->
-					 const_info.description);
+		lw6sys_escape_sql_value (node->node_info->const_info.
+					 description);
 	      if (escaped_description)
 		{
 		  query =
@@ -318,7 +215,9 @@ _lw6p2p_node_new (int argc, char *argv[], _lw6p2p_db_t * db,
 					escaped_public_url, escaped_title,
 					escaped_description,
 					node->node_info->const_info.bench,
-					node->bind_ip, node->bind_port);
+					node->node_info->const_info.
+					open_relay, node->bind_ip,
+					node->bind_port);
 		  if (query)
 		    {
 		      if (_lw6p2p_db_lock (node->db))
@@ -344,8 +243,18 @@ _lw6p2p_node_new (int argc, char *argv[], _lw6p2p_db_t * db,
 
   if (node)
     {
-      lw6sys_log (LW6SYS_LOG_NOTICE, _("started node \"%s\""),
-		  node->public_url);
+      if (node->trojan)
+	{
+	  lw6sys_log (LW6SYS_LOG_WARNING,
+		      _
+		      ("started node \"%s\" in trojan mode, expect problems"),
+		      node->public_url);
+	}
+      else
+	{
+	  lw6sys_log (LW6SYS_LOG_NOTICE, _("started node \"%s\""),
+		      node->public_url);
+	}
     }
 
   return node;
@@ -372,6 +281,7 @@ _lw6p2p_node_free (_lw6p2p_node_t * node)
   if (node)
     {
       _lw6p2p_node_close (node);
+      lw6cnx_ticket_table_clear (&(node->ticket_table));
       if (node->cli_oobs)
 	{
 	  lw6sys_list_free (node->cli_oobs);
@@ -408,7 +318,7 @@ _lw6p2p_node_free (_lw6p2p_node_t * node)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _("trying to free NULL node"));
+      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("trying to free NULL node"));
     }
 }
 
@@ -435,14 +345,14 @@ _lw6p2p_node_repr (_lw6p2p_node_t * node)
   if (node && node->id && node->bind_ip)
     {
       repr =
-	lw6sys_new_sprintf (_("%u %s %s:%d %s"), node->id,
+	lw6sys_new_sprintf (_x_ ("%u %s %s:%d %s"), node->id,
 			    node->node_id_str, node->bind_ip,
 			    node->bind_port, node->public_url);
     }
   else
     {
       lw6sys_log (LW6SYS_LOG_WARNING,
-		  _("can't repr NULL or unitialized node"));
+		  _x_ ("can't repr NULL or unitialized node"));
     }
 
   return repr;
@@ -474,63 +384,60 @@ _poll_step1_accept_tcp (_lw6p2p_node_t * node)
   lw6srv_tcp_accepter_t *tcp_accepter = NULL;
   char *guessed_public_url = NULL;
 
-  lw6sys_log (LW6SYS_LOG_DEBUG, _("polling node TCP"));
+  lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("polling node TCP"));
 
-  if (lw6srv_poll (node->listener))
+  if (lw6net_socket_is_valid (node->listener->tcp_sock))
     {
-      if (node->listener->tcp_sock >= 0)
+      sock =
+	lw6net_tcp_accept (&ip, &port, node->listener->tcp_sock,
+			   node->db->data.consts.accept_delay);
+      if (sock >= 0 && ip != NULL && port > 0)
 	{
-	  sock =
-	    lw6net_tcp_accept (&ip, &port, node->listener->tcp_sock,
-			       node->db->data.consts.accept_delay / 1000.0f);
-	  if (sock >= 0 && ip != NULL && port > 0)
+	  tcp_accepter = lw6srv_tcp_accepter_new (ip, port, sock);
+	  if (tcp_accepter)
 	    {
-	      tcp_accepter = lw6srv_tcp_accepter_new (ip, port, sock);
-	      if (tcp_accepter)
+	      lw6sys_log (LW6SYS_LOG_DEBUG,
+			  _x_ ("TCP connection from %s:%d"), ip, port);
+	      lw6sys_list_push_front (&(node->listener->tcp_accepters),
+				      tcp_accepter);
+
+	      /*
+	       * Now we register this peer as a potential server,
+	       * it will be qualified as a real server (or not) later
+	       */
+	      guessed_public_url =
+		lw6sys_url_http_from_ip_port (ip, LW6NET_DEFAULT_PORT);
+	      if (guessed_public_url)
 		{
 		  lw6sys_log (LW6SYS_LOG_DEBUG,
-			      _("TCP connection from %s:%d"), ip, port);
-		  lw6sys_list_push_front (&(node->listener->tcp_accepters),
-					  tcp_accepter);
-
-		  /*
-		   * Now we register this peer as a potential server,
-		   * it will be qualified as a real server (or not) later
-		   */
+			      _x_
+			      ("discovered node \"%s\" from guessed url"),
+			      guessed_public_url);
+		  lw6nod_info_add_discovered_node (node->node_info,
+						   guessed_public_url);
+		  LW6SYS_FREE (guessed_public_url);
+		}
+	      if (node->bind_port != LW6NET_DEFAULT_PORT)
+		{
 		  guessed_public_url =
-		    lw6sys_url_http_from_ip_port (ip, LW6NET_DEFAULT_PORT);
+		    lw6sys_url_http_from_ip_port (ip, node->bind_port);
 		  if (guessed_public_url)
 		    {
 		      lw6sys_log (LW6SYS_LOG_DEBUG,
-				  _
-				  ("discovered node \"%s\" from guessed url"),
-				  guessed_public_url);
+				  _x_
+				  ("discovered node \"%s\" from guessed url (using non-standard port %d)"),
+				  guessed_public_url, node->bind_port);
 		      lw6nod_info_add_discovered_node (node->node_info,
 						       guessed_public_url);
 		      LW6SYS_FREE (guessed_public_url);
 		    }
-		  if (node->bind_port != LW6NET_DEFAULT_PORT)
-		    {
-		      guessed_public_url =
-			lw6sys_url_http_from_ip_port (ip, node->bind_port);
-		      if (guessed_public_url)
-			{
-			  lw6sys_log (LW6SYS_LOG_DEBUG,
-				      _
-				      ("discovered node \"%s\" from guessed url (using non-standard port %d)"),
-				      guessed_public_url, node->bind_port);
-			  lw6nod_info_add_discovered_node (node->node_info,
-							   guessed_public_url);
-			  LW6SYS_FREE (guessed_public_url);
-			}
-		    }
+		}
 
-		  ip = NULL;	// tcp_accepter will free it
-		}
-	      else
-		{
-		  ret = 0;
-		}
+	      ip = NULL;	// tcp_accepter will free it
+	    }
+	  else
+	    {
+	      ret = 0;
 	    }
 	}
     }
@@ -547,7 +454,7 @@ static int
 _poll_step2_recv_udp (_lw6p2p_node_t * node)
 {
   int ret = 1;
-  char buf[_UDP_MINIMAL_BUF_SIZE + 1];
+  char buf[LW6NET_UDP_MINIMAL_BUF_SIZE + 1];
   char *ip1 = NULL;
   char *ip2 = NULL;
   int port1 = 0;
@@ -556,79 +463,73 @@ _poll_step2_recv_udp (_lw6p2p_node_t * node)
   lw6srv_udp_buffer_t *udp_buffer = NULL;
   char *guessed_public_url = NULL;
 
-  lw6sys_log (LW6SYS_LOG_DEBUG, _("polling node UDP"));
-  memset (buf, 0, _UDP_MINIMAL_BUF_SIZE + 1);
-  if (lw6srv_poll (node->listener))
+  lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("polling node UDP"));
+  memset (buf, 0, LW6NET_UDP_MINIMAL_BUF_SIZE + 1);
+  if (node->listener->udp_sock >= 0)
     {
-      if (node->listener->udp_sock >= 0)
+      if (lw6net_udp_peek
+	  (node->listener->udp_sock, buf, LW6NET_UDP_MINIMAL_BUF_SIZE, &ip1,
+	   &port1))
 	{
-	  if (lw6net_udp_peek
-	      (node->listener->udp_sock, buf, _UDP_MINIMAL_BUF_SIZE, &ip1,
-	       &port1))
+	  lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("received data from %s:%d"),
+		      ip1, port1);
+	  line =
+	    lw6net_recv_line_udp (node->listener->udp_sock, &ip2, &port2);
+	  if (line)
 	    {
-	      lw6sys_log (LW6SYS_LOG_DEBUG, _("received data from %s:%d"),
-			  ip1, port1);
-	      line =
-		lw6net_recv_line_udp (node->listener->udp_sock, &ip2, &port2);
-	      if (line)
+	      lw6sys_log (LW6SYS_LOG_DEBUG,
+			  _x_ ("UDP connection from %s:%d"), ip2, port2);
+	      udp_buffer = lw6srv_udp_buffer_new (ip2, port2, line);
+	      if (udp_buffer)
 		{
-		  lw6sys_log (LW6SYS_LOG_DEBUG,
-			      _("UDP connection from %s:%d"), ip2, port2);
-		  udp_buffer = lw6srv_udp_buffer_new (ip2, port2, line);
-		  if (udp_buffer)
+		  lw6sys_list_push_front (&(node->listener->udp_buffers),
+					  udp_buffer);
+		  /*
+		   * Now we register this peer as a potential server,
+		   * it will be qualified as a real server (or not) later
+		   */
+		  guessed_public_url =
+		    lw6sys_url_http_from_ip_port (ip2, LW6NET_DEFAULT_PORT);
+		  if (guessed_public_url)
+		    {
+		      lw6sys_log (LW6SYS_LOG_DEBUG,
+				  _x_
+				  ("discovered node \"%s\" from guessed url"),
+				  guessed_public_url);
+		      lw6nod_info_add_discovered_node (node->node_info,
+						       guessed_public_url);
+		      LW6SYS_FREE (guessed_public_url);
+		    }
+		  if (node->bind_port != LW6NET_DEFAULT_PORT)
 		    {
-		      lw6sys_list_push_front (&(node->listener->udp_buffers),
-					      udp_buffer);
-		      /*
-		       * Now we register this peer as a potential server,
-		       * it will be qualified as a real server (or not) later
-		       */
 		      guessed_public_url =
-			lw6sys_url_http_from_ip_port (ip2,
-						      LW6NET_DEFAULT_PORT);
+			lw6sys_url_http_from_ip_port (ip2, node->bind_port);
 		      if (guessed_public_url)
 			{
 			  lw6sys_log (LW6SYS_LOG_DEBUG,
-				      _
-				      ("discovered node \"%s\" from guessed url"),
-				      guessed_public_url);
-			  lw6nod_info_add_discovered_node (node->node_info,
-							   guessed_public_url);
+				      _x_
+				      ("discovered node \"%s\" from guessed url (using non-standard port %d)"),
+				      guessed_public_url, node->bind_port);
+			  lw6nod_info_add_discovered_node
+			    (node->node_info, guessed_public_url);
 			  LW6SYS_FREE (guessed_public_url);
 			}
-		      if (node->bind_port != LW6NET_DEFAULT_PORT)
-			{
-			  guessed_public_url =
-			    lw6sys_url_http_from_ip_port (ip2,
-							  node->bind_port);
-			  if (guessed_public_url)
-			    {
-			      lw6sys_log (LW6SYS_LOG_DEBUG,
-					  _
-					  ("discovered node \"%s\" from guessed url (using non-standard port %d)"),
-					  guessed_public_url,
-					  node->bind_port);
-			      lw6nod_info_add_discovered_node
-				(node->node_info, guessed_public_url);
-			      LW6SYS_FREE (guessed_public_url);
-			    }
-			}
-		      line = NULL;	// udp_buffer will free it
-		      ip2 = NULL;	// udp_buffer will free it
-		    }
-		  else
-		    {
-		      ret = 0;
 		    }
+		  line = NULL;	// udp_buffer will free it
+		  ip2 = NULL;	// udp_buffer will free it
 		}
 	      else
 		{
-		  lw6sys_log (LW6SYS_LOG_INFO,
-			      _
-			      ("udp data received from %s:%d, but it's not correct"),
-			      ip1, port1);
+		  ret = 0;
 		}
 	    }
+	  else
+	    {
+	      lw6sys_log (LW6SYS_LOG_INFO,
+			  _x_
+			  ("udp data received from %s:%d, but it's not correct"),
+			  ip1, port1);
+	    }
 	}
     }
 
@@ -654,35 +555,45 @@ _tcp_accepter_reply (void *func_data, void *data)
   int ret = 1;
   _lw6p2p_node_t *node = (_lw6p2p_node_t *) func_data;
   lw6srv_tcp_accepter_t *tcp_accepter = (lw6srv_tcp_accepter_t *) data;
-  lw6srv_connection_t *connection = NULL;
   _lw6p2p_srv_oob_callback_data_t *srv_oob = NULL;
-  char *query = NULL;
-  char *connection_ptr_str = NULL;
-  char *backend_ptr_str = NULL;
   int i = 0;
   int analyse_tcp_ret = 0;
+  u_int64_t remote_id = 0;
+  char *remote_url = NULL;
+  int tentacle_index = -1;
 
   lw6net_tcp_peek (tcp_accepter->sock, tcp_accepter->first_line,
-		   LW6SRV_PROTOCOL_BUFFER_SIZE, 0.0f);
+		   LW6SRV_PROTOCOL_BUFFER_SIZE, 0);
 
-  for (i = 0; i < node->nb_srv_backends && ret; ++i)
+  for (i = 0; i < node->backends.nb_srv_backends && ret; ++i)
     {
       analyse_tcp_ret =
-	lw6srv_analyse_tcp (node->srv_backends[i], tcp_accepter);
+	lw6srv_analyse_tcp (node->backends.srv_backends[i], tcp_accepter,
+			    node->node_info, &remote_id, NULL);
       if (analyse_tcp_ret & LW6SRV_ANALYSE_DEAD)
 	{
 	  lw6sys_log (LW6SYS_LOG_DEBUG,
-		      _("dead accepter, scheduling it for deletion"));
+		      _x_ ("dead accepter, scheduling it for deletion"));
+	  if (lw6net_socket_is_valid (tcp_accepter->sock))
+	    {
+	      lw6net_socket_close (tcp_accepter->sock);
+	      tcp_accepter->sock = LW6NET_SOCKET_INVALID;
+	    }
 	  ret = 0;
 	}
       else
 	{
 	  if (analyse_tcp_ret & LW6SRV_ANALYSE_UNDERSTANDABLE)
 	    {
+	      lw6sys_log (LW6SYS_LOG_DEBUG,
+			  _x_
+			  ("understood accepter, scheduling it for deletion"));
+	      ret = 0;		// will be filtered
 	      if (analyse_tcp_ret & LW6SRV_ANALYSE_OOB)
 		{
 		  srv_oob =
-		    _lw6p2p_srv_oob_callback_data_new (node->srv_backends[i],
+		    _lw6p2p_srv_oob_callback_data_new (node->backends.
+						       srv_backends[i],
 						       node->node_info,
 						       tcp_accepter->
 						       client_id.client_ip,
@@ -692,56 +603,71 @@ _tcp_accepter_reply (void *func_data, void *data)
 						       NULL);
 		  if (srv_oob)
 		    {
-		      lw6sys_log (LW6SYS_LOG_DEBUG, _("process srv_oob"));
+		      lw6sys_log (LW6SYS_LOG_DEBUG,
+				  _x_ ("process srv_oob (tcp)"));
 		      srv_oob->srv_oob->thread =
 			lw6sys_thread_create (_lw6p2p_srv_oob_callback, NULL,
 					      srv_oob);
 		      lw6sys_lifo_push (&(node->srv_oobs), srv_oob);
-		      ret = 0;
 		    }
 		}
 	      else
 		{
-		  lw6sys_log (LW6SYS_LOG_DEBUG, _("new tcp"));
-		  connection =
-		    lw6srv_accept_tcp (node->srv_backends[i], tcp_accepter,
-				       node->password);
-		  if (connection)
+		  tentacle_index =
+		    _lw6p2p_node_find_tentacle (node, remote_id);
+		  if (tentacle_index < 0)
 		    {
-		      connection_ptr_str =
-			lw6sys_hexa_ptr_to_str (connection);
-		      if (connection_ptr_str)
+		      /*
+		       * We analyse again, but this time querying for
+		       * remote_url. The first call does not do this
+		       * to save time, since protocol analysis must
+		       * really remain simple. Besides this "double"
+		       * anlysis is rare since it only concerns one
+		       * message at the beginning of each incoming 
+		       * connection.
+		       */
+		      analyse_tcp_ret =
+			lw6srv_analyse_tcp (node->backends.srv_backends[i],
+					    tcp_accepter, node->node_info,
+					    &remote_id, &remote_url);
+		      if (remote_id != 0 && remote_url != NULL)
 			{
-			  backend_ptr_str =
-			    lw6sys_hexa_ptr_to_str (node->srv_backends[i]);
-			  if (backend_ptr_str)
+			  if (_lw6p2p_node_register_tentacle
+			      (node, remote_url,
+			       tcp_accepter->client_id.client_ip, remote_id))
 			    {
-			      query = lw6sys_new_sprintf (_lw6p2p_db_get_query
-							  (node->db,
-							   _LW6P2P_INSERT_CONNECTION_SQL),
-							  connection_ptr_str,
-							  backend_ptr_str,
-							  node->node_id_str);
-			      if (query)
-				{
-				  if (_lw6p2p_db_lock (node->db))
-				    {
-				      _lw6p2p_db_exec_ignore_data (node->db,
-								   query);
-				      _lw6p2p_db_unlock (node->db);
-				    }
-				  LW6SYS_FREE (query);
-				}
-			      LW6SYS_FREE (backend_ptr_str);
+			      tentacle_index =
+				_lw6p2p_node_find_tentacle (node, remote_id);
 			    }
-			  LW6SYS_FREE (connection_ptr_str);
+			  else
+			    {
+			      lw6sys_log (LW6SYS_LOG_DEBUG,
+					  _x_
+					  ("can't create tentacle with \"%s\""),
+					  remote_url);
+			    }
+			  LW6SYS_FREE (remote_url);
+			}
+		      else
+			{
+			  lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("wrong id/url"));
 			}
 		    }
+		  if (tentacle_index >= 0
+		      && tentacle_index < LW6P2P_MAX_NB_TENTACLES)
+		    {
+		      lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("feed srv (tcp)"));
+		      lw6srv_feed_with_tcp (node->backends.srv_backends[i],
+					    node->tentacles
+					    [tentacle_index].srv_connections
+					    [i], tcp_accepter);
+		    }
+		  else
+		    {
+		      lw6net_socket_close (tcp_accepter->sock);
+		      tcp_accepter->sock = LW6NET_SOCKET_INVALID;
+		    }
 		}
-	      lw6sys_log (LW6SYS_LOG_DEBUG,
-			  _
-			  ("understood accepter, scheduling it for deletion"));
-	      ret = 0;		// will be filtered
 	    }
 	}
     }
@@ -755,92 +681,107 @@ _udp_buffer_reply (void *func_data, void *data)
   int ret = 1;
   _lw6p2p_node_t *node = (_lw6p2p_node_t *) func_data;
   lw6srv_udp_buffer_t *udp_buffer = (lw6srv_udp_buffer_t *) data;
-  lw6srv_connection_t *connection = NULL;
   _lw6p2p_srv_oob_callback_data_t *srv_oob = NULL;
-  char *query = NULL;
-  char *connection_ptr_str = NULL;
-  char *backend_ptr_str = NULL;
   int i = 0;
   int analyse_udp_ret = 0;
+  u_int64_t remote_id = 0;
+  char *remote_url = NULL;
+  int tentacle_index = -1;
 
-  for (i = 0; i < node->nb_srv_backends && ret; ++i)
+  for (i = 0; i < node->backends.nb_srv_backends && ret; ++i)
     {
       analyse_udp_ret =
-	lw6srv_analyse_udp (node->srv_backends[i], udp_buffer);
+	lw6srv_analyse_udp (node->backends.srv_backends[i], udp_buffer,
+			    node->node_info, &remote_id, NULL);
       if (analyse_udp_ret & LW6SRV_ANALYSE_DEAD)
 	{
 	  lw6sys_log (LW6SYS_LOG_DEBUG,
-		      _("dead buffer, scheduling it for deletion"));
+		      _x_ ("dead buffer, scheduling it for deletion"));
 	  ret = 0;
 	}
       else
 	{
 	  if (analyse_udp_ret & LW6SRV_ANALYSE_UNDERSTANDABLE)
 	    {
+	      lw6sys_log (LW6SYS_LOG_DEBUG,
+			  _x_
+			  ("understood buffer, scheduling it for deletion"));
+	      ret = 0;		// will be filtered
 	      if (analyse_udp_ret & LW6SRV_ANALYSE_OOB)
 		{
 		  srv_oob =
-		    _lw6p2p_srv_oob_callback_data_new (node->srv_backends[i],
+		    _lw6p2p_srv_oob_callback_data_new (node->backends.
+						       srv_backends[i],
 						       node->node_info,
-						       udp_buffer->
-						       client_id.client_ip,
-						       udp_buffer->
-						       client_id.client_port,
-						       node->
-						       listener->udp_sock,
+						       udp_buffer->client_id.
+						       client_ip,
+						       udp_buffer->client_id.
+						       client_port,
+						       node->listener->
+						       udp_sock,
 						       udp_buffer->line);
 		  if (srv_oob)
 		    {
-		      lw6sys_log (LW6SYS_LOG_DEBUG, _("process srv_oob"));
+		      lw6sys_log (LW6SYS_LOG_DEBUG,
+				  _x_ ("process srv_oob (udp)"));
 		      srv_oob->srv_oob->thread =
 			lw6sys_thread_create (_lw6p2p_srv_oob_callback, NULL,
 					      srv_oob);
 		      lw6sys_lifo_push (&(node->srv_oobs), srv_oob);
-		      ret = 0;
 		    }
 		}
 	      else
 		{
-		  lw6sys_log (LW6SYS_LOG_DEBUG, _("new udp"));
-		  connection =
-		    lw6srv_new_udp (node->srv_backends[i], udp_buffer,
-				    node->password);
-		  if (connection)
+		  tentacle_index =
+		    _lw6p2p_node_find_tentacle (node, remote_id);
+		  if (tentacle_index < 0)
 		    {
-		      connection_ptr_str =
-			lw6sys_hexa_ptr_to_str (connection);
-		      if (connection_ptr_str)
+		      /*
+		       * We analyse again, but this time querying for
+		       * remote_url. The first call does not do this
+		       * to save time, since protocol analysis must
+		       * really remain simple. Besides this "double"
+		       * anlysis is rare since it only concerns one
+		       * message at the beginning of each incoming 
+		       * connection.
+		       */
+		      analyse_udp_ret =
+			lw6srv_analyse_udp (node->backends.srv_backends[i],
+					    udp_buffer, node->node_info,
+					    &remote_id, &remote_url);
+		      if (remote_id != 0 && remote_url != NULL)
 			{
-			  backend_ptr_str =
-			    lw6sys_hexa_ptr_to_str (node->srv_backends[i]);
-			  if (backend_ptr_str)
+			  if (_lw6p2p_node_register_tentacle
+			      (node, remote_url,
+			       udp_buffer->client_id.client_ip, remote_id))
 			    {
-			      query = lw6sys_new_sprintf (_lw6p2p_db_get_query
-							  (node->db,
-							   _LW6P2P_INSERT_CONNECTION_SQL),
-							  connection_ptr_str,
-							  backend_ptr_str,
-							  node->node_id_str);
-			      if (query)
-				{
-				  if (_lw6p2p_db_lock (node->db))
-				    {
-				      _lw6p2p_db_exec_ignore_data (node->db,
-								   query);
-				      _lw6p2p_db_unlock (node->db);
-				    }
-				  LW6SYS_FREE (query);
-				}
-			      LW6SYS_FREE (backend_ptr_str);
+			      tentacle_index =
+				_lw6p2p_node_find_tentacle (node, remote_id);
 			    }
-			  LW6SYS_FREE (connection_ptr_str);
+			  else
+			    {
+			      lw6sys_log (LW6SYS_LOG_DEBUG,
+					  _x_
+					  ("can't create tentacle with \"%s\""),
+					  remote_url);
+			    }
+			  LW6SYS_FREE (remote_url);
+			}
+		      else
+			{
+			  lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("wrong id/url"));
 			}
 		    }
+		  if (tentacle_index >= 0
+		      && tentacle_index < LW6P2P_MAX_NB_TENTACLES)
+		    {
+		      lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("feed srv (udp)"));
+		      lw6srv_feed_with_udp (node->backends.srv_backends[i],
+					    node->tentacles
+					    [tentacle_index].srv_connections
+					    [i], udp_buffer);
+		    }
 		}
-	      lw6sys_log (LW6SYS_LOG_DEBUG,
-			  _
-			  ("understood accepter, scheduling it for deletion"));
-	      ret = 0;		// will be filtered
 	    }
 	}
     }
@@ -945,6 +886,25 @@ _poll_step9_flush_verified_nodes (_lw6p2p_node_t * node)
   return ret;
 }
 
+static int
+_poll_step10_poll_tentacles (_lw6p2p_node_t * node)
+{
+  int ret = 1;
+  int i = 0;
+
+  for (i = 0; i < LW6P2P_MAX_NB_TENTACLES; ++i)
+    {
+      if (_lw6p2p_tentacle_enabled (&(node->tentacles[i])))
+	{
+	  _lw6p2p_tentacle_poll (&(node->tentacles[i]), node->node_info,
+				 &(node->ticket_table),
+				 node->db->data.consts.foo_delay);
+	}
+    }
+
+  return ret;
+}
+
 int
 _lw6p2p_node_poll (_lw6p2p_node_t * node)
 {
@@ -959,6 +919,7 @@ _lw6p2p_node_poll (_lw6p2p_node_t * node)
   ret = _poll_step7_flush_discovered_nodes (node) && ret;
   ret = _poll_step8_explore_verify_nodes (node) && ret;
   ret = _poll_step9_flush_verified_nodes (node) && ret;
+  ret = _poll_step10_poll_tentacles (node) && ret;
 
   return ret;
 }
@@ -984,10 +945,10 @@ lw6p2p_node_close (lw6p2p_node_t * node)
 void
 _lw6p2p_node_close (_lw6p2p_node_t * node)
 {
-  int i = 0;
   char *query = NULL;
   _lw6p2p_srv_oob_callback_data_t *srv_oob = NULL;
   _lw6p2p_cli_oob_callback_data_t *cli_oob = NULL;
+  int i = 0;
 
   if (node)
     {
@@ -1028,6 +989,12 @@ _lw6p2p_node_close (_lw6p2p_node_t * node)
 		}
 	      _lw6p2p_db_unlock (node->db);
 	    }
+
+	  for (i = 0; i < LW6P2P_MAX_NB_TENTACLES; ++i)
+	    {
+	      _lw6p2p_tentacle_clear (&(node->tentacles[i]));
+	    }
+
 	  if (node->srv_oobs)
 	    {
 	      while (node->srv_oobs && !lw6sys_list_is_empty (node->srv_oobs))
@@ -1040,7 +1007,7 @@ _lw6p2p_node_close (_lw6p2p_node_t * node)
 	      if (!(node->srv_oobs))
 		{
 		  lw6sys_log (LW6SYS_LOG_WARNING,
-			      _("NULL srv_oobs after emptying"));
+			      _x_ ("NULL srv_oobs after emptying"));
 		}
 	    }
 	  if (node->cli_oobs)
@@ -1055,40 +1022,13 @@ _lw6p2p_node_close (_lw6p2p_node_t * node)
 	      if (!(node->cli_oobs))
 		{
 		  lw6sys_log (LW6SYS_LOG_WARNING,
-			      _("NULL cli_oobs after emptying"));
+			      _x_ ("NULL cli_oobs after emptying"));
 		}
 	    }
 
-	  if (node->srv_backends)
-	    {
-	      for (i = 0; i < node->nb_srv_backends; ++i)
-		{
-		  if (node->srv_backends[i])
-		    {
-		      lw6srv_quit (node->srv_backends[i]);
-		      lw6srv_destroy_backend (node->srv_backends[i]);
-		      node->srv_backends[i] = NULL;
-		    }
-		}
-	      LW6SYS_FREE (node->srv_backends);
-	      node->srv_backends = NULL;
-	      node->nb_srv_backends = 0;
-	    }
-	  if (node->cli_backends)
-	    {
-	      for (i = 0; i < node->nb_cli_backends; ++i)
-		{
-		  if (node->cli_backends[i])
-		    {
-		      lw6cli_quit (node->cli_backends[i]);
-		      lw6cli_destroy_backend (node->cli_backends[i]);
-		      node->cli_backends[i] = NULL;
-		    }
-		}
-	      LW6SYS_FREE (node->cli_backends);
-	      node->cli_backends = NULL;
-	      node->nb_cli_backends = 0;
-	    }
+	  _lw6p2p_backends_clear_srv (&(node->backends));
+	  _lw6p2p_backends_clear_cli (&(node->backends));
+
 	  if (node->listener)
 	    {
 	      lw6srv_stop (node->listener);
@@ -1097,15 +1037,45 @@ _lw6p2p_node_close (_lw6p2p_node_t * node)
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_DEBUG, _("closing closed node"));
+	  lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("closing closed node"));
 	}
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _("trying to close NULL node"));
+      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("trying to close NULL node"));
     }
 }
 
+/**
+ * lw6p2p_node_get_id
+ *
+ * @node: the node to query
+ *
+ * Returns the node id, an id which is supposed to uniquely identify
+ * the node at run-time.
+ *
+ * Return value: numerical id.
+ */
+u_int64_t
+lw6p2p_node_get_id (lw6p2p_node_t * node)
+{
+  u_int64_t id = 0;
+
+  id = _lw6p2p_node_get_id ((_lw6p2p_node_t *) node);
+
+  return id;
+}
+
+u_int64_t
+_lw6p2p_node_get_id (_lw6p2p_node_t * node)
+{
+  u_int64_t id = 0;
+
+  id = node->node_id_int;
+
+  return id;
+}
+
 static int
 _select_node_by_url_callback (void *func_data, int nb_fields,
 			      char **fields_values, char **fields_names)
@@ -1115,7 +1085,7 @@ _select_node_by_url_callback (void *func_data, int nb_fields,
 
   (*count)++;
   lw6sys_log (LW6SYS_LOG_DEBUG,
-	      _
+	      _x_
 	      ("select_node_by_url_callback called with %d fields, count is %d"),
 	      nb_fields, (*count));
 
@@ -1153,7 +1123,8 @@ _lw6p2p_node_insert_discovered (_lw6p2p_node_t * node, char *public_url)
 		  if (count > 0)
 		    {
 		      lw6sys_log (LW6SYS_LOG_DEBUG,
-				  _("there's already a node with url \"%s\""),
+				  _x_
+				  ("there's already a node with url \"%s\""),
 				  public_url);
 		    }
 		  else
@@ -1189,3 +1160,189 @@ _lw6p2p_node_insert_discovered (_lw6p2p_node_t * node, char *public_url)
 
   return ret;
 }
+
+int
+_lw6p2p_node_update_peer (_lw6p2p_node_t * node, char *version,
+			  char *codename, int stamp, char *id, char *url,
+			  char *title, char *description, int has_password,
+			  int bench, int open_relay, int creation_timestamp,
+			  char *community_id, int round, char *level,
+			  int required_bench, int nb_colors,
+			  int max_nb_colors, int nb_cursors,
+			  int max_nb_cursors, int nb_nodes, int max_nb_nodes,
+			  char *ip, int port, int last_ping_timestamp,
+			  int ping_delay_msec)
+{
+  int ret = 1;
+  char *query = NULL;
+  char *escaped_version = NULL;
+  char *escaped_codename = NULL;
+  char *escaped_id = NULL;
+  char *escaped_url = NULL;
+  char *escaped_title = NULL;
+  char *escaped_description = NULL;
+  char *escaped_community_id = NULL;
+  char *escaped_level = NULL;
+
+  escaped_version = lw6sys_escape_sql_value (version);
+  escaped_codename = lw6sys_escape_sql_value (codename);
+  escaped_id = lw6sys_escape_sql_value (id);
+  escaped_url = lw6sys_escape_sql_value (url);
+  escaped_title = lw6sys_escape_sql_value (title);
+  escaped_description = lw6sys_escape_sql_value (description);
+  escaped_community_id = lw6sys_escape_sql_value (community_id);
+  escaped_level = lw6sys_escape_sql_value (level);
+
+  query = lw6sys_new_sprintf (_lw6p2p_db_get_query
+			      (node->db,
+			       _LW6P2P_UPDATE_NODE_SQL),
+			      creation_timestamp, escaped_version,
+			      escaped_codename, stamp,
+			      escaped_id, escaped_title,
+			      escaped_description, has_password,
+			      bench, open_relay, escaped_community_id, round,
+			      escaped_level, required_bench, nb_colors,
+			      max_nb_colors, nb_cursors, max_nb_cursors,
+			      nb_nodes, max_nb_nodes, ip, port,
+			      last_ping_timestamp, ping_delay_msec,
+			      escaped_url);
+  if (query)
+    {
+      if (_lw6p2p_db_lock (node->db))
+	{
+	  ret = _lw6p2p_db_exec_ignore_data (node->db, query);
+	  _lw6p2p_db_unlock (node->db);
+	}
+      LW6SYS_FREE (query);
+    }
+
+  if (escaped_version)
+    {
+      LW6SYS_FREE (escaped_version);
+    }
+  if (escaped_codename)
+    {
+      LW6SYS_FREE (escaped_codename);
+    }
+  if (escaped_id)
+    {
+      LW6SYS_FREE (escaped_id);
+    }
+  if (escaped_url)
+    {
+      LW6SYS_FREE (escaped_url);
+    }
+  if (escaped_title)
+    {
+      LW6SYS_FREE (escaped_title);
+    }
+  if (escaped_description)
+    {
+      LW6SYS_FREE (escaped_description);
+    }
+  if (escaped_community_id)
+    {
+      LW6SYS_FREE (escaped_community_id);
+    }
+  if (escaped_level)
+    {
+      LW6SYS_FREE (escaped_level);
+    }
+
+  return ret;
+}
+
+int
+_lw6p2p_node_find_free_tentacle (_lw6p2p_node_t * node)
+{
+  int ret = -1;
+  int i;
+
+  for (i = 0; i < LW6P2P_MAX_NB_TENTACLES && ret < 0; ++i)
+    {
+      if (!_lw6p2p_tentacle_enabled (&(node->tentacles[i])))
+	{
+	  ret = i;
+	  lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("found free tentacle %d"), i);
+	}
+    }
+
+  return ret;
+}
+
+int
+_lw6p2p_node_find_tentacle (_lw6p2p_node_t * node, u_int64_t remote_id)
+{
+  int ret = -1;
+  int i;
+
+  if (remote_id != 0)
+    {
+      for (i = 0; i < LW6P2P_MAX_NB_TENTACLES && ret < 0; ++i)
+	{
+	  if (node->tentacles[i].remote_id_int == remote_id)
+	    {
+	      ret = i;
+	    }
+	}
+    }
+
+  return ret;
+}
+
+int
+_lw6p2p_node_register_tentacle (_lw6p2p_node_t * node, char *remote_url,
+				char *real_remote_ip, u_int64_t remote_id)
+{
+  int ret = 0;
+  int i = 0;
+
+  i = _lw6p2p_node_find_tentacle (node, remote_id);
+  if (i < 0)
+    {
+      i = _lw6p2p_node_find_free_tentacle (node);
+      if (i >= 0 && i < LW6P2P_MAX_NB_TENTACLES)
+	{
+	  ret =
+	    _lw6p2p_tentacle_init (&(node->tentacles[i]), &(node->backends),
+				   node->listener,
+				   node->public_url, remote_url,
+				   real_remote_ip, node->password,
+				   node->node_id_int, remote_id,
+				   node->network_reliability,
+				   _lw6p2p_recv_callback, (void *) node);
+	}
+      else
+	{
+	  lw6sys_log (LW6SYS_LOG_WARNING,
+		      _x_ ("unable to find a free tentacle"));
+	}
+    }
+  else
+    {
+      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("tentacle already exists (i=%d)"),
+		  i);
+    }
+
+  return ret;
+}
+
+int
+_lw6p2p_node_unregister_tentacle (_lw6p2p_node_t * node, u_int64_t remote_id)
+{
+  int ret = 0;
+  int i = 0;
+
+  i = _lw6p2p_node_find_tentacle (node, remote_id);
+  if (i >= 0 && i < LW6P2P_MAX_NB_TENTACLES)
+    {
+      _lw6p2p_tentacle_clear (&(node->tentacles[i]));
+      ret = 1;
+    }
+  else
+    {
+      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("unable to find tentacle"));
+    }
+
+  return ret;
+}
