@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -107,7 +107,7 @@ lw6srv_create_backend (int argc, char *argv[], char *name)
   else
     {
       lw6sys_log (LW6SYS_LOG_WARNING,
-		  _("server backend \"%s\" does not exist"), name);
+		  _x_ ("server backend \"%s\" does not exist"), name);
     }
 #else
   lw6dyn_dl_handle_t *backend_handle = NULL;
@@ -131,7 +131,7 @@ lw6srv_create_backend (int argc, char *argv[], char *name)
 	  else
 	    {
 	      lw6sys_log (LW6SYS_LOG_WARNING,
-			  _
+			  _x_
 			  ("unable to find function \"%s\" in server backend \"%s\""),
 			  init_func_name, name);
 	    }
@@ -150,7 +150,7 @@ lw6srv_create_backend (int argc, char *argv[], char *name)
   else
     {
       lw6sys_log (LW6SYS_LOG_WARNING,
-		  _("unable to open server backend \"%s\""), name);
+		  _x_ ("unable to open server backend \"%s\""), name);
     }
 #endif
 
