@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -92,7 +92,7 @@ lw6sys_dump (char *user_dir, char *content)
        * Send a message in log file to tell where the dump is,
        * very convenient to copy-paste then cat file.
        */
-      lw6sys_log (LW6SYS_LOG_WARNING, _("dump saved in file \"%s\""),
+      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("dump saved in file \"%s\""),
 		  dump_file);
       ret = lw6sys_write_file_content (dump_file, content);
       LW6SYS_FREE (dump_file);
