@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -114,7 +114,7 @@ lw6sys_keyword_as_key (char *keyword)
 	    }
 	  else
 	    {
-	      lw6sys_log_critical (_
+	      lw6sys_log_critical (_x_
 				   ("weird char '%c' in keyword \"%s\""),
 				   pos[0], keyword);
 	    }
@@ -192,7 +192,7 @@ lw6sys_keyword_as_env (char *keyword)
 	    }
 	  else
 	    {
-	      lw6sys_log_critical (_
+	      lw6sys_log_critical (_x_
 				   ("weird char '%c' in keyword \"%s\""),
 				   pos[0], keyword);
 	    }
