@@ -41,6 +41,12 @@
 #define HISTORY_LENGTH 256
 #define LEVEL_LENGTH 80
 #define MSGBOX_LENGTH 4096
+/*
+ * For some reason seams on GNU/Linux (gtk2/xorg) systems
+ * the message box is trimmed at 64 chars width. 128 makes
+ * it transparent. For the "\n" is already here on one over
+ * two lines.
+ */
 #define MSGBOX_WIDTH 128
 
 #define CRITICAL_FILE "sys-log.c"
@@ -49,6 +55,8 @@
 #define STATIC_LOG_FILENAME_SIZE 65536
 static char static_log_filename[STATIC_LOG_FILENAME_SIZE + 1] = { 0 };
 
+#define GTK_NB_IDLE_ITERATIONS 10
+
 static char *
 get_log_file ()
 {
@@ -602,16 +610,41 @@ log_to_history (char *level_str, char *fmt, va_list ap)
   lw6sys_history_register (full_msg);
 }
 
-static void
-msgbox_alert (char *level_str, char *file, int line, char *fmt, va_list ap)
+/*
+ * This function not declared static so that we're sure it's never inlined
+ * because that could wreck the backtrace construction. It's not exported
+ * in the sys/sys.h header anyway, we don't want others to use it, it still
+ * does have the lw6sys_ prefix to avoid name conflicts.
+ */
+void
+lw6sys_msgbox_alert (char *level_str, char *file, int line, char *fmt,
+		     va_list ap)
 {
   char message_raw[MSGBOX_LENGTH + 1];
   char message_full[MSGBOX_LENGTH + 1];
+  char *bt = NULL;
+  int free_bt = 0;
 
   _lw6sys_buf_vsnprintf (message_raw, MSGBOX_LENGTH, fmt, ap);
   lw6sys_str_reformat_this (message_raw, MSGBOX_WIDTH);
-  lw6sys_buf_sprintf (message_full, MSGBOX_LENGTH, "%s (%s:%d)\n\n%s",
-		      level_str, file, line, message_raw);
+  bt = lw6sys_backtrace (2);	// skip this function & caller  
+  if (bt)
+    {
+      lw6sys_str_reformat_this (bt, MSGBOX_WIDTH);
+      free_bt = 1;
+    }
+  else
+    {
+      bt = "";
+    }
+  lw6sys_buf_sprintf (message_full, MSGBOX_LENGTH,
+		      "%s (%s:%d)\n\n%s\n\nbacktrace: %s", level_str, file,
+		      line, message_raw, bt);
+  if (free_bt)
+    {
+      LW6SYS_FREE (bt);
+      bt = NULL;
+    }
 #ifdef LW6_MS_WINDOWS
   if (message_full)
     {
@@ -656,23 +689,34 @@ msgbox_alert (char *level_str, char *file, int line, char *fmt, va_list ap)
   argv = argv_data;
   if (!gtk_init_done)
     {
-      gtk_init (&argc, &argv);
-      gtk_init_done = 1;
+      if (gtk_init_check (&argc, &argv))
+	{
+	  gtk_init_done = 1;
+	}
+      // no "else" here, we won't log inside a log function
     }
-  dlg = gtk_message_dialog_new (NULL,
-				GTK_DIALOG_MODAL,
-				GTK_MESSAGE_ERROR,
-				GTK_BUTTONS_NONE, "%s", message_full);
-  if (dlg)
+  if (gtk_init_done)
     {
-      gtk_window_set_title (GTK_WINDOW (dlg),
-			    lw6sys_build_get_package_name ());
-      gtk_dialog_add_button (GTK_DIALOG (dlg), GTK_STOCK_OK, GTK_RESPONSE_OK);
-      gtk_dialog_run (GTK_DIALOG (dlg));
-      gtk_widget_hide_all (dlg);
-      gtk_main_iteration ();
-      gtk_widget_destroy (dlg);
-      gtk_main_iteration ();
+      dlg = gtk_message_dialog_new (NULL,
+				    GTK_DIALOG_MODAL,
+				    GTK_MESSAGE_ERROR,
+				    GTK_BUTTONS_NONE, "%s", message_full);
+      if (dlg)
+	{
+	  gtk_window_set_title (GTK_WINDOW (dlg),
+				lw6sys_build_get_package_name ());
+	  gtk_dialog_add_button (GTK_DIALOG (dlg), GTK_STOCK_OK,
+				 GTK_RESPONSE_OK);
+	  gtk_dialog_run (GTK_DIALOG (dlg));
+	  gtk_widget_hide_all (dlg);
+	  gtk_widget_destroy (dlg);
+
+	  while (gtk_events_pending ())
+	    {
+	      gtk_main_iteration ();
+	      lw6sys_idle ();
+	    }
+	}
     }
 #endif
 #endif
@@ -837,7 +881,7 @@ lw6sys_log (int level_id, char *file, int line, char *fmt, ...)
 	  if (level_id <= LW6SYS_LOG_ERROR_ID)
 	    {
 	      va_copy (ap2, ap);
-	      msgbox_alert (level_str, file_only, line, fmt, ap2);
+	      lw6sys_msgbox_alert (level_str, file_only, line, fmt, ap2);
 	      va_end (ap2);
 	    }
 	}
@@ -880,7 +924,8 @@ lw6sys_log_critical (char *fmt, ...)
   va_end (ap2);
 
   va_copy (ap2, ap);
-  msgbox_alert (_("CRITICAL!"), CRITICAL_FILE, CRITICAL_LINE, fmt, ap2);
+  lw6sys_msgbox_alert (_("CRITICAL!"), CRITICAL_FILE, CRITICAL_LINE, fmt,
+		       ap2);
   va_end (ap2);
 
   exit (_LW6SYS_EXIT_CRITICAL);
