@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -118,7 +118,7 @@ lw6sys_math_poly_wy1y2s1 (float *y, float *s, float x, float w, float y1,
   else
     {
       lw6sys_log (LW6SYS_LOG_WARNING,
-		  _("can't extrapolate with x=%f and w=%f"), x, w);
+		  _x_ ("can't extrapolate with x=%f and w=%f"), x, w);
       tmp_y = y2;
       tmp_s = 0.0f;
     }
@@ -240,7 +240,7 @@ lw6sys_math_heartbeat (int64_t x, int period, float y1, float y2)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _("can't use period %d"), period);
+      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("can't use period %d"), period);
     }
 
   return ret;
@@ -271,7 +271,7 @@ lw6sys_math_blink (int64_t x, int period)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _("can't use period %d"), period);
+      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("can't use period %d"), period);
     }
 
   return ret;
