@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -59,7 +59,7 @@ lw6sys_spinlock_create ()
 
   if (!spinlock)
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _("unable to create spinlock"));
+      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("unable to create spinlock"));
     }
 #else
 #if LW6_X86
@@ -67,7 +67,7 @@ lw6sys_spinlock_create ()
     (_lw6sys_spinlock_t *) LW6SYS_CALLOC (sizeof (_lw6sys_spinlock_t));
   if (!spinlock)
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _("unable to create X86 spinlock"));
+      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("unable to create X86 spinlock"));
     }
 #else
   spinlock = lw6sys_mutex_create ();
@@ -127,7 +127,7 @@ lw6sys_spinlock_lock (void *spinlock)
   else
     {
       lw6sys_log (LW6SYS_LOG_WARNING,
-		  _("pthread_spin_lock failed with error code %d"),
+		  _x_ ("pthread_spin_lock failed with error code %d"),
 		  pthread_ret);
     }
 #else
@@ -180,7 +180,7 @@ lw6sys_spinlock_trylock (void *spinlock)
       else
 	{
 	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _("pthread_spin_trylock failed with error code %d"),
+		      _x_ ("pthread_spin_trylock failed with error code %d"),
 		      pthread_ret);
 	}
     }
@@ -219,7 +219,7 @@ lw6sys_spinlock_unlock (void *spinlock)
   else
     {
       lw6sys_log (LW6SYS_LOG_WARNING,
-		  _("pthread_spin_unlock failed with error code %d"),
+		  _x_ ("pthread_spin_unlock failed with error code %d"),
 		  pthread_ret);
     }
 #else
