@@ -71,6 +71,7 @@
 #define TEST_PATH_SPLIT "/foo/\\bar\\"
 #define _TEST_DIR_LIST_FUNC_DATA "foo,bar"
 #define _TEST_PATH_LIST_OTHER "."
+#define _TEST_PATH_FILE_ONLY "/foo/bar.txt"
 #define _FIND_IN_DIR_AND_PATH_DIR "/foo"
 #define _FIND_IN_DIR_AND_PATH_PATH "/bar:/etc"
 #define _FIND_IN_DIR_AND_PATH_FILE "hosts"
@@ -181,8 +182,11 @@
 #define TEST_SHAPE_X 123
 #define TEST_SHAPE_Y 456
 #define TEST_SHAPE_Z 1
-#define TEST_SHAPE_MIN_WH 10
-#define TEST_SHAPE_MAX_WH 1000
+#define TEST_SHAPE_MIN_W 10
+#define TEST_SHAPE_MIN_H 10
+#define TEST_SHAPE_MIN_D 1
+#define TEST_SHAPE_MAX_W 1000
+#define TEST_SHAPE_MAX_H 1000
 #define TEST_SHAPE_MAX_D 5
 #define TEST_MATH_POLY_WY1Y2S1_NB_STEPS 20
 #define TEST_MATH_POLY_WY1Y2S1_W 5.0f
@@ -372,6 +376,31 @@ test_assoc ()
   return ret;
 }
 
+/*
+ * Test functions in backtrace.c
+ */
+static int
+test_backtrace ()
+{
+  int ret = 1;
+  LW6SYS_TEST_FUNCTION_BEGIN;
+
+  {
+    char *bt = NULL;
+
+    bt = lw6sys_backtrace (0);
+    if (bt)
+      {
+	lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("backtrace=\"%s\""), bt);
+	LW6SYS_FREE (bt);
+      }
+    BT;
+  }
+
+  LW6SYS_TEST_FUNCTION_END;
+  return ret;
+}
+
 /*
  * Test functions in build.c
  */
@@ -2404,6 +2433,13 @@ test_path ()
 		    _FIND_IN_DIR_AND_PATH_PATH, _FIND_IN_DIR_AND_PATH_FILE);
 	LW6SYS_FREE (path);
       }
+    path = lw6sys_file_only (_TEST_PATH_FILE_ONLY);
+    if (path)
+      {
+	lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("file only for \"%s\" is \"%s\""),
+		    _TEST_PATH_FILE_ONLY, path);
+	LW6SYS_FREE (path);
+      }
   }
 
   LW6SYS_TEST_FUNCTION_END;
@@ -3047,15 +3083,20 @@ test_shape ()
     lw6sys_whd_t shape = { TEST_SHAPE_W, TEST_SHAPE_H, TEST_SHAPE_D };
     lw6sys_whd_t shape2 =
       { TEST_SHAPE_W + 1, TEST_SHAPE_H + 1, TEST_SHAPE_D + 1 };
+    lw6sys_whd_t shape_min =
+      { TEST_SHAPE_MIN_W, TEST_SHAPE_MIN_H, TEST_SHAPE_MIN_D };
+    lw6sys_whd_t shape_max =
+      { TEST_SHAPE_MAX_W, TEST_SHAPE_MAX_H, TEST_SHAPE_MAX_D };
     lw6sys_xyz_t pos = { TEST_SHAPE_X, TEST_SHAPE_Y, TEST_SHAPE_Z };
 
-    if (lw6sys_shape_check_min_max_whd
-	(&shape, TEST_SHAPE_MIN_WH, TEST_SHAPE_MAX_WH, TEST_SHAPE_MAX_D))
+    if (lw6sys_shape_check_min_max_whd (&shape, &shape_min, &shape_max))
       {
 	lw6sys_log (LW6SYS_LOG_NOTICE,
-		    _x_ ("shape %dx%dx%d respects [%d-%d-%d] constraints"),
+		    _x_
+		    ("shape %dx%dx%d respects constraints min=%dx%dx%d max=%dx%dx%d"),
 		    (int) shape.w, (int) shape.h, (int) shape.d,
-		    TEST_SHAPE_MIN_WH, TEST_SHAPE_MAX_WH, TEST_SHAPE_MAX_D);
+		    TEST_SHAPE_MIN_W, TEST_SHAPE_MIN_H, TEST_SHAPE_MIN_D,
+		    TEST_SHAPE_MAX_W, TEST_SHAPE_MAX_H, TEST_SHAPE_MAX_D);
       }
     else
       {
@@ -3739,13 +3780,13 @@ lw6sys_test (int mode)
 {
   int ret = 0;
 
-  ret = test_arg () && test_assoc () && test_build () && test_checksum ()
-    && test_color () && test_convert () && test_daemon () && test_dump ()
-    && test_env () && test_escape () && test_file () && test_profiler ()
-    && test_hash () && test_hexa () && test_history () && test_i18n ()
-    && test_id () && test_keyword () && test_list () && test_log (mode)
-    && test_math () && test_mem () && test_mutex () && test_options ()
-    && test_nop () && test_path () && test_progress ()
+  ret = test_arg () && test_assoc () && test_backtrace () && test_build ()
+    && test_checksum () && test_color () && test_convert () && test_daemon ()
+    && test_dump () && test_env () && test_escape () && test_file ()
+    && test_profiler () && test_hash () && test_hexa () && test_history ()
+    && test_i18n () && test_id () && test_keyword () && test_list ()
+    && test_log (mode) && test_math () && test_mem () && test_mutex ()
+    && test_options () && test_nop () && test_path () && test_progress ()
     && test_random () && test_sdl () && test_serial () && test_shape ()
     && test_signal () && test_sort () && test_spinlock () && test_str ()
     && test_stream () && test_thread () && test_time () && test_url ()
