@@ -356,6 +356,11 @@ extern lw6sys_color_hsv_t LW6SYS_COLOR_HSV_BLUE;
 #define TMP8(message,arg1,arg2,arg3,arg4,arg5,arg6,arg7,arg8) lw6sys_log(LW6SYS_LOG_TMP, message, arg1, arg2, arg3, arg4, arg5, arg6, arg7, arg8)
 #define TMP9(message,arg1,arg2,arg3,arg4,arg5,arg6,arg7,arg8,arg9) lw6sys_log(LW6SYS_LOG_TMP, message, arg1, arg2, arg3, arg4, arg5, arg6, arg7, arg8, arg9)
 
+/*
+ * Instant backtrace facility
+ */
+#define BT { char *bt=lw6sys_backtrace(0); if (bt) { TMP1("bt: \"%s\"",bt); LW6SYS_FREE(bt); } }
+
 /*
  * Common indenting parameters
  */
@@ -392,6 +397,9 @@ extern void lw6sys_assoc_sort_and_map (lw6sys_assoc_t * assoc,
 extern lw6sys_assoc_t *lw6sys_assoc_dup (lw6sys_assoc_t * assoc,
 					 lw6sys_dup_func_t dup_func);
 
+/* sys-backtrace.c */
+extern char *lw6sys_backtrace (int skip);
+
 /* sys-bazooka.c */
 extern int lw6sys_default_memory_bazooka ();
 extern void lw6sys_clear_memory_bazooka ();
@@ -451,6 +459,7 @@ extern char *lw6sys_build_get_enable_mod_gl ();
 extern char *lw6sys_build_get_enable_mod_csound ();
 extern char *lw6sys_build_get_enable_mod_ogg ();
 extern char *lw6sys_build_get_enable_mod_http ();
+extern char *lw6sys_build_get_enable_openmp ();
 extern char *lw6sys_build_get_enable_optimize ();
 extern char *lw6sys_build_get_enable_allinone ();
 extern char *lw6sys_build_get_enable_fullstatic ();
@@ -812,6 +821,7 @@ extern char *lw6sys_path_add_slash (char *path);
 extern char *lw6sys_path_strip_slash (char *path);
 extern char *lw6sys_path_concat (char *path1, char *path2);
 extern lw6sys_list_t *lw6sys_path_split (char *path);
+extern char *lw6sys_file_only (char *path);
 extern int lw6sys_path_is_relative (char *path);
 extern int lw6sys_path_is_cwd (char *path);
 extern char *lw6sys_path_parent (char *path);
@@ -877,8 +887,9 @@ extern void lw6sys_serialize_int16 (unsigned char *data, int16_t value);
 extern int16_t lw6sys_unserialize_int16 (unsigned char *data);
 
 /* sys-shape.c */
-extern int lw6sys_shape_check_min_max_whd (lw6sys_whd_t * shape, int min_wh,
-					   int max_wh, int max_d);;
+extern int lw6sys_shape_check_min_max_whd (lw6sys_whd_t * shape,
+					   lw6sys_whd_t * min,
+					   lw6sys_whd_t * max);
 extern int lw6sys_shape_check_pos (lw6sys_whd_t * shape, lw6sys_xyz_t * pos);
 extern int lw6sys_shape_is_same (lw6sys_whd_t * shape_a,
 				 lw6sys_whd_t * shape_b);
